
/*  Copyright (C) 2017 CZ.NIC, z.s.p.o. <knot-dns@labs.nic.cz>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include <arpa/inet.h>
#include <fcntl.h>
#include <stdbool.h>
#include <stdint.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <libgen.h>
#include <math.h>
#include <netinet/in.h>
#include <sys/socket.h>
#include <sys/mman.h>
#include <sys/stat.h>
#include <sys/types.h>
#include <unistd.h>

#include "zscanner/scanner.h"
#include "zscanner/functions.h"
#include "libknot/descriptor.h"

/*! \brief Shorthand for setting warning data. */
#define WARN(err_code) { s->error.code = err_code; }
/*! \brief Shorthand for setting error data. */
#define ERR(err_code) { WARN(err_code); s->error.fatal = true; }
/*! \brief Shorthand for error reset. */
#define NOERR { WARN(ZS_OK); s->error.fatal = false; }

/*!
 * \brief Writes record type number to r_data.
 *
 * \param type		Type number.
 * \param rdata_tail	Position where to write type number to.
 */
static inline void type_num(const uint16_t type, uint8_t **rdata_tail)
{
	*((uint16_t *)*rdata_tail) = htons(type);
	*rdata_tail += 2;
}

/*!
 * \brief Sets bit to bitmap window.
 *
 * \param type		Type number.
 * \param s		Scanner context.
 */
static inline void window_add_bit(const uint16_t type, zs_scanner_t *s) {
	uint8_t win      = type / 256;
	uint8_t bit_pos  = type % 256;
	uint8_t byte_pos = bit_pos / 8;

	((s->windows[win]).bitmap)[byte_pos] |= 128 >> (bit_pos % 8);

	if ((s->windows[win]).length < byte_pos + 1) {
		(s->windows[win]).length = byte_pos + 1;
	}

	if (s->last_window < win) {
		s->last_window = win;
	}
}

// Include scanner file (in Ragel).

static const short _zone_scanner_actions[] = {
	0, 1, 0, 1, 1, 1, 2, 1,
	3, 1, 4, 1, 6, 1, 7, 1,
	9, 1, 11, 1, 12, 1, 13, 1,
	15, 1, 16, 1, 21, 1, 22, 1,
	24, 1, 25, 1, 27, 1, 29, 1,
	31, 1, 32, 1, 41, 1, 42, 1,
	43, 1, 45, 1, 47, 1, 48, 1,
	49, 1, 50, 1, 54, 1, 55, 1,
	57, 1, 59, 1, 61, 1, 62, 1,
	64, 1, 68, 1, 69, 1, 72, 1,
	73, 1, 76, 1, 79, 1, 81, 1,
	82, 1, 83, 1, 84, 1, 85, 1,
	86, 1, 87, 1, 88, 1, 90, 1,
	92, 1, 94, 1, 98, 1, 99, 1,
	103, 1, 104, 1, 108, 1, 109, 1,
	110, 1, 111, 1, 112, 1, 113, 1,
	114, 1, 115, 1, 116, 1, 117, 1,
	118, 1, 119, 1, 120, 1, 121, 1,
	123, 1, 124, 1, 125, 1, 126, 1,
	153, 1, 154, 1, 155, 1, 156, 1,
	157, 1, 158, 1, 159, 1, 160, 1,
	161, 1, 162, 1, 163, 1, 164, 1,
	165, 1, 166, 1, 167, 1, 168, 1,
	169, 1, 170, 1, 171, 1, 172, 1,
	173, 1, 174, 1, 175, 1, 176, 1,
	177, 1, 178, 1, 179, 1, 180, 1,
	181, 1, 182, 1, 183, 1, 184, 1,
	185, 1, 186, 1, 187, 1, 188, 1,
	189, 1, 190, 1, 191, 1, 192, 1,
	193, 1, 194, 1, 195, 1, 196, 1,
	197, 1, 198, 1, 199, 1, 200, 1,
	201, 1, 202, 1, 203, 1, 204, 1,
	205, 1, 206, 1, 207, 1, 208, 1,
	209, 1, 210, 1, 211, 1, 212, 1,
	213, 1, 214, 1, 215, 1, 216, 1,
	217, 1, 218, 1, 219, 1, 220, 1,
	221, 1, 222, 1, 223, 1, 224, 1,
	225, 1, 226, 1, 227, 1, 228, 1,
	229, 1, 230, 1, 231, 1, 232, 1,
	233, 1, 234, 1, 235, 1, 236, 1,
	237, 1, 238, 1, 240, 1, 242, 1,
	243, 1, 244, 1, 245, 1, 252, 1,
	253, 1, 258, 1, 260, 1, 265, 1,
	268, 1, 269, 1, 270, 1, 271, 1,
	273, 1, 274, 1, 275, 1, 276, 1,
	278, 2, 0, 45, 2, 1, 0, 2,
	1, 274, 2, 1, 321, 2, 2, 4,
	2, 2, 6, 2, 3, 4, 2, 3,
	6, 2, 4, 2, 2, 4, 3, 2,
	4, 6, 2, 5, 1, 2, 6, 1,
	2, 6, 2, 2, 6, 3, 2, 6,
	4, 2, 6, 28, 2, 7, 68, 2,
	7, 72, 2, 8, 9, 2, 10, 1,
	2, 11, 12, 2, 14, 15, 2, 16,
	12, 2, 16, 13, 2, 17, 22, 2,
	17, 72, 2, 17, 79, 2, 18, 0,
	2, 18, 6, 2, 20, 0, 2, 21,
	11, 2, 24, 64, 2, 24, 103, 2,
	24, 114, 2, 25, 0, 2, 25, 1,
	2, 25, 2, 2, 25, 3, 2, 25,
	241, 2, 26, 23, 2, 27, 1, 2,
	27, 2, 2, 27, 3, 2, 27, 6,
	2, 27, 88, 2, 28, 6, 2, 29,
	7, 2, 29, 273, 2, 29, 278, 2,
	30, 23, 2, 31, 0, 2, 31, 1,
	2, 31, 2, 2, 31, 3, 2, 31,
	241, 2, 32, 37, 2, 33, 32, 2,
	34, 68, 2, 34, 258, 2, 34, 273,
	2, 34, 278, 2, 38, 246, 2, 38,
	247, 2, 38, 248, 2, 38, 249, 2,
	38, 250, 2, 38, 251, 2, 41, 0,
	2, 41, 1, 2, 41, 2, 2, 41,
	3, 2, 42, 0, 2, 42, 1, 2,
	42, 2, 2, 42, 3, 2, 43, 0,
	2, 43, 1, 2, 43, 2, 2, 43,
	3, 2, 44, 272, 2, 45, 1, 2,
	45, 2, 2, 45, 3, 2, 52, 6,
	2, 52, 43, 2, 52, 88, 2, 53,
	54, 2, 55, 1, 2, 55, 2, 2,
	55, 3, 2, 56, 273, 2, 57, 0,
	2, 58, 59, 2, 60, 61, 2, 62,
	0, 2, 62, 57, 2, 66, 0, 2,
	66, 273, 2, 70, 21, 2, 74, 64,
	2, 75, 6, 2, 76, 7, 2, 77,
	21, 2, 79, 7, 2, 83, 6, 2,
	85, 86, 2, 87, 1, 2, 87, 2,
	2, 87, 3, 2, 88, 1, 2, 88,
	2, 2, 88, 3, 2, 88, 6, 2,
	89, 90, 2, 91, 273, 2, 92, 93,
	2, 94, 95, 2, 96, 97, 2, 96,
	98, 2, 96, 99, 2, 100, 101, 2,
	102, 273, 2, 105, 273, 2, 106, 0,
	2, 122, 273, 2, 124, 0, 2, 125,
	0, 2, 126, 0, 2, 127, 0, 2,
	128, 0, 2, 129, 0, 2, 130, 0,
	2, 131, 0, 2, 132, 0, 2, 133,
	0, 2, 134, 0, 2, 135, 0, 2,
	136, 0, 2, 137, 0, 2, 138, 0,
	2, 139, 0, 2, 140, 0, 2, 141,
	0, 2, 142, 0, 2, 143, 0, 2,
	144, 0, 2, 145, 0, 2, 146, 0,
	2, 147, 0, 2, 148, 0, 2, 149,
	0, 2, 150, 273, 2, 151, 273, 2,
	152, 273, 2, 153, 1, 2, 153, 2,
	2, 153, 3, 2, 154, 1, 2, 154,
	2, 2, 154, 3, 2, 155, 1, 2,
	155, 2, 2, 155, 3, 2, 156, 1,
	2, 156, 2, 2, 156, 3, 2, 157,
	1, 2, 157, 2, 2, 157, 3, 2,
	158, 1, 2, 158, 2, 2, 158, 3,
	2, 159, 1, 2, 159, 2, 2, 159,
	3, 2, 160, 1, 2, 160, 2, 2,
	160, 3, 2, 161, 1, 2, 161, 2,
	2, 161, 3, 2, 162, 1, 2, 162,
	2, 2, 162, 3, 2, 163, 1, 2,
	163, 2, 2, 163, 3, 2, 164, 1,
	2, 164, 2, 2, 164, 3, 2, 165,
	1, 2, 165, 2, 2, 165, 3, 2,
	166, 1, 2, 166, 2, 2, 166, 3,
	2, 167, 1, 2, 167, 2, 2, 167,
	3, 2, 168, 1, 2, 168, 2, 2,
	168, 3, 2, 169, 1, 2, 169, 2,
	2, 169, 3, 2, 170, 1, 2, 170,
	2, 2, 170, 3, 2, 171, 1, 2,
	171, 2, 2, 171, 3, 2, 172, 1,
	2, 172, 2, 2, 172, 3, 2, 173,
	1, 2, 173, 2, 2, 173, 3, 2,
	174, 1, 2, 174, 2, 2, 174, 3,
	2, 175, 1, 2, 175, 2, 2, 175,
	3, 2, 176, 1, 2, 176, 2, 2,
	176, 3, 2, 177, 1, 2, 177, 2,
	2, 177, 3, 2, 178, 1, 2, 178,
	2, 2, 178, 3, 2, 179, 1, 2,
	179, 2, 2, 179, 3, 2, 180, 1,
	2, 180, 2, 2, 180, 3, 2, 181,
	1, 2, 181, 2, 2, 181, 3, 2,
	182, 1, 2, 182, 2, 2, 182, 3,
	2, 183, 1, 2, 183, 2, 2, 183,
	3, 2, 184, 1, 2, 184, 2, 2,
	184, 3, 2, 185, 1, 2, 185, 2,
	2, 185, 3, 2, 186, 1, 2, 186,
	2, 2, 186, 3, 2, 187, 1, 2,
	187, 2, 2, 187, 3, 2, 188, 1,
	2, 188, 2, 2, 188, 3, 2, 189,
	1, 2, 189, 2, 2, 189, 3, 2,
	190, 1, 2, 190, 2, 2, 190, 3,
	2, 191, 1, 2, 191, 2, 2, 191,
	3, 2, 192, 1, 2, 192, 2, 2,
	192, 3, 2, 193, 1, 2, 193, 2,
	2, 193, 3, 2, 194, 1, 2, 194,
	2, 2, 194, 3, 2, 195, 1, 2,
	195, 2, 2, 195, 3, 2, 196, 1,
	2, 196, 2, 2, 196, 3, 2, 197,
	1, 2, 197, 2, 2, 197, 3, 2,
	198, 1, 2, 198, 2, 2, 198, 3,
	2, 199, 1, 2, 199, 2, 2, 199,
	3, 2, 200, 1, 2, 200, 2, 2,
	200, 3, 2, 201, 1, 2, 201, 2,
	2, 201, 3, 2, 202, 1, 2, 202,
	2, 2, 202, 3, 2, 203, 1, 2,
	203, 2, 2, 203, 3, 2, 204, 1,
	2, 204, 2, 2, 204, 3, 2, 205,
	1, 2, 205, 2, 2, 205, 3, 2,
	206, 1, 2, 206, 2, 2, 206, 3,
	2, 207, 1, 2, 207, 2, 2, 207,
	3, 2, 208, 1, 2, 208, 2, 2,
	208, 3, 2, 209, 1, 2, 209, 2,
	2, 209, 3, 2, 210, 1, 2, 210,
	2, 2, 210, 3, 2, 211, 1, 2,
	211, 2, 2, 211, 3, 2, 212, 1,
	2, 212, 2, 2, 212, 3, 2, 213,
	1, 2, 213, 2, 2, 213, 3, 2,
	214, 1, 2, 214, 2, 2, 214, 3,
	2, 215, 1, 2, 215, 2, 2, 215,
	3, 2, 216, 1, 2, 216, 2, 2,
	216, 3, 2, 217, 1, 2, 217, 2,
	2, 217, 3, 2, 218, 1, 2, 218,
	2, 2, 218, 3, 2, 219, 1, 2,
	219, 2, 2, 219, 3, 2, 220, 1,
	2, 220, 2, 2, 220, 3, 2, 221,
	1, 2, 221, 2, 2, 221, 3, 2,
	222, 1, 2, 222, 2, 2, 222, 3,
	2, 223, 1, 2, 223, 2, 2, 223,
	3, 2, 224, 1, 2, 224, 2, 2,
	224, 3, 2, 225, 1, 2, 225, 2,
	2, 225, 3, 2, 226, 1, 2, 226,
	2, 2, 226, 3, 2, 227, 1, 2,
	227, 2, 2, 227, 3, 2, 228, 1,
	2, 228, 2, 2, 228, 3, 2, 229,
	1, 2, 229, 2, 2, 229, 3, 2,
	230, 1, 2, 230, 2, 2, 230, 3,
	2, 231, 1, 2, 231, 2, 2, 231,
	3, 2, 232, 1, 2, 232, 2, 2,
	232, 3, 2, 233, 1, 2, 233, 2,
	2, 233, 3, 2, 234, 1, 2, 234,
	2, 2, 234, 3, 2, 235, 1, 2,
	235, 2, 2, 235, 3, 2, 236, 1,
	2, 236, 2, 2, 236, 3, 2, 237,
	1, 2, 237, 2, 2, 237, 3, 2,
	238, 1, 2, 238, 2, 2, 238, 3,
	2, 239, 0, 2, 242, 1, 2, 242,
	2, 2, 242, 3, 2, 243, 1, 2,
	243, 2, 2, 243, 3, 2, 244, 1,
	2, 244, 2, 2, 244, 3, 2, 245,
	1, 2, 245, 2, 2, 245, 3, 2,
	252, 1, 2, 252, 2, 2, 252, 3,
	2, 253, 1, 2, 253, 2, 2, 253,
	3, 2, 256, 0, 2, 257, 273, 2,
	259, 103, 2, 264, 103, 2, 273, 7,
	2, 274, 1, 2, 274, 6, 2, 277,
	274, 2, 278, 7, 2, 278, 273, 2,
	279, 272, 2, 280, 272, 2, 281, 272,
	2, 282, 272, 2, 283, 272, 2, 284,
	272, 2, 285, 272, 2, 286, 272, 2,
	287, 272, 2, 288, 272, 2, 289, 272,
	2, 290, 272, 2, 291, 272, 2, 292,
	272, 2, 293, 272, 2, 294, 272, 2,
	295, 272, 2, 296, 272, 2, 297, 272,
	2, 298, 272, 2, 299, 272, 2, 300,
	272, 2, 301, 272, 2, 302, 272, 2,
	303, 272, 2, 304, 272, 2, 305, 272,
	2, 306, 272, 2, 307, 272, 2, 308,
	272, 2, 309, 272, 2, 310, 272, 2,
	311, 272, 2, 312, 272, 2, 313, 272,
	2, 314, 272, 2, 315, 272, 2, 316,
	272, 2, 317, 272, 2, 318, 272, 2,
	319, 272, 2, 320, 272, 2, 321, 1,
	3, 0, 45, 1, 3, 0, 45, 2,
	3, 0, 45, 3, 3, 1, 6, 321,
	3, 1, 28, 6, 3, 1, 66, 0,
	3, 1, 106, 0, 3, 1, 239, 0,
	3, 1, 256, 0, 3, 1, 274, 321,
	3, 2, 6, 28, 3, 2, 28, 6,
	3, 3, 6, 28, 3, 3, 28, 6,
	3, 4, 6, 2, 3, 4, 6, 3,
	3, 5, 1, 321, 3, 5, 321, 1,
	3, 6, 2, 4, 3, 6, 2, 28,
	3, 6, 3, 4, 3, 6, 3, 28,
	3, 6, 321, 1, 3, 8, 10, 1,
	3, 13, 19, 0, 3, 18, 6, 2,
	3, 18, 6, 3, 3, 18, 78, 6,
	3, 21, 11, 12, 3, 25, 66, 0,
	3, 27, 1, 88, 3, 27, 2, 6,
	3, 27, 2, 88, 3, 27, 3, 6,
	3, 27, 3, 88, 3, 27, 88, 6,
	3, 27, 277, 274, 3, 27, 279, 272,
	3, 28, 1, 6, 3, 28, 2, 6,
	3, 28, 3, 6, 3, 29, 84, 7,
	3, 29, 273, 7, 3, 29, 278, 7,
	3, 29, 278, 273, 3, 31, 1, 0,
	3, 33, 32, 274, 3, 34, 150, 273,
	3, 34, 152, 273, 3, 34, 278, 7,
	3, 34, 278, 273, 3, 36, 38, 246,
	3, 36, 38, 247, 3, 36, 38, 248,
	3, 36, 38, 249, 3, 36, 38, 250,
	3, 36, 38, 251, 3, 38, 246, 1,
	3, 38, 246, 2, 3, 38, 246, 3,
	3, 38, 247, 1, 3, 38, 247, 2,
	3, 38, 247, 3, 3, 38, 248, 1,
	3, 38, 248, 2, 3, 38, 248, 3,
	3, 38, 249, 1, 3, 38, 249, 2,
	3, 38, 249, 3, 3, 38, 250, 1,
	3, 38, 250, 2, 3, 38, 250, 3,
	3, 38, 251, 1, 3, 38, 251, 2,
	3, 38, 251, 3, 3, 44, 272, 1,
	3, 44, 272, 2, 3, 44, 272, 3,
	3, 44, 272, 274, 3, 46, 34, 68,
	3, 46, 34, 273, 3, 46, 34, 278,
	3, 51, 33, 32, 3, 52, 6, 2,
	3, 52, 6, 3, 3, 52, 43, 0,
	3, 52, 43, 1, 3, 52, 43, 2,
	3, 52, 43, 3, 3, 52, 88, 1,
	3, 52, 88, 2, 3, 52, 88, 3,
	3, 62, 57, 0, 3, 63, 58, 59,
	3, 65, 24, 64, 3, 67, 0, 1,
	3, 70, 21, 11, 3, 71, 0, 1,
	3, 75, 2, 6, 3, 75, 3, 6,
	3, 77, 21, 11, 3, 80, 0, 1,
	3, 83, 6, 1, 3, 83, 26, 23,
	3, 83, 28, 6, 3, 85, 26, 23,
	3, 85, 86, 274, 3, 88, 2, 6,
	3, 88, 3, 6, 3, 91, 102, 273,
	3, 91, 150, 273, 3, 92, 93, 0,
	3, 92, 93, 1, 3, 92, 93, 2,
	3, 92, 93, 3, 3, 94, 95, 0,
	3, 94, 95, 1, 3, 94, 95, 2,
	3, 94, 95, 3, 3, 100, 101, 0,
	3, 100, 101, 1, 3, 100, 101, 2,
	3, 100, 101, 3, 3, 105, 107, 258,
	3, 105, 267, 273, 3, 150, 151, 273,
	3, 195, 239, 0, 3, 196, 239, 0,
	3, 197, 239, 0, 3, 198, 239, 0,
	3, 199, 239, 0, 3, 200, 239, 0,
	3, 201, 239, 0, 3, 202, 239, 0,
	3, 203, 239, 0, 3, 204, 239, 0,
	3, 205, 239, 0, 3, 206, 239, 0,
	3, 207, 239, 0, 3, 208, 239, 0,
	3, 209, 239, 0, 3, 210, 239, 0,
	3, 211, 239, 0, 3, 212, 239, 0,
	3, 213, 239, 0, 3, 214, 239, 0,
	3, 215, 239, 0, 3, 216, 239, 0,
	3, 217, 239, 0, 3, 218, 239, 0,
	3, 219, 239, 0, 3, 220, 239, 0,
	3, 221, 239, 0, 3, 222, 239, 0,
	3, 223, 239, 0, 3, 224, 239, 0,
	3, 225, 239, 0, 3, 226, 239, 0,
	3, 227, 239, 0, 3, 228, 239, 0,
	3, 229, 239, 0, 3, 230, 239, 0,
	3, 231, 239, 0, 3, 232, 239, 0,
	3, 233, 239, 0, 3, 234, 239, 0,
	3, 235, 239, 0, 3, 236, 239, 0,
	3, 237, 239, 0, 3, 238, 239, 0,
	3, 255, 33, 32, 3, 260, 261, 0,
	3, 260, 262, 0, 3, 263, 105, 273,
	3, 265, 266, 0, 3, 267, 105, 273,
	3, 273, 7, 84, 3, 274, 6, 1,
	3, 274, 6, 28, 3, 274, 26, 23,
	3, 274, 28, 6, 3, 274, 321, 1,
	3, 276, 26, 23, 3, 278, 273, 7,
	3, 279, 272, 1, 3, 279, 272, 2,
	3, 279, 272, 3, 3, 279, 272, 6,
	3, 279, 272, 274, 3, 280, 272, 1,
	3, 280, 272, 2, 3, 280, 272, 3,
	3, 280, 272, 274, 3, 281, 272, 1,
	3, 281, 272, 2, 3, 281, 272, 3,
	3, 281, 272, 274, 3, 282, 272, 1,
	3, 282, 272, 2, 3, 282, 272, 3,
	3, 282, 272, 274, 3, 283, 272, 1,
	3, 283, 272, 2, 3, 283, 272, 3,
	3, 283, 272, 274, 3, 284, 272, 1,
	3, 284, 272, 2, 3, 284, 272, 3,
	3, 284, 272, 274, 3, 285, 272, 1,
	3, 285, 272, 2, 3, 285, 272, 3,
	3, 285, 272, 274, 3, 286, 272, 1,
	3, 286, 272, 2, 3, 286, 272, 3,
	3, 286, 272, 274, 3, 287, 272, 1,
	3, 287, 272, 2, 3, 287, 272, 3,
	3, 287, 272, 274, 3, 288, 272, 1,
	3, 288, 272, 2, 3, 288, 272, 3,
	3, 288, 272, 274, 3, 289, 272, 1,
	3, 289, 272, 2, 3, 289, 272, 3,
	3, 289, 272, 274, 3, 290, 272, 1,
	3, 290, 272, 2, 3, 290, 272, 3,
	3, 290, 272, 274, 3, 291, 272, 1,
	3, 291, 272, 2, 3, 291, 272, 3,
	3, 291, 272, 274, 3, 292, 272, 1,
	3, 292, 272, 2, 3, 292, 272, 3,
	3, 292, 272, 274, 3, 293, 272, 1,
	3, 293, 272, 2, 3, 293, 272, 3,
	3, 293, 272, 274, 3, 294, 272, 1,
	3, 294, 272, 2, 3, 294, 272, 3,
	3, 294, 272, 274, 3, 295, 272, 1,
	3, 295, 272, 2, 3, 295, 272, 3,
	3, 295, 272, 274, 3, 296, 272, 1,
	3, 296, 272, 2, 3, 296, 272, 3,
	3, 296, 272, 274, 3, 297, 272, 1,
	3, 297, 272, 2, 3, 297, 272, 3,
	3, 297, 272, 274, 3, 298, 272, 1,
	3, 298, 272, 2, 3, 298, 272, 3,
	3, 298, 272, 274, 3, 299, 272, 1,
	3, 299, 272, 2, 3, 299, 272, 3,
	3, 299, 272, 274, 3, 300, 272, 1,
	3, 300, 272, 2, 3, 300, 272, 3,
	3, 300, 272, 274, 3, 301, 272, 1,
	3, 301, 272, 2, 3, 301, 272, 3,
	3, 301, 272, 274, 3, 302, 272, 1,
	3, 302, 272, 2, 3, 302, 272, 3,
	3, 302, 272, 274, 3, 303, 272, 1,
	3, 303, 272, 2, 3, 303, 272, 3,
	3, 303, 272, 274, 3, 304, 272, 1,
	3, 304, 272, 2, 3, 304, 272, 3,
	3, 304, 272, 274, 3, 305, 272, 1,
	3, 305, 272, 2, 3, 305, 272, 3,
	3, 305, 272, 274, 3, 306, 272, 1,
	3, 306, 272, 2, 3, 306, 272, 3,
	3, 306, 272, 274, 3, 307, 272, 1,
	3, 307, 272, 2, 3, 307, 272, 3,
	3, 307, 272, 274, 3, 308, 272, 1,
	3, 308, 272, 2, 3, 308, 272, 3,
	3, 308, 272, 274, 3, 309, 272, 1,
	3, 309, 272, 2, 3, 309, 272, 3,
	3, 309, 272, 274, 3, 310, 272, 1,
	3, 310, 272, 2, 3, 310, 272, 3,
	3, 310, 272, 274, 3, 311, 272, 1,
	3, 311, 272, 2, 3, 311, 272, 3,
	3, 311, 272, 274, 3, 312, 272, 1,
	3, 312, 272, 2, 3, 312, 272, 3,
	3, 312, 272, 274, 3, 313, 272, 1,
	3, 313, 272, 2, 3, 313, 272, 3,
	3, 313, 272, 274, 3, 314, 272, 1,
	3, 314, 272, 2, 3, 314, 272, 3,
	3, 314, 272, 274, 3, 315, 272, 1,
	3, 315, 272, 2, 3, 315, 272, 3,
	3, 315, 272, 274, 3, 316, 272, 1,
	3, 316, 272, 2, 3, 316, 272, 3,
	3, 316, 272, 274, 3, 317, 272, 1,
	3, 317, 272, 2, 3, 317, 272, 3,
	3, 317, 272, 274, 3, 318, 272, 1,
	3, 318, 272, 2, 3, 318, 272, 3,
	3, 318, 272, 274, 3, 319, 272, 1,
	3, 319, 272, 2, 3, 319, 272, 3,
	3, 319, 272, 274, 3, 320, 272, 1,
	3, 320, 272, 2, 3, 320, 272, 3,
	3, 320, 272, 274, 3, 321, 1, 5,
	4, 1, 6, 321, 28, 4, 1, 274,
	28, 6, 4, 5, 1, 6, 321, 4,
	5, 1, 80, 0, 4, 5, 67, 0,
	1, 4, 5, 71, 0, 1, 4, 5,
	80, 0, 1, 4, 6, 5, 321, 1,
	4, 6, 67, 0, 1, 4, 6, 321,
	1, 5, 4, 6, 321, 1, 28, 4,
	16, 13, 19, 0, 4, 18, 78, 6,
	2, 4, 18, 78, 6, 3, 4, 25,
	1, 66, 0, 4, 27, 1, 6, 321,
	4, 27, 1, 277, 274, 4, 27, 1,
	279, 272, 4, 27, 2, 88, 6, 4,
	27, 2, 277, 274, 4, 27, 2, 279,
	272, 4, 27, 3, 88, 6, 4, 27,
	3, 277, 274, 4, 27, 3, 279, 272,
	4, 27, 279, 272, 6, 4, 27, 279,
	272, 274, 4, 29, 34, 278, 7, 4,
	29, 46, 34, 278, 4, 29, 278, 273,
	7, 4, 33, 32, 26, 23, 4, 34,
	278, 273, 7, 4, 36, 33, 32, 37,
	4, 36, 38, 246, 1, 4, 36, 38,
	246, 2, 4, 36, 38, 246, 3, 4,
	36, 38, 247, 1, 4, 36, 38, 247,
	2, 4, 36, 38, 247, 3, 4, 36,
	38, 248, 1, 4, 36, 38, 248, 2,
	4, 36, 38, 248, 3, 4, 36, 38,
	249, 1, 4, 36, 38, 249, 2, 4,
	36, 38, 249, 3, 4, 36, 38, 250,
	1, 4, 36, 38, 250, 2, 4, 36,
	38, 250, 3, 4, 36, 38, 251, 1,
	4, 36, 38, 251, 2, 4, 36, 38,
	251, 3, 4, 38, 248, 256, 0, 4,
	38, 249, 256, 0, 4, 38, 250, 256,
	0, 4, 38, 251, 256, 0, 4, 39,
	35, 33, 32, 4, 40, 35, 33, 32,
	4, 44, 272, 1, 274, 4, 46, 34,
	7, 68, 4, 52, 51, 33, 32, 4,
	70, 21, 11, 12, 4, 77, 21, 11,
	12, 4, 83, 28, 1, 6, 4, 83,
	28, 2, 6, 4, 83, 28, 3, 6,
	4, 85, 86, 26, 23, 4, 88, 1,
	6, 321, 4, 91, 150, 151, 273, 4,
	92, 93, 1, 0, 4, 94, 95, 1,
	0, 4, 100, 101, 1, 0, 4, 195,
	1, 239, 0, 4, 196, 1, 239, 0,
	4, 197, 1, 239, 0, 4, 198, 1,
	239, 0, 4, 199, 1, 239, 0, 4,
	200, 1, 239, 0, 4, 201, 1, 239,
	0, 4, 202, 1, 239, 0, 4, 203,
	1, 239, 0, 4, 204, 1, 239, 0,
	4, 205, 1, 239, 0, 4, 206, 1,
	239, 0, 4, 207, 1, 239, 0, 4,
	208, 1, 239, 0, 4, 209, 1, 239,
	0, 4, 210, 1, 239, 0, 4, 211,
	1, 239, 0, 4, 212, 1, 239, 0,
	4, 213, 1, 239, 0, 4, 214, 1,
	239, 0, 4, 215, 1, 239, 0, 4,
	216, 1, 239, 0, 4, 217, 1, 239,
	0, 4, 218, 1, 239, 0, 4, 219,
	1, 239, 0, 4, 220, 1, 239, 0,
	4, 221, 1, 239, 0, 4, 222, 1,
	239, 0, 4, 223, 1, 239, 0, 4,
	224, 1, 239, 0, 4, 225, 1, 239,
	0, 4, 226, 1, 239, 0, 4, 227,
	1, 239, 0, 4, 228, 1, 239, 0,
	4, 229, 1, 239, 0, 4, 230, 1,
	239, 0, 4, 231, 1, 239, 0, 4,
	232, 1, 239, 0, 4, 233, 1, 239,
	0, 4, 234, 1, 239, 0, 4, 235,
	1, 239, 0, 4, 236, 1, 239, 0,
	4, 237, 1, 239, 0, 4, 238, 1,
	239, 0, 4, 274, 6, 321, 1, 4,
	279, 272, 1, 274, 4, 279, 272, 2,
	6, 4, 279, 272, 3, 6, 4, 279,
	272, 274, 6, 4, 280, 272, 1, 274,
	4, 281, 272, 1, 274, 4, 282, 272,
	1, 274, 4, 283, 272, 1, 274, 4,
	284, 272, 1, 274, 4, 285, 272, 1,
	274, 4, 286, 272, 1, 274, 4, 287,
	272, 1, 274, 4, 288, 272, 1, 274,
	4, 289, 272, 1, 274, 4, 290, 272,
	1, 274, 4, 291, 272, 1, 274, 4,
	292, 272, 1, 274, 4, 293, 272, 1,
	274, 4, 294, 272, 1, 274, 4, 295,
	272, 1, 274, 4, 296, 272, 1, 274,
	4, 297, 272, 1, 274, 4, 298, 272,
	1, 274, 4, 299, 272, 1, 274, 4,
	300, 272, 1, 274, 4, 301, 272, 1,
	274, 4, 302, 272, 1, 274, 4, 303,
	272, 1, 274, 4, 304, 272, 1, 274,
	4, 305, 272, 1, 274, 4, 306, 272,
	1, 274, 4, 307, 272, 1, 274, 4,
	308, 272, 1, 274, 4, 309, 272, 1,
	274, 4, 310, 272, 1, 274, 4, 311,
	272, 1, 274, 4, 312, 272, 1, 274,
	4, 313, 272, 1, 274, 4, 314, 272,
	1, 274, 4, 315, 272, 1, 274, 4,
	316, 272, 1, 274, 4, 317, 272, 1,
	274, 4, 318, 272, 1, 274, 4, 319,
	272, 1, 274, 4, 320, 272, 1, 274,
	5, 18, 6, 71, 0, 1, 5, 27,
	1, 88, 6, 321, 5, 27, 1, 279,
	272, 274, 5, 27, 2, 279, 272, 6,
	5, 27, 3, 279, 272, 6, 5, 27,
	279, 272, 274, 6, 5, 29, 34, 278,
	273, 7, 5, 33, 32, 274, 26, 23,
	5, 36, 38, 248, 256, 0, 5, 36,
	38, 249, 256, 0, 5, 36, 38, 250,
	256, 0, 5, 36, 38, 251, 256, 0,
	5, 38, 248, 1, 256, 0, 5, 38,
	249, 1, 256, 0, 5, 38, 250, 1,
	256, 0, 5, 38, 251, 1, 256, 0,
	5, 46, 34, 278, 273, 7, 5, 52,
	6, 67, 0, 1, 5, 75, 6, 80,
	0, 1, 5, 85, 86, 274, 26, 23,
	5, 254, 39, 35, 33, 32, 5, 279,
	272, 1, 6, 321, 6, 18, 78, 6,
	80, 0, 1, 6, 27, 1, 279, 272,
	6, 321, 6, 29, 46, 34, 278, 273,
	7, 6, 36, 38, 248, 1, 256, 0,
	6, 36, 38, 249, 1, 256, 0, 6,
	36, 38, 250, 1, 256, 0, 6, 36,
	38, 251, 1, 256, 0, 6, 279, 272,
	1, 274, 6, 321, 6, 279, 272, 274,
	6, 321, 1, 7, 27, 1, 279, 272,
	274, 6, 321
};

static const short _zone_scanner_cond_offsets[] = {
	0, 0, 2, 4, 6, 8, 10, 12,
	14, 14, 14, 17, 19, 21, 24, 26,
	28, 30, 30, 30, 32, 37, 42, 42,
	42, 42, 42, 42, 44, 46, 46, 46,
	48, 48, 48, 48, 50, 50, 50, 50,
	50, 52, 52, 52, 52, 54, 54, 54,
	54, 56, 58, 58, 58, 58, 58, 60,
	60, 62, 62, 62, 62, 62, 64, 64,
	66, 68, 68, 68, 68, 68, 68, 68,
	68, 70, 70, 70, 72, 74, 74, 74,
	76, 76, 78, 78, 80, 82, 82, 82,
	82, 82, 84, 86, 86, 86, 86, 86,
	88, 88, 90, 92, 92, 94, 96, 96,
	96, 96, 96, 98, 98, 98, 100, 100,
	102, 102, 102, 102, 104, 106, 106, 106,
	108, 108, 110, 110, 112, 112, 112, 112,
	114, 114, 114, 114, 116, 116, 118, 118,
	118, 118, 120, 120, 120, 122, 125, 127,
	127, 129, 131, 133, 135, 135, 137, 140,
	140, 140, 140, 140, 140, 140, 140, 140,
	140, 142, 144, 147, 149, 151, 154, 156,
	156, 158, 161, 163, 165, 167, 169, 171,
	174, 176, 178, 180, 182, 184, 186, 188,
	190, 192, 194, 196, 198, 200, 202, 204,
	206, 208, 211, 213, 213, 213, 213, 213,
	213, 213, 213, 213, 213, 215, 217, 219,
	222, 224, 226, 228, 230, 232, 234, 236,
	238, 240, 242, 244, 246, 248, 250, 252,
	254, 256, 258, 263, 268, 273, 278, 278,
	278, 280, 280, 280, 280, 282, 282, 284,
	287, 289, 291, 296, 301, 306, 311, 314,
	316, 321, 326, 328, 330, 332, 334, 336,
	338, 340, 342, 344, 346, 348, 350, 352,
	354, 357, 360, 362, 365, 365, 365, 365,
	365, 365, 365, 365, 365, 365, 365, 365,
	365, 365, 365, 365, 365, 365, 366, 366,
	366, 366, 366, 367, 369, 371, 373, 375,
	375, 377, 377, 379, 382, 384, 386, 386,
	388, 390, 390, 390, 390, 390, 390, 392,
	395, 397, 399, 401, 403, 403, 405, 407,
	407, 407, 407, 407, 407, 409, 412, 414,
	417, 420, 420, 420, 420, 420, 422, 425,
	425, 427, 429, 431, 431, 431, 433, 436,
	436, 436, 438, 438, 438, 438, 438, 438,
	440, 442, 442, 442, 444, 444, 444, 444,
	446, 446, 446, 446, 446, 448, 448, 448,
	448, 450, 450, 450, 450, 452, 454, 454,
	454, 454, 454, 456, 456, 458, 458, 458,
	458, 458, 460, 460, 460, 460, 460, 460,
	460, 460, 462, 462, 462, 464, 466, 466,
	466, 468, 468, 470, 470, 472, 474, 474,
	474, 474, 474, 476, 478, 478, 478, 478,
	478, 480, 480, 482, 484, 484, 486, 488,
	488, 488, 488, 488, 490, 490, 490, 492,
	492, 494, 494, 494, 494, 496, 498, 498,
	498, 500, 500, 502, 502, 504, 504, 504,
	504, 506, 506, 506, 506, 508, 508, 510,
	510, 510, 510, 512, 512, 512, 514, 514,
	514, 514, 516, 516, 518, 520, 522, 524,
	526, 526, 528, 531, 534, 537, 539, 541,
	543, 545, 545, 547, 550, 553, 555, 558,
	558, 558, 558, 558, 558, 558, 558, 558,
	558, 558, 558, 558, 558, 558, 558, 558,
	558, 558, 558, 558, 558, 558, 558, 558,
	558, 558, 558, 558, 558, 558, 558, 558,
	558, 558, 558, 558, 558, 558, 558, 558,
	558, 558, 558, 558, 558, 558, 558, 558,
	558, 558, 558, 558, 558, 558, 558, 558,
	558, 558, 558, 558, 558, 558, 558, 558,
	558, 558, 558, 558, 558, 558, 558, 558,
	558, 558, 558, 558, 558, 558, 558, 558,
	558, 558, 558, 558, 558, 558, 558, 558,
	558, 558, 558, 558, 558, 558, 558, 558,
	558, 558, 558, 558, 558, 558, 558, 558,
	558, 558, 558, 558, 558, 558, 558, 558,
	558, 558, 558, 558, 558, 558, 558, 558,
	558, 558, 558, 558, 558, 558, 558, 558,
	558, 558, 558, 558, 558, 558, 558, 558,
	558, 558, 558, 558, 558, 558, 558, 558,
	558, 558, 558, 558, 558, 558, 560, 562,
	564, 566, 568, 570, 572, 574, 576, 578,
	580, 582, 582, 582, 582, 582, 585, 587,
	587, 589, 592, 594, 594, 596, 599, 601,
	601, 603, 606, 609, 612, 612, 614, 616,
	616, 619, 619, 621, 623, 623, 626, 626,
	628, 630, 630, 633, 633, 635, 637, 640,
	640, 640, 640, 642, 644, 646, 648, 650,
	652, 654, 656, 658, 660, 662, 664, 666,
	668, 670, 672, 672, 674, 676, 678, 680,
	682, 684, 686, 688, 691, 693, 695, 698,
	700, 702, 704, 707, 709, 711, 713, 716,
	718, 720, 722, 725, 727, 730, 732, 734,
	737, 740, 743, 745, 748, 750, 752, 755,
	758, 758, 760, 762, 764, 766, 768, 770,
	770, 773, 776, 779, 779, 781, 783, 785,
	787, 789, 791, 793, 795, 797, 799, 799,
	802, 805, 808, 811, 814, 814, 816, 818,
	820, 822, 824, 826, 828, 831, 834, 837,
	839, 839, 839, 839, 839, 839, 841, 844,
	844, 844, 844, 844, 846, 848, 850, 852,
	854, 856, 856, 858, 861, 864, 867, 870,
	870, 872, 874, 876, 878, 878, 880, 883,
	886, 889, 889, 891, 893, 895, 897, 899,
	901, 907, 918, 920, 923, 929, 932, 943,
	946, 949, 952, 954, 956, 958, 960, 966,
	969, 972, 974, 976, 978, 980, 986, 989,
	992, 994, 996, 998, 1000, 1006, 1009, 1012,
	1015, 1015, 1017, 1019, 1021, 1023, 1025, 1027,
	1029, 1031, 1033, 1035, 1037, 1039, 1041, 1043,
	1045, 1047, 1049, 1052, 1055, 1058, 1061, 1064,
	1067, 1070, 1073, 1073, 1073, 1075, 1075, 1075,
	1075, 1077, 1077, 1079, 1079, 1079, 1081, 1081,
	1081, 1081, 1081, 1081, 1083, 1085, 1085, 1085,
	1087, 1087, 1087, 1087, 1089, 1089, 1089, 1089,
	1089, 1091, 1091, 1091, 1091, 1093, 1093, 1093,
	1093, 1095, 1097, 1097, 1097, 1097, 1097, 1099,
	1099, 1101, 1101, 1101, 1101, 1101, 1103, 1103,
	1103, 1103, 1103, 1103, 1103, 1103, 1105, 1105,
	1105, 1107, 1109, 1109, 1109, 1111, 1111, 1113,
	1113, 1115, 1117, 1117, 1117, 1117, 1117, 1119,
	1121, 1121, 1121, 1121, 1121, 1123, 1123, 1125,
	1127, 1127, 1129, 1131, 1131, 1131, 1131, 1131,
	1133, 1133, 1133, 1135, 1135, 1137, 1137, 1137,
	1137, 1139, 1141, 1141, 1141, 1143, 1143, 1145,
	1145, 1147, 1147, 1147, 1147, 1149, 1149, 1149,
	1149, 1151, 1151, 1153, 1153, 1153, 1153, 1155,
	1155, 1155, 1157, 1157, 1157, 1157, 1157, 1159,
	1161, 1163, 1165, 1167, 1169, 1171, 1174, 1177,
	1180, 1180, 1182, 1182, 1184, 1186, 1188, 1190,
	1192, 1194, 1196, 1198, 1198, 1198, 1198, 1198,
	1198, 1198, 1198, 1198, 1198, 1198, 1198, 1198,
	1198, 1198, 1201, 1201, 1203, 1206, 1209, 1212,
	1212, 1214, 1216, 1218, 1220, 1222, 1224, 1224,
	1224, 1224, 1227, 1230, 1233, 1233, 1235, 1237,
	1239, 1241, 1243, 1245, 1245, 1247, 1250, 1253,
	1256, 1259, 1259, 1261, 1263, 1263, 1266, 1266,
	1268, 1270, 1270, 1270, 1270, 1270, 1270, 1270,
	1270, 1270, 1270, 1273, 1273, 1273, 1273, 1273,
	1273, 1273, 1273, 1273, 1273, 1273, 1273, 1273,
	1273, 1275, 1277, 1279, 1281, 1281, 1284, 1287,
	1287, 1289, 1291, 1293, 1295, 1295, 1298, 1301,
	1303, 1305, 1307, 1309, 1311, 1313, 1315, 1317,
	1319, 1321, 1321, 1321, 1321, 1321, 1321, 1321,
	1321, 1323, 1323, 1325, 1328, 1328, 1330, 1333,
	1333, 1335, 1338, 1340, 1340, 1342, 1345, 1348,
	1348, 1348, 1348, 1348, 1348, 1348, 1348, 1348,
	1348, 1350, 1353, 1353, 1353, 1355, 1358, 1360,
	1363, 1365, 1368, 1370, 1373, 1373, 1373, 1373,
	1373, 1375, 1378, 1378, 1380, 1383, 1383, 1385,
	1388, 1388, 1394, 1397, 1408, 1411, 1422, 1425,
	1425, 1425, 1425, 1425, 1425, 1425, 1425, 1427,
	1430, 1430, 1430, 1430, 1430, 1430
};

static const char _zone_scanner_cond_lengths[] = {
	0, 2, 2, 2, 2, 2, 2, 2,
	0, 0, 3, 2, 2, 3, 2, 2,
	2, 0, 0, 2, 5, 5, 0, 0,
	0, 0, 0, 2, 2, 0, 0, 2,
	0, 0, 0, 2, 0, 0, 0, 0,
	2, 0, 0, 0, 2, 0, 0, 0,
	2, 2, 0, 0, 0, 0, 2, 0,
	2, 0, 0, 0, 0, 2, 0, 2,
	2, 0, 0, 0, 0, 0, 0, 0,
	2, 0, 0, 2, 2, 0, 0, 2,
	0, 2, 0, 2, 2, 0, 0, 0,
	0, 2, 2, 0, 0, 0, 0, 2,
	0, 2, 2, 0, 2, 2, 0, 0,
	0, 0, 2, 0, 0, 2, 0, 2,
	0, 0, 0, 2, 2, 0, 0, 2,
	0, 2, 0, 2, 0, 0, 0, 2,
	0, 0, 0, 2, 0, 2, 0, 0,
	0, 2, 0, 0, 2, 3, 2, 0,
	2, 2, 2, 2, 0, 2, 3, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	2, 2, 3, 2, 2, 3, 2, 0,
	2, 3, 2, 2, 2, 2, 2, 3,
	2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2,
	2, 3, 2, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 2, 2, 2, 3,
	2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 5, 5, 5, 5, 0, 0,
	2, 0, 0, 0, 2, 0, 2, 3,
	2, 2, 5, 5, 5, 5, 3, 2,
	5, 5, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2,
	3, 3, 2, 3, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 1, 0, 0,
	0, 0, 1, 2, 2, 2, 2, 0,
	2, 0, 2, 3, 2, 2, 0, 2,
	2, 0, 0, 0, 0, 0, 2, 3,
	2, 2, 2, 2, 0, 2, 2, 0,
	0, 0, 0, 0, 2, 3, 2, 3,
	3, 0, 0, 0, 0, 2, 3, 0,
	2, 2, 2, 0, 0, 2, 3, 0,
	0, 2, 0, 0, 0, 0, 0, 2,
	2, 0, 0, 2, 0, 0, 0, 2,
	0, 0, 0, 0, 2, 0, 0, 0,
	2, 0, 0, 0, 2, 2, 0, 0,
	0, 0, 2, 0, 2, 0, 0, 0,
	0, 2, 0, 0, 0, 0, 0, 0,
	0, 2, 0, 0, 2, 2, 0, 0,
	2, 0, 2, 0, 2, 2, 0, 0,
	0, 0, 2, 2, 0, 0, 0, 0,
	2, 0, 2, 2, 0, 2, 2, 0,
	0, 0, 0, 2, 0, 0, 2, 0,
	2, 0, 0, 0, 2, 2, 0, 0,
	2, 0, 2, 0, 2, 0, 0, 0,
	2, 0, 0, 0, 2, 0, 2, 0,
	0, 0, 2, 0, 0, 2, 0, 0,
	0, 2, 0, 2, 2, 2, 2, 2,
	0, 2, 3, 3, 3, 2, 2, 2,
	2, 0, 2, 3, 3, 2, 3, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2,
	2, 0, 0, 0, 0, 3, 2, 0,
	2, 3, 2, 0, 2, 3, 2, 0,
	2, 3, 3, 3, 0, 2, 2, 0,
	3, 0, 2, 2, 0, 3, 0, 2,
	2, 0, 3, 0, 2, 2, 3, 0,
	0, 0, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 0, 2, 2, 2, 2, 2,
	2, 2, 2, 3, 2, 2, 3, 2,
	2, 2, 3, 2, 2, 2, 3, 2,
	2, 2, 3, 2, 3, 2, 2, 3,
	3, 3, 2, 3, 2, 2, 3, 3,
	0, 2, 2, 2, 2, 2, 2, 0,
	3, 3, 3, 0, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 0, 3,
	3, 3, 3, 3, 0, 2, 2, 2,
	2, 2, 2, 2, 3, 3, 3, 2,
	0, 0, 0, 0, 0, 2, 3, 0,
	0, 0, 0, 2, 2, 2, 2, 2,
	2, 0, 2, 3, 3, 3, 3, 0,
	2, 2, 2, 2, 0, 2, 3, 3,
	3, 0, 2, 2, 2, 2, 2, 2,
	6, 11, 2, 3, 6, 3, 11, 3,
	3, 3, 2, 2, 2, 2, 6, 3,
	3, 2, 2, 2, 2, 6, 3, 3,
	2, 2, 2, 2, 6, 3, 3, 3,
	0, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 3, 3, 3, 3, 3, 3,
	3, 3, 0, 0, 2, 0, 0, 0,
	2, 0, 2, 0, 0, 2, 0, 0,
	0, 0, 0, 2, 2, 0, 0, 2,
	0, 0, 0, 2, 0, 0, 0, 0,
	2, 0, 0, 0, 2, 0, 0, 0,
	2, 2, 0, 0, 0, 0, 2, 0,
	2, 0, 0, 0, 0, 2, 0, 0,
	0, 0, 0, 0, 0, 2, 0, 0,
	2, 2, 0, 0, 2, 0, 2, 0,
	2, 2, 0, 0, 0, 0, 2, 2,
	0, 0, 0, 0, 2, 0, 2, 2,
	0, 2, 2, 0, 0, 0, 0, 2,
	0, 0, 2, 0, 2, 0, 0, 0,
	2, 2, 0, 0, 2, 0, 2, 0,
	2, 0, 0, 0, 2, 0, 0, 0,
	2, 0, 2, 0, 0, 0, 2, 0,
	0, 2, 0, 0, 0, 0, 2, 2,
	2, 2, 2, 2, 2, 3, 3, 3,
	0, 2, 0, 2, 2, 2, 2, 2,
	2, 2, 2, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 3, 0, 2, 3, 3, 3, 0,
	2, 2, 2, 2, 2, 2, 0, 0,
	0, 3, 3, 3, 0, 2, 2, 2,
	2, 2, 2, 0, 2, 3, 3, 3,
	3, 0, 2, 2, 0, 3, 0, 2,
	2, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 3, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	2, 2, 2, 2, 0, 3, 3, 0,
	2, 2, 2, 2, 0, 3, 3, 2,
	2, 2, 2, 2, 2, 2, 2, 2,
	2, 0, 0, 0, 0, 0, 0, 0,
	2, 0, 2, 3, 0, 2, 3, 0,
	2, 3, 2, 0, 2, 3, 3, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	2, 3, 0, 0, 2, 3, 2, 3,
	2, 3, 2, 3, 0, 0, 0, 0,
	2, 3, 0, 2, 3, 0, 2, 3,
	0, 6, 3, 11, 3, 11, 3, 0,
	0, 0, 0, 0, 0, 0, 2, 3,
	0, 0, 0, 0, 0, 0
};

static const short _zone_scanner_cond_keys[] = {
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, -128, 9, 10, 10,
	11, 127, 10, 10, 59, 59, 10, 10,
	59, 59, -128, 9, 10, 10, 11, 127,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	-128, 9, 10, 10, 11, 58, 59, 59,
	60, 127, -128, 9, 10, 10, 11, 58,
	59, 59, 60, 127, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, -128, 9, 10, 10,
	11, 127, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, -128, 9, 10, 10, 11, 127,
	10, 10, 59, 59, 10, 10, 59, 59,
	-128, 9, 10, 10, 11, 127, 10, 10,
	59, 59, 10, 10, 59, 59, -128, 9,
	10, 10, 11, 127, 10, 10, 59, 59,
	10, 10, 59, 59, -128, 9, 10, 10,
	11, 127, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, -128, 9,
	10, 10, 11, 127, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	-128, 9, 10, 10, 11, 127, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, -128, 9,
	10, 10, 11, 127, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, -128, 9, 10, 10,
	11, 58, 59, 59, 60, 127, -128, 9,
	10, 10, 11, 58, 59, 59, 60, 127,
	-128, 9, 10, 10, 11, 58, 59, 59,
	60, 127, -128, 9, 10, 10, 11, 58,
	59, 59, 60, 127, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	-128, 9, 10, 10, 11, 127, 10, 10,
	59, 59, 10, 10, 59, 59, -128, 9,
	10, 10, 11, 58, 59, 59, 60, 127,
	-128, 9, 10, 10, 11, 58, 59, 59,
	60, 127, -128, 9, 10, 10, 11, 58,
	59, 59, 60, 127, -128, 9, 10, 10,
	11, 58, 59, 59, 60, 127, -128, 9,
	10, 10, 11, 127, 10, 10, 59, 59,
	-128, 9, 10, 10, 11, 58, 59, 59,
	60, 127, -128, 9, 10, 10, 11, 58,
	59, 59, 60, 127, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, -128, 9, 10, 10,
	11, 127, -128, 9, 10, 10, 11, 127,
	10, 10, 59, 59, -128, 9, 10, 10,
	11, 127, 10, 10, 10, 10, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, -128, 9,
	10, 10, 11, 127, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	-128, 9, 10, 10, 11, 127, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, -128, 9, 10, 10, 11, 127,
	10, 10, 59, 59, -128, 9, 10, 10,
	11, 127, -128, 9, 10, 10, 11, 127,
	10, 10, 59, 59, -128, 9, 10, 10,
	11, 127, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, -128, 9, 10, 10, 11, 127,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	-128, 9, 10, 10, 11, 127, -128, 9,
	10, 10, 11, 127, -128, 9, 10, 10,
	11, 127, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, -128, 9,
	10, 10, 11, 127, -128, 9, 10, 10,
	11, 127, 10, 10, 59, 59, -128, 9,
	10, 10, 11, 127, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, -128, 9, 10, 10,
	11, 127, 10, 10, 59, 59, 10, 10,
	59, 59, -128, 9, 10, 10, 11, 127,
	10, 10, 59, 59, 10, 10, 59, 59,
	-128, 9, 10, 10, 11, 127, 10, 10,
	59, 59, 10, 10, 59, 59, -128, 9,
	10, 10, 11, 127, -128, 9, 10, 10,
	11, 127, -128, 9, 10, 10, 11, 127,
	10, 10, 59, 59, 10, 10, 59, 59,
	-128, 9, 10, 10, 11, 127, 10, 10,
	59, 59, 10, 10, 59, 59, -128, 9,
	10, 10, 11, 127, 10, 10, 59, 59,
	10, 10, 59, 59, -128, 9, 10, 10,
	11, 127, 10, 10, 59, 59, 10, 10,
	59, 59, -128, 9, 10, 10, 11, 127,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	-128, 9, 10, 10, 11, 127, 10, 10,
	59, 59, 10, 10, 59, 59, -128, 9,
	10, 10, 11, 127, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	-128, 9, 10, 10, 11, 127, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, -128, 9, 10, 10, 11, 127,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, -128, 9, 10, 10,
	11, 127, 10, 10, 59, 59, -128, 9,
	10, 10, 11, 127, 10, 10, 59, 59,
	10, 10, 59, 59, -128, 9, 10, 10,
	11, 127, -128, 9, 10, 10, 11, 127,
	-128, 9, 10, 10, 11, 127, 10, 10,
	59, 59, -128, 9, 10, 10, 11, 127,
	10, 10, 59, 59, 10, 10, 59, 59,
	-128, 9, 10, 10, 11, 127, -128, 9,
	10, 10, 11, 127, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, -128, 9, 10, 10,
	11, 127, -128, 9, 10, 10, 11, 127,
	-128, 9, 10, 10, 11, 127, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, -128, 9,
	10, 10, 11, 127, -128, 9, 10, 10,
	11, 127, -128, 9, 10, 10, 11, 127,
	-128, 9, 10, 10, 11, 127, -128, 9,
	10, 10, 11, 127, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	-128, 9, 10, 10, 11, 127, -128, 9,
	10, 10, 11, 127, -128, 9, 10, 10,
	11, 127, 10, 10, 59, 59, 10, 10,
	59, 59, -128, 9, 10, 10, 11, 127,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, -128, 9, 10, 10,
	11, 127, -128, 9, 10, 10, 11, 127,
	-128, 9, 10, 10, 11, 127, -128, 9,
	10, 10, 11, 127, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	-128, 9, 10, 10, 11, 127, -128, 9,
	10, 10, 11, 127, -128, 9, 10, 10,
	11, 127, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 9, 9, 10, 10, 32, 32,
	40, 40, 41, 41, 59, 59, 9, 9,
	10, 10, 32, 32, 40, 40, 41, 41,
	43, 43, 47, 47, 48, 57, 59, 59,
	65, 90, 97, 122, 10, 10, 59, 59,
	-128, 9, 10, 10, 11, 127, 9, 9,
	10, 10, 32, 32, 40, 40, 41, 41,
	59, 59, -128, 9, 10, 10, 11, 127,
	9, 9, 10, 10, 32, 32, 40, 40,
	41, 41, 43, 43, 47, 47, 48, 57,
	59, 59, 65, 90, 97, 122, -128, 9,
	10, 10, 11, 127, -128, 9, 10, 10,
	11, 127, -128, 9, 10, 10, 11, 127,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	9, 9, 10, 10, 32, 32, 40, 40,
	41, 41, 59, 59, -128, 9, 10, 10,
	11, 127, -128, 9, 10, 10, 11, 127,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	9, 9, 10, 10, 32, 32, 40, 40,
	41, 41, 59, 59, -128, 9, 10, 10,
	11, 127, -128, 9, 10, 10, 11, 127,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	9, 9, 10, 10, 32, 32, 40, 40,
	41, 41, 59, 59, -128, 9, 10, 10,
	11, 127, -128, 9, 10, 10, 11, 127,
	-128, 9, 10, 10, 11, 127, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, -128, 9, 10, 10, 11, 127,
	-128, 9, 10, 10, 11, 127, -128, 9,
	10, 10, 11, 127, -128, 9, 10, 10,
	11, 127, -128, 9, 10, 10, 11, 127,
	-128, 9, 10, 10, 11, 127, -128, 9,
	10, 10, 11, 127, -128, 9, 10, 10,
	11, 127, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, -128, 9,
	10, 10, 11, 127, -128, 9, 10, 10,
	11, 127, -128, 9, 10, 10, 11, 127,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, -128, 9, 10, 10,
	11, 127, 10, 10, 59, 59, -128, 9,
	10, 10, 11, 127, -128, 9, 10, 10,
	11, 127, -128, 9, 10, 10, 11, 127,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	10, 10, 59, 59, 10, 10, 59, 59,
	-128, 9, 10, 10, 11, 127, -128, 9,
	10, 10, 11, 127, -128, 9, 10, 10,
	11, 127, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, -128, 9,
	10, 10, 11, 127, -128, 9, 10, 10,
	11, 127, -128, 9, 10, 10, 11, 127,
	-128, 9, 10, 10, 11, 127, 10, 10,
	59, 59, 10, 10, 59, 59, -128, 9,
	10, 10, 11, 127, 10, 10, 59, 59,
	10, 10, 59, 59, -128, 9, 10, 10,
	11, 127, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, -128, 9, 10, 10, 11, 127,
	-128, 9, 10, 10, 11, 127, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, -128, 9,
	10, 10, 11, 127, -128, 9, 10, 10,
	11, 127, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, 10, 10, 59, 59, 10, 10,
	59, 59, -128, 9, 10, 10, 11, 127,
	10, 10, 59, 59, -128, 9, 10, 10,
	11, 127, 10, 10, 59, 59, -128, 9,
	10, 10, 11, 127, 10, 10, 59, 59,
	10, 10, 59, 59, -128, 9, 10, 10,
	11, 127, -128, 9, 10, 10, 11, 127,
	10, 10, 59, 59, -128, 9, 10, 10,
	11, 127, 10, 10, 59, 59, -128, 9,
	10, 10, 11, 127, 10, 10, 59, 59,
	-128, 9, 10, 10, 11, 127, 10, 10,
	59, 59, -128, 9, 10, 10, 11, 127,
	10, 10, 59, 59, -128, 9, 10, 10,
	11, 127, 10, 10, 59, 59, -128, 9,
	10, 10, 11, 127, 10, 10, 59, 59,
	-128, 9, 10, 10, 11, 127, 10, 10,
	59, 59, -128, 9, 10, 10, 11, 127,
	9, 9, 10, 10, 32, 32, 40, 40,
	41, 41, 59, 59, -128, 9, 10, 10,
	11, 127, 9, 9, 10, 10, 32, 32,
	40, 40, 41, 41, 43, 43, 47, 47,
	48, 57, 59, 59, 65, 90, 97, 122,
	-128, 9, 10, 10, 11, 127, 9, 9,
	10, 10, 32, 32, 40, 40, 41, 41,
	43, 43, 47, 47, 48, 57, 59, 59,
	65, 90, 97, 122, -128, 9, 10, 10,
	11, 127, 10, 10, 59, 59, -128, 9,
	10, 10, 11, 127, 0
};

static const char _zone_scanner_cond_spaces[] = {
	0, 0, 0, 0, 0, 0, 5, 5,
	5, 5, 0, 0, 0, 0, 0, 0,
	0, 5, 5, 5, 5, 0, 0, 0,
	5, 5, 0, 0, 0, 0, 5, 5,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5,
	0, 0, 0, 0, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 5, 5, 5, 5, 5, 5, 5,
	5, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 5, 5, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 5, 5,
	5, 5, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 5, 5,
	5, 5, 5, 5, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 5, 5, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 2, 2, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 5, 5, 0, 0,
	0, 5, 5, 5, 5, 5, 5, 5,
	5, 0, 0, 0, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 0, 0,
	0, 0, 0, 0, 0, 0, 5, 5,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 5, 5, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 5, 5, 5, 5, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	5, 5, 5, 5, 5, 5, 5, 5,
	5, 5, 5, 5, 5, 5, 5, 5,
	0, 0, 0, 5, 5, 5, 5, 0,
	0, 0, 5, 5, 5, 5, 5, 5,
	0, 0, 0, 5, 5, 5, 5, 5,
	5, 0, 0, 0, 5, 5, 5, 5,
	5, 5, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 1, 1, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 5, 5, 5,
	5, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	5, 5, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 5, 5,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 8, 11, 8,
	8, 8, 11, 3, 6, 3, 3, 3,
	3, 3, 3, 6, 3, 3, 1, 1,
	6, 6, 6, 4, 9, 4, 4, 4,
	9, 7, 7, 7, 8, 11, 8, 8,
	8, 3, 3, 3, 11, 3, 3, 10,
	10, 10, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	8, 11, 8, 8, 8, 11, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 8, 11, 8, 8,
	8, 11, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	8, 11, 8, 8, 8, 11, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 1,
	1, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 5, 5, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 5,
	5, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 5, 5, 5, 5, 5,
	5, 0, 0, 5, 5, 0, 0, 0,
	5, 5, 0, 0, 0, 5, 5, 0,
	0, 0, 0, 0, 5, 5, 0, 0,
	0, 0, 0, 0, 5, 5, 0, 0,
	0, 5, 5, 0, 0, 0, 5, 5,
	0, 0, 0, 5, 5, 0, 0, 0,
	5, 5, 0, 0, 0, 5, 5, 0,
	0, 0, 5, 5, 0, 0, 0, 5,
	5, 0, 0, 0, 4, 9, 4, 4,
	4, 9, 7, 7, 7, 3, 6, 3,
	3, 3, 3, 3, 3, 6, 3, 3,
	6, 6, 6, 8, 11, 8, 8, 8,
	3, 3, 3, 11, 3, 3, 10, 10,
	10, 5, 5, 0, 0, 0, 0
};

static const short _zone_scanner_key_offsets[] = {
	0, 0, 40, 58, 94, 110, 127, 135,
	143, 144, 145, 148, 167, 186, 192, 244,
	264, 302, 310, 312, 322, 336, 350, 354,
	356, 358, 360, 362, 372, 382, 384, 386,
	396, 398, 400, 402, 412, 418, 420, 422,
	424, 434, 438, 440, 442, 452, 454, 456,
	458, 468, 478, 480, 482, 484, 485, 495,
	496, 506, 508, 510, 512, 514, 524, 528,
	534, 570, 572, 574, 576, 578, 580, 582,
	584, 594, 598, 600, 610, 620, 626, 627,
	637, 638, 648, 650, 660, 670, 674, 676,
	678, 680, 690, 700, 706, 708, 710, 712,
	722, 724, 734, 746, 748, 759, 771, 773,
	775, 777, 779, 789, 791, 793, 803, 809,
	819, 821, 823, 825, 835, 845, 853, 855,
	865, 867, 877, 879, 889, 891, 893, 895,
	905, 911, 913, 915, 925, 927, 937, 939,
	941, 943, 955, 957, 959, 969, 972, 1012,
	1016, 1022, 1060, 1078, 1086, 1098, 1106, 1109,
	1110, 1116, 1118, 1120, 1122, 1124, 1126, 1128,
	1134, 1140, 1178, 1181, 1199, 1237, 1240, 1248,
	1260, 1268, 1271, 1287, 1337, 1355, 1374, 1414,
	1420, 1434, 1448, 1500, 1516, 1530, 1540, 1550,
	1562, 1574, 1588, 1600, 1614, 1624, 1638, 1654,
	1668, 1678, 1684, 1698, 1700, 1702, 1704, 1706,
	1708, 1714, 1716, 1718, 1724, 1732, 1752, 1792,
	1798, 1816, 1868, 1884, 1898, 1908, 1918, 1930,
	1942, 1956, 1968, 1982, 1992, 2006, 2022, 2036,
	2046, 2061, 2101, 2115, 2129, 2145, 2159, 2161,
	2163, 2173, 2175, 2177, 2179, 2189, 2191, 2201,
	2207, 2221, 2235, 2251, 2267, 2283, 2297, 2300,
	2352, 2366, 2380, 2394, 2406, 2414, 2422, 2432,
	2442, 2454, 2464, 2476, 2484, 2496, 2510, 2522,
	2530, 2536, 2542, 2552, 2558, 2559, 2560, 2571,
	2587, 2603, 2605, 2607, 2609, 2625, 2631, 2637,
	2643, 2655, 2661, 2663, 2665, 2677, 2683, 2689,
	2695, 2697, 2699, 2705, 2711, 2719, 2739, 2747,
	2748, 2758, 2770, 2780, 2783, 2789, 2805, 2815,
	2833, 2841, 2842, 2844, 2846, 2848, 2858, 2866,
	2869, 2875, 2887, 2895, 2913, 2923, 2941, 2949,
	2950, 2952, 2954, 2956, 2966, 2974, 2980, 2996,
	2999, 3002, 3009, 3016, 3024, 3032, 3049, 3052,
	3053, 3063, 3103, 3119, 3121, 3123, 3133, 3136,
	3144, 3146, 3156, 3160, 3162, 3164, 3166, 3168,
	3178, 3188, 3190, 3192, 3202, 3204, 3206, 3208,
	3218, 3224, 3226, 3228, 3230, 3240, 3244, 3246,
	3248, 3258, 3260, 3262, 3264, 3274, 3284, 3286,
	3288, 3290, 3291, 3301, 3302, 3312, 3314, 3316,
	3318, 3320, 3330, 3332, 3334, 3336, 3338, 3340,
	3342, 3344, 3354, 3358, 3360, 3370, 3380, 3386,
	3387, 3397, 3398, 3408, 3410, 3420, 3430, 3434,
	3436, 3438, 3440, 3450, 3460, 3466, 3468, 3470,
	3472, 3482, 3484, 3494, 3506, 3508, 3519, 3531,
	3533, 3535, 3537, 3539, 3549, 3551, 3553, 3563,
	3569, 3579, 3581, 3583, 3585, 3595, 3605, 3613,
	3615, 3625, 3627, 3637, 3639, 3649, 3651, 3653,
	3655, 3665, 3671, 3673, 3675, 3685, 3687, 3697,
	3699, 3701, 3703, 3715, 3717, 3719, 3729, 3731,
	3733, 3735, 3745, 3747, 3757, 3763, 3771, 3779,
	3791, 3797, 3813, 3816, 3819, 3822, 3828, 3837,
	3847, 3859, 3865, 3881, 3884, 3887, 3895, 3898,
	3910, 3918, 3922, 3928, 3930, 3937, 3939, 3941,
	3943, 3945, 3946, 3947, 3949, 3951, 3953, 3954,
	3960, 3964, 3968, 3969, 3971, 3973, 3975, 3977,
	3983, 3985, 3987, 3989, 3991, 3992, 3993, 3995,
	3997, 3999, 4000, 4001, 4002, 4008, 4009, 4010,
	4012, 4014, 4016, 4017, 4018, 4019, 4025, 4027,
	4028, 4029, 4030, 4031, 4037, 4038, 4039, 4045,
	4047, 4049, 4051, 4053, 4055, 4057, 4059, 4065,
	4067, 4069, 4071, 4073, 4075, 4077, 4081, 4083,
	4085, 4091, 4093, 4095, 4101, 4103, 4105, 4109,
	4111, 4112, 4118, 4120, 4122, 4125, 4132, 4134,
	4136, 4138, 4140, 4141, 4142, 4144, 4146, 4148,
	4149, 4155, 4156, 4157, 4163, 4164, 4165, 4171,
	4185, 4193, 4195, 4197, 4199, 4201, 4203, 4209,
	4215, 4217, 4219, 4221, 4223, 4225, 4231, 4235,
	4237, 4243, 4245, 4247, 4253, 4255, 4257, 4259,
	4265, 4267, 4269, 4275, 4279, 4281, 4287, 4289,
	4291, 4297, 4299, 4301, 4303, 4309, 4311, 4313,
	4319, 4322, 4331, 4340, 4346, 4355, 4361, 4376,
	4382, 4390, 4398, 4406, 4424, 4432, 4450, 4458,
	4476, 4484, 4502, 4510, 4522, 4530, 4533, 4541,
	4553, 4561, 4564, 4572, 4584, 4592, 4595, 4603,
	4615, 4623, 4626, 4629, 4632, 4638, 4644, 4656,
	4662, 4665, 4674, 4680, 4695, 4701, 4704, 4706,
	4714, 4729, 4735, 4738, 4744, 4754, 4770, 4773,
	4780, 4793, 4795, 4803, 4813, 4821, 4831, 4840,
	4848, 4854, 4862, 4870, 4880, 4888, 4898, 4907,
	4915, 4921, 4930, 4932, 4946, 4958, 4972, 4984,
	4998, 5010, 5024, 5034, 5037, 5050, 5063, 5066,
	5079, 5092, 5102, 5105, 5118, 5131, 5141, 5144,
	5157, 5170, 5180, 5183, 5189, 5192, 5200, 5208,
	5211, 5214, 5217, 5223, 5226, 5234, 5242, 5245,
	5248, 5250, 5258, 5266, 5274, 5282, 5290, 5305,
	5311, 5314, 5317, 5320, 5322, 5330, 5338, 5346,
	5358, 5364, 5376, 5382, 5394, 5400, 5415, 5421,
	5424, 5427, 5430, 5433, 5436, 5442, 5448, 5456,
	5464, 5476, 5482, 5495, 5497, 5500, 5503, 5506,
	5519, 5521, 5522, 5525, 5528, 5530, 5542, 5545,
	5546, 5553, 5560, 5562, 5570, 5582, 5588, 5596,
	5604, 5616, 5622, 5638, 5641, 5644, 5647, 5650,
	5652, 5660, 5668, 5676, 5688, 5694, 5710, 5713,
	5716, 5719, 5721, 5729, 5739, 5745, 5753, 5761,
	5768, 5802, 5815, 5817, 5820, 5834, 5837, 5878,
	5887, 5890, 5893, 5899, 5907, 5915, 5924, 5961,
	5964, 5967, 5973, 5981, 5989, 6002, 6043, 6046,
	6049, 6055, 6063, 6071, 6086, 6120, 6123, 6126,
	6129, 6159, 6171, 6183, 6189, 6197, 6205, 6213,
	6221, 6229, 6237, 6245, 6253, 6261, 6269, 6284,
	6290, 6303, 6305, 6308, 6311, 6314, 6317, 6320,
	6323, 6326, 6329, 6331, 6333, 6339, 6341, 6343,
	6345, 6351, 6353, 6359, 6367, 6369, 6375, 6379,
	6381, 6383, 6385, 6387, 6393, 6399, 6401, 6403,
	6409, 6411, 6413, 6415, 6421, 6427, 6429, 6431,
	6433, 6439, 6443, 6445, 6447, 6453, 6455, 6457,
	6459, 6465, 6471, 6473, 6475, 6477, 6478, 6484,
	6485, 6491, 6493, 6495, 6497, 6499, 6505, 6507,
	6509, 6511, 6513, 6515, 6517, 6519, 6525, 6529,
	6531, 6537, 6543, 6549, 6550, 6556, 6557, 6563,
	6565, 6571, 6577, 6581, 6583, 6585, 6587, 6593,
	6599, 6605, 6607, 6609, 6611, 6617, 6619, 6625,
	6633, 6635, 6642, 6650, 6652, 6654, 6656, 6658,
	6664, 6666, 6668, 6674, 6680, 6686, 6688, 6690,
	6692, 6698, 6704, 6712, 6714, 6720, 6722, 6728,
	6730, 6736, 6738, 6740, 6742, 6748, 6754, 6756,
	6758, 6764, 6766, 6772, 6774, 6776, 6778, 6786,
	6788, 6790, 6796, 6805, 6811, 6817, 6819, 6827,
	6835, 6843, 6855, 6861, 6874, 6876, 6879, 6882,
	6885, 6892, 6894, 6896, 6904, 6912, 6920, 6928,
	6936, 6949, 6955, 6967, 6973, 6980, 6986, 6993,
	7000, 7006, 7013, 7025, 7031, 7032, 7033, 7034,
	7035, 7036, 7039, 7045, 7057, 7060, 7063, 7066,
	7068, 7076, 7084, 7092, 7100, 7108, 7121, 7127,
	7133, 7145, 7148, 7151, 7154, 7156, 7164, 7172,
	7180, 7188, 7196, 7208, 7214, 7230, 7233, 7236,
	7239, 7242, 7244, 7252, 7261, 7270, 7273, 7275,
	7283, 7295, 7301, 7307, 7313, 7314, 7320, 7326,
	7332, 7338, 7345, 7348, 7354, 7360, 7361, 7367,
	7373, 7380, 7386, 7392, 7393, 7399, 7405, 7412,
	7414, 7422, 7430, 7438, 7450, 7456, 7459, 7462,
	7464, 7472, 7484, 7490, 7502, 7508, 7511, 7514,
	7532, 7565, 7613, 7663, 7681, 7731, 7749, 7782,
	7847, 7912, 7912, 7912, 7912, 7924, 7924, 7924,
	7924, 7940, 7940, 7957, 7960, 7960, 8000, 8003,
	8003, 8019, 8022, 8034, 8034, 8050, 8053, 8056,
	8056, 8056, 8056, 8056, 8056, 8056, 8056, 8056,
	8056, 8072, 8075, 8075, 8075, 8085, 8088, 8100,
	8103, 8115, 8118, 8130, 8133, 8133, 8133, 8133,
	8133, 8146, 8149, 8149, 8165, 8168, 8168, 8184,
	8187, 8187, 8201, 8204, 8217, 8220, 8261, 8270,
	8270, 8270, 8270, 8270, 8270, 8270, 8270, 8286,
	8289, 8289, 8289, 8289, 8289, 8289
};

static const short _zone_scanner_trans_keys[] = {
	9, 32, 40, 41, 65, 67, 68, 69,
	72, 73, 75, 76, 77, 78, 80, 82,
	83, 84, 85, 97, 99, 100, 101, 104,
	105, 107, 108, 109, 110, 112, 114, 115,
	116, 117, 778, 827, 1034, 1083, 48, 57,
	9, 32, 40, 41, 68, 72, 77, 83,
	87, 100, 104, 109, 115, 119, 1034, 1083,
	48, 57, 9, 32, 40, 41, 65, 67,
	68, 69, 72, 73, 75, 76, 77, 78,
	80, 82, 83, 84, 85, 97, 99, 100,
	101, 104, 105, 107, 108, 109, 110, 112,
	114, 115, 116, 117, 1034, 1083, 9, 32,
	40, 41, 65, 70, 80, 97, 102, 112,
	2058, 2107, 2314, 2363, 2570, 2619, 9, 32,
	40, 41, 92, 2058, 2107, 2314, 2363, 2570,
	2619, -128, 8, 11, 58, 60, 127, 9,
	32, 40, 41, 778, 827, 1034, 1083, 9,
	32, 40, 41, 778, 827, 1034, 1083, 10,
	35, 1034, 896, 1151, 9, 32, 40, 41,
	92, 1802, 1851, 2058, 2107, 2314, 2363, 2570,
	2619, -128, 8, 11, 58, 60, 127, 9,
	32, 40, 41, 92, 1802, 1851, 2058, 2107,
	2314, 2363, 2570, 2619, -128, 8, 11, 58,
	60, 127, 778, 1034, 640, 895, 896, 1151,
	9, 32, 40, 41, 58, 65, 67, 68,
	69, 72, 73, 75, 76, 77, 78, 80,
	82, 83, 84, 85, 92, 97, 99, 100,
	101, 104, 105, 107, 108, 109, 110, 112,
	114, 115, 116, 117, 1802, 1851, 2058, 2107,
	2314, 2363, 2570, 2619, -128, 8, 11, 47,
	48, 57, 60, 127, 9, 32, 40, 41,
	68, 72, 77, 83, 87, 100, 104, 109,
	115, 119, 778, 827, 1034, 1083, 48, 57,
	9, 32, 40, 41, 65, 67, 68, 69,
	72, 73, 75, 76, 77, 78, 80, 82,
	83, 84, 85, 97, 99, 100, 101, 104,
	105, 107, 108, 109, 110, 112, 114, 115,
	116, 117, 778, 827, 1034, 1083, 65, 68,
	69, 78, 97, 100, 101, 110, 65, 97,
	9, 32, 40, 41, 2058, 2107, 2314, 2363,
	2570, 2619, 777, 778, 800, 808, 809, 827,
	1033, 1034, 1056, 1064, 1065, 1083, 896, 1151,
	777, 778, 800, 808, 809, 827, 1033, 1034,
	1056, 1064, 1065, 1083, 896, 1151, 78, 83,
	110, 115, 83, 115, 75, 107, 69, 101,
	89, 121, 9, 32, 40, 41, 2058, 2107,
	2314, 2363, 2570, 2619, 9, 32, 40, 41,
	2058, 2107, 2314, 2363, 2570, 2619, 82, 114,
	84, 116, 9, 32, 40, 41, 2058, 2107,
	2314, 2363, 2570, 2619, 65, 97, 77, 109,
	69, 101, 9, 32, 40, 41, 2058, 2107,
	2314, 2363, 2570, 2619, 72, 78, 83, 104,
	110, 115, 67, 99, 73, 105, 68, 100,
	9, 32, 40, 41, 2058, 2107, 2314, 2363,
	2570, 2619, 65, 83, 97, 115, 77, 109,
	69, 101, 9, 32, 40, 41, 2058, 2107,
	2314, 2363, 2570, 2619, 75, 107, 69, 101,
	89, 121, 9, 32, 40, 41, 2058, 2107,
	2314, 2363, 2570, 2619, 9, 32, 40, 41,
	2058, 2107, 2314, 2363, 2570, 2619, 85, 117,
	73, 105, 52, 54, 56, 9, 32, 40,
	41, 2058, 2107, 2314, 2363, 2570, 2619, 52,
	9, 32, 40, 41, 2058, 2107, 2314, 2363,
	2570, 2619, 73, 105, 78, 110, 70, 102,
	79, 111, 9, 32, 40, 41, 2058, 2107,
	2314, 2363, 2570, 2619, 78, 80, 110, 112,
	9, 32, 40, 41, 1034, 1083, 9, 32,
	40, 41, 65, 67, 68, 69, 72, 73,
	75, 76, 77, 78, 80, 82, 83, 84,
	85, 97, 99, 100, 101, 104, 105, 107,
	108, 109, 110, 112, 114, 115, 116, 117,
	1034, 1083, 80, 112, 83, 115, 69, 101,
	67, 99, 75, 107, 69, 101, 89, 121,
	9, 32, 40, 41, 2058, 2107, 2314, 2363,
	2570, 2619, 69, 88, 101, 120, 89, 121,
	9, 32, 40, 41, 2058, 2107, 2314, 2363,
	2570, 2619, 9, 32, 40, 41, 2058, 2107,
	2314, 2363, 2570, 2619, 51, 54, 79, 80,
	111, 112, 50, 9, 32, 40, 41, 2058,
	2107, 2314, 2363, 2570, 2619, 52, 9, 32,
	40, 41, 2058, 2107, 2314, 2363, 2570, 2619,
	67, 99, 9, 32, 40, 41, 2058, 2107,
	2314, 2363, 2570, 2619, 9, 32, 40, 41,
	2058, 2107, 2314, 2363, 2570, 2619, 73, 88,
	105, 120, 78, 110, 70, 102, 79, 111,
	9, 32, 40, 41, 2058, 2107, 2314, 2363,
	2570, 2619, 9, 32, 40, 41, 2058, 2107,
	2314, 2363, 2570, 2619, 65, 73, 83, 97,
	105, 115, 80, 112, 84, 116, 82, 114,
	9, 32, 40, 41, 2058, 2107, 2314, 2363,
	2570, 2619, 68, 100, 9, 32, 40, 41,
	2058, 2107, 2314, 2363, 2570, 2619, 9, 32,
	40, 41, 69, 101, 2058, 2107, 2314, 2363,
	2570, 2619, 67, 99, 9, 32, 40, 41,
	51, 2058, 2107, 2314, 2363, 2570, 2619, 9,
	32, 40, 41, 80, 112, 2058, 2107, 2314,
	2363, 2570, 2619, 65, 97, 82, 114, 65,
	97, 77, 109, 9, 32, 40, 41, 2058,
	2107, 2314, 2363, 2570, 2619, 84, 116, 82,
	114, 9, 32, 40, 41, 2058, 2107, 2314,
	2363, 2570, 2619, 80, 82, 84, 112, 114,
	116, 9, 32, 40, 41, 2058, 2107, 2314,
	2363, 2570, 2619, 83, 115, 73, 105, 71,
	103, 9, 32, 40, 41, 2058, 2107, 2314,
	2363, 2570, 2619, 9, 32, 40, 41, 2058,
	2107, 2314, 2363, 2570, 2619, 79, 80, 82,
	83, 111, 112, 114, 115, 65, 97, 9,
	32, 40, 41, 2058, 2107, 2314, 2363, 2570,
	2619, 70, 102, 9, 32, 40, 41, 2058,
	2107, 2314, 2363, 2570, 2619, 86, 118, 9,
	32, 40, 41, 2058, 2107, 2314, 2363, 2570,
	2619, 72, 104, 70, 102, 80, 112, 9,
	32, 40, 41, 2058, 2107, 2314, 2363, 2570,
	2619, 76, 88, 89, 108, 120, 121, 83,
	115, 65, 97, 9, 32, 40, 41, 2058,
	2107, 2314, 2363, 2570, 2619, 84, 116, 9,
	32, 40, 41, 2058, 2107, 2314, 2363, 2570,
	2619, 80, 112, 69, 101, 48, 57, 9,
	32, 40, 41, 2058, 2107, 2314, 2363, 2570,
	2619, 48, 57, 82, 114, 73, 105, 9,
	32, 40, 41, 2058, 2107, 2314, 2363, 2570,
	2619, 1034, 896, 1151, 9, 32, 40, 41,
	65, 67, 68, 69, 72, 73, 75, 76,
	77, 78, 80, 82, 83, 84, 85, 97,
	99, 100, 101, 104, 105, 107, 108, 109,
	110, 112, 114, 115, 116, 117, 778, 827,
	1034, 1083, 48, 57, 78, 80, 110, 112,
	9, 32, 40, 41, 1034, 1083, 9, 32,
	40, 41, 65, 67, 68, 69, 72, 73,
	75, 76, 77, 78, 80, 82, 83, 84,
	85, 97, 99, 100, 101, 104, 105, 107,
	108, 109, 110, 112, 114, 115, 116, 117,
	1034, 1083, 48, 57, 9, 32, 40, 41,
	68, 72, 77, 83, 87, 100, 104, 109,
	115, 119, 1034, 1083, 48, 57, 9, 32,
	40, 41, 1034, 1083, 48, 57, 68, 72,
	77, 83, 87, 100, 104, 109, 115, 119,
	48, 57, 9, 32, 40, 41, 1034, 1083,
	48, 57, 1034, 896, 1151, 10, 73, 79,
	84, 105, 111, 116, 78, 110, 67, 99,
	76, 108, 85, 117, 68, 100, 69, 101,
	32, 59, 9, 10, 40, 41, 9, 32,
	40, 41, 1034, 1083, 9, 32, 40, 41,
	65, 67, 68, 69, 72, 73, 75, 76,
	77, 78, 80, 82, 83, 84, 85, 97,
	99, 100, 101, 104, 105, 107, 108, 109,
	110, 112, 114, 115, 116, 117, 1034, 1083,
	48, 57, 1034, 896, 1151, 9, 32, 40,
	41, 68, 72, 77, 83, 87, 100, 104,
	109, 115, 119, 1034, 1083, 48, 57, 9,
	32, 40, 41, 65, 67, 68, 69, 72,
	73, 75, 76, 77, 78, 80, 82, 83,
	84, 85, 97, 99, 100, 101, 104, 105,
	107, 108, 109, 110, 112, 114, 115, 116,
	117, 1034, 1083, 48, 57, 1034, 896, 1151,
	9, 32, 40, 41, 1034, 1083, 48, 57,
	68, 72, 77, 83, 87, 100, 104, 109,
	115, 119, 48, 57, 9, 32, 40, 41,
	1034, 1083, 48, 57, 1034, 896, 1151, 9,
	32, 40, 41, 65, 70, 80, 97, 102,
	112, 2058, 2107, 2314, 2363, 2570, 2619, 9,
	32, 40, 41, 58, 65, 67, 68, 69,
	72, 73, 75, 76, 77, 78, 80, 82,
	83, 84, 85, 92, 97, 99, 100, 101,
	104, 105, 107, 108, 109, 110, 112, 114,
	115, 116, 117, 2058, 2107, 2314, 2363, 2570,
	2619, -128, 8, 11, 47, 48, 57, 60,
	127, 9, 32, 40, 41, 65, 70, 80,
	97, 102, 112, 1802, 1851, 2058, 2107, 2314,
	2363, 2570, 2619, 9, 32, 40, 41, 92,
	1802, 1851, 2058, 2107, 2314, 2363, 2570, 2619,
	-128, 8, 11, 58, 60, 127, 9, 32,
	40, 41, 65, 67, 68, 69, 72, 73,
	75, 76, 77, 78, 80, 82, 83, 84,
	85, 97, 99, 100, 101, 104, 105, 107,
	108, 109, 110, 112, 114, 115, 116, 117,
	778, 827, 1034, 1083, 48, 57, 778, 1034,
	640, 895, 896, 1151, 9, 32, 40, 41,
	778, 827, 1034, 1083, -128, 8, 11, 58,
	60, 127, 9, 32, 40, 41, 778, 827,
	1034, 1083, -128, 8, 11, 58, 60, 127,
	9, 32, 40, 41, 58, 65, 67, 68,
	69, 72, 73, 75, 76, 77, 78, 80,
	82, 83, 84, 85, 92, 97, 99, 100,
	101, 104, 105, 107, 108, 109, 110, 112,
	114, 115, 116, 117, 1802, 1851, 2058, 2107,
	2314, 2363, 2570, 2619, -128, 8, 11, 47,
	48, 57, 60, 127, 9, 32, 40, 41,
	65, 68, 69, 78, 97, 100, 101, 110,
	778, 827, 1034, 1083, 9, 32, 40, 41,
	72, 78, 83, 104, 110, 115, 778, 827,
	1034, 1083, 9, 32, 40, 41, 85, 117,
	778, 827, 1034, 1083, 9, 32, 40, 41,
	73, 105, 778, 827, 1034, 1083, 9, 32,
	40, 41, 78, 80, 110, 112, 778, 827,
	1034, 1083, 9, 32, 40, 41, 69, 88,
	101, 120, 778, 827, 1034, 1083, 9, 32,
	40, 41, 51, 54, 79, 80, 111, 112,
	778, 827, 1034, 1083, 9, 32, 40, 41,
	73, 88, 105, 120, 778, 827, 1034, 1083,
	9, 32, 40, 41, 65, 73, 83, 97,
	105, 115, 778, 827, 1034, 1083, 9, 32,
	40, 41, 84, 116, 778, 827, 1034, 1083,
	9, 32, 40, 41, 80, 82, 84, 112,
	114, 116, 778, 827, 1034, 1083, 9, 32,
	40, 41, 79, 80, 82, 83, 111, 112,
	114, 115, 778, 827, 1034, 1083, 9, 32,
	40, 41, 76, 88, 89, 108, 120, 121,
	778, 827, 1034, 1083, 9, 32, 40, 41,
	82, 114, 778, 827, 1034, 1083, 778, 1034,
	640, 895, 896, 1151, 9, 32, 40, 41,
	73, 79, 84, 105, 111, 116, 778, 827,
	1034, 1083, 82, 114, 73, 105, 71, 103,
	73, 105, 78, 110, 32, 59, 9, 10,
	40, 41, 84, 116, 76, 108, 32, 59,
	9, 10, 40, 41, 9, 32, 40, 41,
	778, 827, 1034, 1083, 9, 32, 40, 41,
	68, 72, 77, 83, 87, 100, 104, 109,
	115, 119, 778, 827, 1034, 1083, 48, 57,
	9, 32, 40, 41, 65, 67, 68, 69,
	72, 73, 75, 76, 77, 78, 80, 82,
	83, 84, 85, 97, 99, 100, 101, 104,
	105, 107, 108, 109, 110, 112, 114, 115,
	116, 117, 778, 827, 1034, 1083, 48, 57,
	778, 1034, 640, 895, 896, 1151, 9, 32,
	40, 41, 65, 70, 80, 97, 102, 112,
	1802, 1851, 2058, 2107, 2314, 2363, 2570, 2619,
	9, 32, 40, 41, 58, 65, 67, 68,
	69, 72, 73, 75, 76, 77, 78, 80,
	82, 83, 84, 85, 92, 97, 99, 100,
	101, 104, 105, 107, 108, 109, 110, 112,
	114, 115, 116, 117, 1802, 1851, 2058, 2107,
	2314, 2363, 2570, 2619, -128, 8, 11, 47,
	48, 57, 60, 127, 9, 32, 40, 41,
	65, 68, 69, 78, 97, 100, 101, 110,
	778, 827, 1034, 1083, 9, 32, 40, 41,
	72, 78, 83, 104, 110, 115, 778, 827,
	1034, 1083, 9, 32, 40, 41, 85, 117,
	778, 827, 1034, 1083, 9, 32, 40, 41,
	73, 105, 778, 827, 1034, 1083, 9, 32,
	40, 41, 78, 80, 110, 112, 778, 827,
	1034, 1083, 9, 32, 40, 41, 69, 88,
	101, 120, 778, 827, 1034, 1083, 9, 32,
	40, 41, 51, 54, 79, 80, 111, 112,
	778, 827, 1034, 1083, 9, 32, 40, 41,
	73, 88, 105, 120, 778, 827, 1034, 1083,
	9, 32, 40, 41, 65, 73, 83, 97,
	105, 115, 778, 827, 1034, 1083, 9, 32,
	40, 41, 84, 116, 778, 827, 1034, 1083,
	9, 32, 40, 41, 80, 82, 84, 112,
	114, 116, 778, 827, 1034, 1083, 9, 32,
	40, 41, 79, 80, 82, 83, 111, 112,
	114, 115, 778, 827, 1034, 1083, 9, 32,
	40, 41, 76, 88, 89, 108, 120, 121,
	778, 827, 1034, 1083, 9, 32, 40, 41,
	82, 114, 778, 827, 1034, 1083, 9, 32,
	35, 40, 41, 778, 827, 1034, 1083, -128,
	8, 11, 58, 60, 127, 9, 32, 40,
	41, 65, 67, 68, 69, 72, 73, 75,
	76, 77, 78, 80, 82, 83, 84, 85,
	97, 99, 100, 101, 104, 105, 107, 108,
	109, 110, 112, 114, 115, 116, 117, 778,
	827, 1034, 1083, 48, 57, 777, 778, 800,
	808, 809, 827, 1033, 1034, 1056, 1064, 1065,
	1083, 896, 1151, 777, 778, 800, 808, 809,
	827, 1033, 1034, 1056, 1064, 1065, 1083, 896,
	1151, 777, 778, 800, 808, 809, 827, 1033,
	1034, 1056, 1064, 1065, 1083, 640, 895, 896,
	1151, 777, 778, 800, 808, 809, 1033, 1034,
	1056, 1064, 1065, 640, 895, 896, 1151, 65,
	97, 65, 97, 9, 32, 40, 41, 2058,
	2107, 2314, 2363, 2570, 2619, 83, 115, 68,
	100, 66, 98, 9, 32, 40, 41, 2058,
	2107, 2314, 2363, 2570, 2619, 76, 108, 9,
	32, 40, 41, 2058, 2107, 2314, 2363, 2570,
	2619, 778, 1034, 640, 895, 896, 1151, 9,
	32, 40, 41, 778, 827, 1034, 1083, -128,
	8, 11, 58, 60, 127, 9, 32, 40,
	41, 778, 827, 1034, 1083, -128, 8, 11,
	58, 60, 127, 777, 778, 800, 808, 809,
	827, 1033, 1034, 1056, 1064, 1065, 1083, 640,
	895, 896, 1151, 777, 778, 800, 808, 809,
	827, 1033, 1034, 1056, 1064, 1065, 1083, 640,
	895, 896, 1151, 777, 778, 800, 808, 809,
	827, 1033, 1034, 1056, 1064, 1065, 1083, 640,
	895, 896, 1151, 777, 778, 800, 808, 809,
	1033, 1034, 1056, 1064, 1065, 640, 895, 896,
	1151, 1034, 896, 1151, 9, 32, 40, 41,
	58, 65, 67, 68, 69, 72, 73, 75,
	76, 77, 78, 80, 82, 83, 84, 85,
	92, 97, 99, 100, 101, 104, 105, 107,
	108, 109, 110, 112, 114, 115, 116, 117,
	1802, 1851, 2058, 2107, 2314, 2363, 2570, 2619,
	-128, 8, 11, 47, 48, 57, 60, 127,
	777, 778, 800, 808, 809, 827, 1033, 1034,
	1056, 1064, 1065, 1083, 896, 1151, 777, 778,
	800, 808, 809, 827, 1033, 1034, 1056, 1064,
	1065, 1083, 896, 1151, 9, 32, 40, 41,
	65, 68, 69, 78, 97, 100, 101, 110,
	1034, 1083, 9, 32, 40, 41, 72, 78,
	83, 104, 110, 115, 1034, 1083, 9, 32,
	40, 41, 85, 117, 1034, 1083, 9, 32,
	40, 41, 73, 105, 1034, 1083, 9, 32,
	40, 41, 78, 80, 110, 112, 1034, 1083,
	9, 32, 40, 41, 69, 88, 101, 120,
	1034, 1083, 9, 32, 40, 41, 51, 54,
	79, 80, 111, 112, 1034, 1083, 9, 32,
	40, 41, 73, 88, 105, 120, 1034, 1083,
	9, 32, 40, 41, 65, 73, 83, 97,
	105, 115, 1034, 1083, 9, 32, 40, 41,
	84, 116, 1034, 1083, 9, 32, 40, 41,
	80, 82, 84, 112, 114, 116, 1034, 1083,
	9, 32, 40, 41, 79, 80, 82, 83,
	111, 112, 114, 115, 1034, 1083, 9, 32,
	40, 41, 76, 88, 89, 108, 120, 121,
	1034, 1083, 9, 32, 40, 41, 82, 114,
	1034, 1083, 778, 1034, 640, 895, 896, 1151,
	778, 1034, 640, 895, 896, 1151, 9, 32,
	40, 41, 78, 80, 110, 112, 1034, 1083,
	778, 1034, 640, 895, 896, 1151, 10, 10,
	42, 46, 64, 92, 95, 45, 57, 65,
	90, 97, 122, 32, 42, 46, 59, 92,
	95, 9, 10, 40, 41, 45, 57, 65,
	90, 97, 122, 32, 42, 45, 59, 92,
	95, 9, 10, 40, 41, 47, 57, 65,
	90, 97, 122, 48, 57, 48, 57, 48,
	57, 32, 42, 46, 59, 92, 95, 9,
	10, 40, 41, 45, 57, 65, 90, 97,
	122, 32, 59, 9, 10, 40, 41, 32,
	59, 9, 10, 40, 41, 34, 92, 33,
	58, 60, 126, 32, 33, 59, 92, 9,
	10, 35, 39, 40, 41, 42, 126, 32,
	47, 48, 57, 58, 126, 48, 57, 48,
	57, 32, 33, 59, 92, 9, 10, 35,
	39, 40, 41, 42, 126, 9, 34, 92,
	522, 32, 126, 32, 59, 9, 10, 40,
	41, 32, 47, 48, 57, 58, 126, 48,
	57, 48, 57, 9, 34, 92, 522, 32,
	126, 9, 32, 40, 41, 1034, 1083, 9,
	32, 40, 41, 1034, 1083, 48, 57, 9,
	32, 40, 41, 68, 72, 77, 83, 87,
	100, 104, 109, 115, 119, 778, 827, 1034,
	1083, 48, 57, 9, 32, 40, 41, 778,
	827, 1034, 1083, 10, 9, 32, 40, 41,
	778, 827, 1034, 1083, 48, 57, 68, 72,
	77, 83, 87, 100, 104, 109, 115, 119,
	48, 57, 9, 32, 40, 41, 778, 827,
	1034, 1083, 48, 57, 1034, 896, 1151, 9,
	32, 40, 41, 1034, 1083, 9, 32, 40,
	41, 42, 46, 92, 95, 1034, 1083, 45,
	57, 65, 90, 97, 122, 42, 46, 92,
	95, 45, 57, 65, 90, 97, 122, 9,
	32, 40, 41, 42, 45, 92, 95, 778,
	827, 1034, 1083, 47, 57, 65, 90, 97,
	122, 9, 32, 40, 41, 778, 827, 1034,
	1083, 10, 48, 57, 48, 57, 48, 57,
	42, 46, 92, 95, 45, 57, 65, 90,
	97, 122, 9, 32, 40, 41, 778, 827,
	1034, 1083, 1034, 896, 1151, 9, 32, 40,
	41, 1034, 1083, 9, 32, 40, 41, 1034,
	1083, -128, 8, 11, 58, 60, 127, 9,
	32, 40, 41, 778, 827, 1034, 1083, 9,
	32, 40, 41, 42, 46, 92, 95, 778,
	827, 1034, 1083, 45, 57, 65, 90, 97,
	122, 42, 46, 92, 95, 45, 57, 65,
	90, 97, 122, 9, 32, 40, 41, 42,
	45, 92, 95, 778, 827, 1034, 1083, 47,
	57, 65, 90, 97, 122, 9, 32, 40,
	41, 778, 827, 1034, 1083, 10, 48, 57,
	48, 57, 48, 57, 42, 46, 92, 95,
	45, 57, 65, 90, 97, 122, 9, 32,
	40, 41, 778, 827, 1034, 1083, 778, 1034,
	640, 895, 896, 1151, 9, 32, 40, 41,
	42, 46, 92, 95, 1034, 1083, 45, 57,
	65, 90, 97, 122, 1034, 896, 1151, 1034,
	896, 1151, 43, 47, 57, 65, 90, 97,
	122, 43, 47, 57, 65, 90, 97, 122,
	43, 61, 47, 57, 65, 90, 97, 122,
	43, 61, 47, 57, 65, 90, 97, 122,
	9, 32, 40, 41, 43, 2058, 2107, 2314,
	2363, 2570, 2619, 47, 57, 65, 90, 97,
	122, 1034, 896, 1151, 61, 9, 32, 40,
	41, 2058, 2107, 2314, 2363, 2570, 2619, 9,
	32, 40, 41, 65, 67, 68, 69, 72,
	73, 75, 76, 77, 78, 80, 82, 83,
	84, 85, 97, 99, 100, 101, 104, 105,
	107, 108, 109, 110, 112, 114, 115, 116,
	117, 2058, 2107, 2314, 2363, 2570, 2619, 9,
	32, 40, 41, 65, 70, 80, 97, 102,
	112, 2058, 2107, 2314, 2363, 2570, 2619, 65,
	97, 65, 97, 9, 32, 40, 41, 2058,
	2107, 2314, 2363, 2570, 2619, 1034, 896, 1151,
	65, 68, 69, 78, 97, 100, 101, 110,
	65, 97, 9, 32, 40, 41, 2058, 2107,
	2314, 2363, 2570, 2619, 78, 83, 110, 115,
	83, 115, 75, 107, 69, 101, 89, 121,
	9, 32, 40, 41, 2058, 2107, 2314, 2363,
	2570, 2619, 9, 32, 40, 41, 2058, 2107,
	2314, 2363, 2570, 2619, 82, 114, 84, 116,
	9, 32, 40, 41, 2058, 2107, 2314, 2363,
	2570, 2619, 65, 97, 77, 109, 69, 101,
	9, 32, 40, 41, 2058, 2107, 2314, 2363,
	2570, 2619, 72, 78, 83, 104, 110, 115,
	67, 99, 73, 105, 68, 100, 9, 32,
	40, 41, 2058, 2107, 2314, 2363, 2570, 2619,
	65, 83, 97, 115, 77, 109, 69, 101,
	9, 32, 40, 41, 2058, 2107, 2314, 2363,
	2570, 2619, 75, 107, 69, 101, 89, 121,
	9, 32, 40, 41, 2058, 2107, 2314, 2363,
	2570, 2619, 9, 32, 40, 41, 2058, 2107,
	2314, 2363, 2570, 2619, 85, 117, 73, 105,
	52, 54, 56, 9, 32, 40, 41, 2058,
	2107, 2314, 2363, 2570, 2619, 52, 9, 32,
	40, 41, 2058, 2107, 2314, 2363, 2570, 2619,
	73, 105, 78, 110, 70, 102, 79, 111,
	9, 32, 40, 41, 2058, 2107, 2314, 2363,
	2570, 2619, 80, 112, 83, 115, 69, 101,
	67, 99, 75, 107, 69, 101, 89, 121,
	9, 32, 40, 41, 2058, 2107, 2314, 2363,
	2570, 2619, 69, 88, 101, 120, 89, 121,
	9, 32, 40, 41, 2058, 2107, 2314, 2363,
	2570, 2619, 9, 32, 40, 41, 2058, 2107,
	2314, 2363, 2570, 2619, 51, 54, 79, 80,
	111, 112, 50, 9, 32, 40, 41, 2058,
	2107, 2314, 2363, 2570, 2619, 52, 9, 32,
	40, 41, 2058, 2107, 2314, 2363, 2570, 2619,
	67, 99, 9, 32, 40, 41, 2058, 2107,
	2314, 2363, 2570, 2619, 9, 32, 40, 41,
	2058, 2107, 2314, 2363, 2570, 2619, 73, 88,
	105, 120, 78, 110, 70, 102, 79, 111,
	9, 32, 40, 41, 2058, 2107, 2314, 2363,
	2570, 2619, 9, 32, 40, 41, 2058, 2107,
	2314, 2363, 2570, 2619, 65, 73, 83, 97,
	105, 115, 80, 112, 84, 116, 82, 114,
	9, 32, 40, 41, 2058, 2107, 2314, 2363,
	2570, 2619, 68, 100, 9, 32, 40, 41,
	2058, 2107, 2314, 2363, 2570, 2619, 9, 32,
	40, 41, 69, 101, 2058, 2107, 2314, 2363,
	2570, 2619, 67, 99, 9, 32, 40, 41,
	51, 2058, 2107, 2314, 2363, 2570, 2619, 9,
	32, 40, 41, 80, 112, 2058, 2107, 2314,
	2363, 2570, 2619, 65, 97, 82, 114, 65,
	97, 77, 109, 9, 32, 40, 41, 2058,
	2107, 2314, 2363, 2570, 2619, 84, 116, 82,
	114, 9, 32, 40, 41, 2058, 2107, 2314,
	2363, 2570, 2619, 80, 82, 84, 112, 114,
	116, 9, 32, 40, 41, 2058, 2107, 2314,
	2363, 2570, 2619, 83, 115, 73, 105, 71,
	103, 9, 32, 40, 41, 2058, 2107, 2314,
	2363, 2570, 2619, 9, 32, 40, 41, 2058,
	2107, 2314, 2363, 2570, 2619, 79, 80, 82,
	83, 111, 112, 114, 115, 65, 97, 9,
	32, 40, 41, 2058, 2107, 2314, 2363, 2570,
	2619, 70, 102, 9, 32, 40, 41, 2058,
	2107, 2314, 2363, 2570, 2619, 86, 118, 9,
	32, 40, 41, 2058, 2107, 2314, 2363, 2570,
	2619, 72, 104, 70, 102, 80, 112, 9,
	32, 40, 41, 2058, 2107, 2314, 2363, 2570,
	2619, 76, 88, 89, 108, 120, 121, 83,
	115, 65, 97, 9, 32, 40, 41, 2058,
	2107, 2314, 2363, 2570, 2619, 84, 116, 9,
	32, 40, 41, 2058, 2107, 2314, 2363, 2570,
	2619, 80, 112, 69, 101, 48, 57, 9,
	32, 40, 41, 2058, 2107, 2314, 2363, 2570,
	2619, 48, 57, 82, 114, 73, 105, 9,
	32, 40, 41, 2058, 2107, 2314, 2363, 2570,
	2619, 83, 115, 68, 100, 66, 98, 9,
	32, 40, 41, 2058, 2107, 2314, 2363, 2570,
	2619, 76, 108, 9, 32, 40, 41, 2058,
	2107, 2314, 2363, 2570, 2619, 9, 32, 40,
	41, 1034, 1083, 9, 32, 40, 41, 1034,
	1083, 48, 57, 9, 32, 40, 41, 1034,
	1083, 48, 57, 9, 32, 40, 41, 1034,
	1083, 48, 57, 65, 70, 97, 102, 48,
	57, 65, 70, 97, 102, 9, 32, 40,
	41, 2058, 2107, 2314, 2363, 2570, 2619, 48,
	57, 65, 70, 97, 102, 1034, 896, 1151,
	1034, 896, 1151, 1034, 896, 1151, 9, 32,
	40, 41, 1034, 1083, 9, 32, 40, 41,
	48, 1034, 1083, 49, 57, 9, 32, 40,
	41, 778, 827, 1034, 1083, 48, 57, 9,
	32, 40, 41, 1034, 1083, 48, 57, 65,
	70, 97, 102, 48, 57, 65, 70, 97,
	102, 9, 32, 40, 41, 2058, 2107, 2314,
	2363, 2570, 2619, 48, 57, 65, 70, 97,
	102, 1034, 896, 1151, 1034, 896, 1151, 9,
	32, 40, 41, 1034, 1083, 48, 57, 1034,
	896, 1151, 68, 69, 73, 80, 82, 100,
	101, 105, 112, 114, 48, 57, 32, 59,
	9, 10, 40, 41, 48, 57, 72, 83,
	104, 115, 32, 59, 9, 10, 40, 41,
	65, 97, 32, 45, 59, 9, 10, 40,
	41, 78, 110, 83, 115, 69, 101, 67,
	99, 51, 45, 83, 115, 72, 104, 65,
	97, 49, 32, 59, 9, 10, 40, 41,
	67, 68, 99, 100, 67, 68, 99, 100,
	45, 71, 103, 79, 111, 83, 115, 84,
	116, 32, 59, 9, 10, 40, 41, 83,
	115, 65, 97, 80, 112, 50, 51, 53,
	54, 83, 115, 72, 104, 65, 97, 50,
	53, 54, 32, 59, 9, 10, 40, 41,
	56, 52, 83, 115, 72, 104, 65, 97,
	51, 56, 52, 32, 59, 9, 10, 40,
	41, 50, 52, 53, 53, 49, 57, 32,
	59, 9, 10, 40, 41, 52, 56, 32,
	59, 9, 10, 40, 41, 78, 110, 68,
	100, 73, 105, 82, 114, 69, 101, 67,
	99, 84, 116, 32, 59, 9, 10, 40,
	41, 82, 114, 73, 105, 86, 118, 65,
	97, 84, 116, 69, 101, 68, 79, 100,
	111, 78, 110, 83, 115, 32, 59, 9,
	10, 40, 41, 73, 105, 68, 100, 32,
	59, 9, 10, 40, 41, 83, 115, 65,
	97, 77, 83, 109, 115, 68, 100, 53,
	32, 59, 9, 10, 40, 41, 72, 104,
	65, 97, 49, 50, 53, 32, 45, 59,
	9, 10, 40, 41, 78, 110, 83, 115,
	69, 101, 67, 99, 51, 45, 83, 115,
	72, 104, 65, 97, 49, 32, 59, 9,
	10, 40, 41, 53, 54, 32, 59, 9,
	10, 40, 41, 49, 50, 32, 59, 9,
	10, 40, 41, 65, 73, 79, 80, 83,
	85, 97, 105, 111, 112, 115, 117, 48,
	57, 32, 59, 9, 10, 40, 41, 48,
	57, 67, 99, 80, 112, 75, 107, 73,
	105, 88, 120, 32, 59, 9, 10, 40,
	41, 65, 80, 83, 97, 112, 115, 67,
	99, 80, 112, 75, 107, 73, 105, 88,
	120, 32, 59, 9, 10, 40, 41, 71,
	75, 103, 107, 80, 112, 32, 59, 9,
	10, 40, 41, 73, 105, 88, 120, 32,
	59, 9, 10, 40, 41, 80, 112, 75,
	107, 73, 105, 32, 59, 9, 10, 40,
	41, 73, 105, 68, 100, 32, 59, 9,
	10, 40, 41, 71, 75, 103, 107, 80,
	112, 32, 59, 9, 10, 40, 41, 73,
	105, 88, 120, 32, 59, 9, 10, 40,
	41, 80, 112, 75, 107, 73, 105, 32,
	59, 9, 10, 40, 41, 82, 114, 73,
	105, 32, 59, 9, 10, 40, 41, 46,
	48, 57, 32, 46, 59, 9, 10, 40,
	41, 48, 57, 42, 92, 95, 45, 57,
	64, 90, 97, 122, 32, 59, 9, 10,
	40, 41, 42, 92, 95, 45, 57, 64,
	90, 97, 122, 9, 32, 40, 41, 1034,
	1083, 9, 32, 40, 41, 42, 92, 95,
	1034, 1083, 45, 57, 64, 90, 97, 122,
	9, 32, 40, 41, 1034, 1083, 9, 32,
	40, 41, 1034, 1083, 48, 57, 9, 32,
	40, 41, 1034, 1083, 48, 57, 9, 32,
	40, 41, 1034, 1083, 48, 57, 9, 32,
	40, 41, 68, 72, 77, 83, 87, 100,
	104, 109, 115, 119, 1034, 1083, 48, 57,
	9, 32, 40, 41, 1034, 1083, 48, 57,
	9, 32, 40, 41, 68, 72, 77, 83,
	87, 100, 104, 109, 115, 119, 1034, 1083,
	48, 57, 9, 32, 40, 41, 1034, 1083,
	48, 57, 9, 32, 40, 41, 68, 72,
	77, 83, 87, 100, 104, 109, 115, 119,
	1034, 1083, 48, 57, 9, 32, 40, 41,
	1034, 1083, 48, 57, 32, 59, 68, 72,
	77, 83, 87, 100, 104, 109, 115, 119,
	9, 10, 40, 41, 48, 57, 32, 59,
	9, 10, 40, 41, 48, 57, 68, 72,
	77, 83, 87, 100, 104, 109, 115, 119,
	48, 57, 32, 59, 9, 10, 40, 41,
	48, 57, 1034, 896, 1151, 9, 32, 40,
	41, 1034, 1083, 48, 57, 68, 72, 77,
	83, 87, 100, 104, 109, 115, 119, 48,
	57, 9, 32, 40, 41, 1034, 1083, 48,
	57, 1034, 896, 1151, 9, 32, 40, 41,
	1034, 1083, 48, 57, 68, 72, 77, 83,
	87, 100, 104, 109, 115, 119, 48, 57,
	9, 32, 40, 41, 1034, 1083, 48, 57,
	1034, 896, 1151, 9, 32, 40, 41, 1034,
	1083, 48, 57, 68, 72, 77, 83, 87,
	100, 104, 109, 115, 119, 48, 57, 9,
	32, 40, 41, 1034, 1083, 48, 57, 1034,
	896, 1151, 1034, 896, 1151, 1034, 896, 1151,
	32, 59, 9, 10, 40, 41, 9, 32,
	40, 41, 1034, 1083, 9, 32, 40, 41,
	1034, 1083, -128, 8, 11, 58, 60, 127,
	32, 59, 9, 10, 40, 41, 1034, 896,
	1151, 42, 92, 95, 45, 57, 64, 90,
	97, 122, 9, 32, 40, 41, 1034, 1083,
	9, 32, 40, 41, 42, 92, 95, 1034,
	1083, 45, 57, 64, 90, 97, 122, 32,
	59, 9, 10, 40, 41, 1034, 896, 1151,
	48, 57, 9, 32, 40, 41, 1034, 1083,
	48, 57, 9, 32, 40, 41, 42, 92,
	95, 1034, 1083, 45, 57, 64, 90, 97,
	122, 32, 59, 9, 10, 40, 41, 1034,
	896, 1151, 32, 59, 9, 10, 40, 41,
	9, 32, 40, 41, 2058, 2107, 2314, 2363,
	2570, 2619, 9, 32, 40, 41, 2058, 2107,
	2314, 2363, 2570, 2619, -128, 8, 11, 58,
	60, 127, 1034, 896, 1151, 46, 48, 58,
	65, 70, 97, 102, 32, 46, 59, 9,
	10, 40, 41, 48, 58, 65, 70, 97,
	102, 48, 57, 9, 32, 40, 41, 1034,
	1083, 48, 57, 9, 32, 40, 41, 78,
	83, 1034, 1083, 48, 57, 9, 32, 40,
	41, 1034, 1083, 48, 57, 9, 32, 40,
	41, 78, 83, 1034, 1083, 48, 57, 9,
	32, 40, 41, 46, 1034, 1083, 48, 57,
	9, 32, 40, 41, 78, 83, 1034, 1083,
	9, 32, 40, 41, 1034, 1083, 9, 32,
	40, 41, 1034, 1083, 48, 57, 9, 32,
	40, 41, 1034, 1083, 48, 57, 9, 32,
	40, 41, 69, 87, 1034, 1083, 48, 57,
	9, 32, 40, 41, 1034, 1083, 48, 57,
	9, 32, 40, 41, 69, 87, 1034, 1083,
	48, 57, 9, 32, 40, 41, 46, 1034,
	1083, 48, 57, 9, 32, 40, 41, 69,
	87, 1034, 1083, 9, 32, 40, 41, 1034,
	1083, 9, 32, 40, 41, 45, 1034, 1083,
	48, 57, 48, 57, 9, 32, 40, 41,
	46, 109, 2058, 2107, 2314, 2363, 2570, 2619,
	48, 57, 9, 32, 40, 41, 2058, 2107,
	2314, 2363, 2570, 2619, 48, 57, 9, 32,
	40, 41, 46, 109, 2058, 2107, 2314, 2363,
	2570, 2619, 48, 57, 9, 32, 40, 41,
	2058, 2107, 2314, 2363, 2570, 2619, 48, 57,
	9, 32, 40, 41, 46, 109, 2058, 2107,
	2314, 2363, 2570, 2619, 48, 57, 9, 32,
	40, 41, 2058, 2107, 2314, 2363, 2570, 2619,
	48, 57, 9, 32, 40, 41, 46, 109,
	2058, 2107, 2314, 2363, 2570, 2619, 48, 57,
	9, 32, 40, 41, 2058, 2107, 2314, 2363,
	2570, 2619, 1034, 896, 1151, 9, 32, 40,
	41, 109, 2058, 2107, 2314, 2363, 2570, 2619,
	48, 57, 9, 32, 40, 41, 109, 2058,
	2107, 2314, 2363, 2570, 2619, 48, 57, 1034,
	896, 1151, 9, 32, 40, 41, 109, 2058,
	2107, 2314, 2363, 2570, 2619, 48, 57, 9,
	32, 40, 41, 109, 2058, 2107, 2314, 2363,
	2570, 2619, 48, 57, 9, 32, 40, 41,
	2058, 2107, 2314, 2363, 2570, 2619, 1034, 896,
	1151, 9, 32, 40, 41, 109, 2058, 2107,
	2314, 2363, 2570, 2619, 48, 57, 9, 32,
	40, 41, 109, 2058, 2107, 2314, 2363, 2570,
	2619, 48, 57, 9, 32, 40, 41, 2058,
	2107, 2314, 2363, 2570, 2619, 1034, 896, 1151,
	9, 32, 40, 41, 109, 2058, 2107, 2314,
	2363, 2570, 2619, 48, 57, 9, 32, 40,
	41, 109, 2058, 2107, 2314, 2363, 2570, 2619,
	48, 57, 9, 32, 40, 41, 2058, 2107,
	2314, 2363, 2570, 2619, 1034, 896, 1151, 9,
	32, 40, 41, 1034, 1083, 1034, 896, 1151,
	9, 32, 40, 41, 1034, 1083, 48, 57,
	9, 32, 40, 41, 1034, 1083, 48, 57,
	1034, 896, 1151, 1034, 896, 1151, 1034, 896,
	1151, 9, 32, 40, 41, 1034, 1083, 1034,
	896, 1151, 9, 32, 40, 41, 1034, 1083,
	48, 57, 9, 32, 40, 41, 1034, 1083,
	48, 57, 1034, 896, 1151, 1034, 896, 1151,
	48, 57, 9, 32, 40, 41, 1034, 1083,
	48, 57, 9, 32, 40, 41, 1034, 1083,
	48, 57, 9, 32, 40, 41, 1034, 1083,
	48, 57, 9, 32, 40, 41, 1034, 1083,
	48, 57, 9, 32, 40, 41, 1034, 1083,
	48, 57, 9, 32, 40, 41, 42, 92,
	95, 1034, 1083, 45, 57, 64, 90, 97,
	122, 32, 59, 9, 10, 40, 41, 1034,
	896, 1151, 1034, 896, 1151, 1034, 896, 1151,
	48, 57, 9, 32, 40, 41, 1034, 1083,
	48, 57, 9, 32, 40, 41, 1034, 1083,
	48, 57, 9, 32, 40, 41, 1034, 1083,
	48, 57, 9, 32, 40, 41, 1034, 1083,
	-128, 8, 11, 58, 60, 127, 9, 32,
	40, 41, 1034, 1083, 9, 32, 40, 41,
	1034, 1083, -128, 8, 11, 58, 60, 127,
	9, 32, 40, 41, 1034, 1083, 9, 32,
	40, 41, 1034, 1083, -128, 8, 11, 58,
	60, 127, 9, 32, 40, 41, 1034, 1083,
	9, 32, 40, 41, 42, 92, 95, 1034,
	1083, 45, 57, 64, 90, 97, 122, 32,
	59, 9, 10, 40, 41, 1034, 896, 1151,
	1034, 896, 1151, 1034, 896, 1151, 1034, 896,
	1151, 1034, 896, 1151, 48, 57, 65, 90,
	97, 122, 9, 32, 40, 41, 1034, 1083,
	9, 32, 40, 41, 1034, 1083, 48, 57,
	9, 32, 40, 41, 1034, 1083, 48, 57,
	9, 32, 40, 41, 1034, 1083, 48, 57,
	65, 90, 97, 122, 9, 32, 40, 41,
	1034, 1083, 9, 32, 40, 41, 43, 1034,
	1083, 47, 57, 65, 90, 97, 122, 1546,
	1595, 1034, 896, 1151, 1034, 896, 1151, 1034,
	896, 1151, 9, 32, 33, 40, 41, 49,
	50, 2058, 2107, 2314, 2363, 2570, 2619, 49,
	50, 58, 46, 48, 57, 47, 46, 57,
	48, 57, 9, 32, 40, 41, 2058, 2107,
	2314, 2363, 2570, 2619, 48, 57, 1034, 896,
	1151, 58, 46, 48, 58, 65, 70, 97,
	102, 47, 46, 58, 65, 70, 97, 102,
	48, 57, 9, 32, 40, 41, 1034, 1083,
	48, 57, 9, 32, 40, 41, 1034, 1083,
	48, 57, 65, 90, 97, 122, 9, 32,
	40, 41, 1034, 1083, 9, 32, 40, 41,
	1034, 1083, 48, 57, 9, 32, 40, 41,
	1034, 1083, 48, 57, 9, 32, 40, 41,
	1034, 1083, 48, 57, 65, 70, 97, 102,
	48, 57, 65, 70, 97, 102, 9, 32,
	40, 41, 2058, 2107, 2314, 2363, 2570, 2619,
	48, 57, 65, 70, 97, 102, 1034, 896,
	1151, 1034, 896, 1151, 1034, 896, 1151, 1034,
	896, 1151, 48, 57, 9, 32, 40, 41,
	1034, 1083, 48, 57, 9, 32, 40, 41,
	1034, 1083, 48, 57, 9, 32, 40, 41,
	1034, 1083, 48, 57, 9, 32, 40, 41,
	1034, 1083, 48, 57, 65, 70, 97, 102,
	48, 57, 65, 70, 97, 102, 9, 32,
	40, 41, 2058, 2107, 2314, 2363, 2570, 2619,
	48, 57, 65, 70, 97, 102, 1034, 896,
	1151, 1034, 896, 1151, 1034, 896, 1151, 48,
	57, 9, 32, 40, 41, 1034, 1083, 48,
	57, 9, 32, 40, 41, 48, 49, 50,
	51, 1034, 1083, 9, 32, 40, 41, 1034,
	1083, 9, 32, 40, 41, 1034, 1083, 48,
	57, 9, 32, 40, 41, 1034, 1083, 48,
	57, 9, 32, 40, 41, 46, 1034, 1083,
	6153, 6176, 6184, 6185, 6409, 6432, 6440, 6441,
	6665, 6688, 6696, 6697, 9482, 9531, 9738, 9787,
	10250, 10299, 10506, 10555, 10762, 10811, 11274, 11323,
	11530, 11579, 11786, 11835, 12298, 12347, 12554, 12603,
	12810, 12859, 3081, 3104, 3112, 3113, 3115, 4106,
	4155, 3119, 3129, 3137, 3162, 3169, 3194, 1546,
	1595, 4106, 3968, 4223, 4617, 4640, 4648, 4649,
	13578, 13627, 13834, 13883, 14346, 14395, 14602, 14651,
	14858, 14907, 5642, 5504, 5759, 3115, 6153, 6176,
	6184, 6185, 6409, 6432, 6440, 6441, 6665, 6688,
	6696, 6697, 9482, 9531, 9738, 9787, 10250, 10299,
	10506, 10555, 10762, 10811, 11274, 11323, 11530, 11579,
	11786, 11835, 12298, 12347, 12554, 12603, 12810, 12859,
	3119, 3129, 3137, 3162, 3169, 3194, 7690, 8202,
	8714, 7552, 7807, 8064, 8319, 8576, 8831, 1034,
	896, 1151, 1034, 896, 1151, 9, 32, 40,
	41, 1034, 1083, 9, 32, 40, 41, 1034,
	1083, 48, 57, 9, 32, 40, 41, 1034,
	1083, 48, 57, 9, 32, 40, 41, 46,
	1034, 1083, 48, 57, 46, 6153, 6176, 6184,
	6185, 6409, 6432, 6440, 6441, 6665, 6688, 6696,
	6697, 9482, 9531, 9738, 9787, 10250, 10299, 10506,
	10555, 10762, 10811, 11274, 11323, 11530, 11579, 11786,
	11835, 12298, 12347, 12554, 12603, 12810, 12859, 48,
	57, 1034, 896, 1151, 1034, 896, 1151, 9,
	32, 40, 41, 1034, 1083, 9, 32, 40,
	41, 1034, 1083, 48, 57, 9, 32, 40,
	41, 1034, 1083, 48, 57, 9, 32, 40,
	41, 46, 1034, 1083, 48, 58, 65, 70,
	97, 102, 46, 6153, 6176, 6184, 6185, 6409,
	6432, 6440, 6441, 6665, 6688, 6696, 6697, 9482,
	9531, 9738, 9787, 10250, 10299, 10506, 10555, 10762,
	10811, 11274, 11323, 11530, 11579, 11786, 11835, 12298,
	12347, 12554, 12603, 12810, 12859, 48, 58, 65,
	70, 97, 102, 1034, 896, 1151, 1034, 896,
	1151, 9, 32, 40, 41, 1034, 1083, 9,
	32, 40, 41, 1034, 1083, 48, 57, 9,
	32, 40, 41, 1034, 1083, 48, 57, 9,
	32, 40, 41, 42, 92, 95, 1034, 1083,
	45, 57, 64, 90, 97, 122, 6153, 6176,
	6184, 6185, 6409, 6432, 6440, 6441, 6665, 6688,
	6696, 6697, 9482, 9531, 9738, 9787, 10250, 10299,
	10506, 10555, 10762, 10811, 11274, 11323, 11530, 11579,
	11786, 11835, 12298, 12347, 12554, 12603, 12810, 12859,
	1034, 896, 1151, 1034, 896, 1151, 1034, 896,
	1151, 65, 67, 68, 69, 72, 73, 75,
	76, 77, 78, 80, 82, 83, 84, 85,
	97, 99, 100, 101, 104, 105, 107, 108,
	109, 110, 112, 114, 115, 116, 117, 9,
	32, 40, 41, 65, 70, 80, 97, 102,
	112, 1034, 1083, 9, 32, 40, 41, 1034,
	1083, 48, 57, 65, 90, 97, 122, 9,
	32, 40, 41, 1034, 1083, 9, 32, 40,
	41, 1034, 1083, 48, 57, 9, 32, 40,
	41, 1034, 1083, 48, 57, 9, 32, 40,
	41, 1034, 1083, 48, 57, 9, 32, 40,
	41, 1034, 1083, 48, 57, 9, 32, 40,
	41, 1034, 1083, 48, 57, 9, 32, 40,
	41, 1034, 1083, 48, 57, 9, 32, 40,
	41, 1034, 1083, 48, 57, 9, 32, 40,
	41, 1034, 1083, 48, 57, 9, 32, 40,
	41, 1034, 1083, 48, 57, 9, 32, 40,
	41, 1034, 1083, 48, 57, 9, 32, 40,
	41, 42, 92, 95, 1034, 1083, 45, 57,
	64, 90, 97, 122, 9, 32, 40, 41,
	1034, 1083, 9, 32, 40, 41, 43, 1034,
	1083, 47, 57, 65, 90, 97, 122, 1546,
	1595, 1034, 896, 1151, 1034, 896, 1151, 1034,
	896, 1151, 1034, 896, 1151, 1034, 896, 1151,
	1034, 896, 1151, 1034, 896, 1151, 1034, 896,
	1151, 65, 97, 65, 97, 9, 32, 40,
	41, 1034, 1083, 83, 115, 68, 100, 66,
	98, 9, 32, 40, 41, 1034, 1083, 76,
	108, 9, 32, 40, 41, 1034, 1083, 65,
	68, 69, 78, 97, 100, 101, 110, 65,
	97, 9, 32, 40, 41, 1034, 1083, 78,
	83, 110, 115, 83, 115, 75, 107, 69,
	101, 89, 121, 9, 32, 40, 41, 1034,
	1083, 9, 32, 40, 41, 1034, 1083, 82,
	114, 84, 116, 9, 32, 40, 41, 1034,
	1083, 65, 97, 77, 109, 69, 101, 9,
	32, 40, 41, 1034, 1083, 72, 78, 83,
	104, 110, 115, 67, 99, 73, 105, 68,
	100, 9, 32, 40, 41, 1034, 1083, 65,
	83, 97, 115, 77, 109, 69, 101, 9,
	32, 40, 41, 1034, 1083, 75, 107, 69,
	101, 89, 121, 9, 32, 40, 41, 1034,
	1083, 9, 32, 40, 41, 1034, 1083, 85,
	117, 73, 105, 52, 54, 56, 9, 32,
	40, 41, 1034, 1083, 52, 9, 32, 40,
	41, 1034, 1083, 73, 105, 78, 110, 70,
	102, 79, 111, 9, 32, 40, 41, 1034,
	1083, 80, 112, 83, 115, 69, 101, 67,
	99, 75, 107, 69, 101, 89, 121, 9,
	32, 40, 41, 1034, 1083, 69, 88, 101,
	120, 89, 121, 9, 32, 40, 41, 1034,
	1083, 9, 32, 40, 41, 1034, 1083, 51,
	54, 79, 80, 111, 112, 50, 9, 32,
	40, 41, 1034, 1083, 52, 9, 32, 40,
	41, 1034, 1083, 67, 99, 9, 32, 40,
	41, 1034, 1083, 9, 32, 40, 41, 1034,
	1083, 73, 88, 105, 120, 78, 110, 70,
	102, 79, 111, 9, 32, 40, 41, 1034,
	1083, 9, 32, 40, 41, 1034, 1083, 65,
	73, 83, 97, 105, 115, 80, 112, 84,
	116, 82, 114, 9, 32, 40, 41, 1034,
	1083, 68, 100, 9, 32, 40, 41, 1034,
	1083, 9, 32, 40, 41, 69, 101, 1034,
	1083, 67, 99, 9, 32, 40, 41, 51,
	1034, 1083, 9, 32, 40, 41, 80, 112,
	1034, 1083, 65, 97, 82, 114, 65, 97,
	77, 109, 9, 32, 40, 41, 1034, 1083,
	84, 116, 82, 114, 9, 32, 40, 41,
	1034, 1083, 80, 82, 84, 112, 114, 116,
	9, 32, 40, 41, 1034, 1083, 83, 115,
	73, 105, 71, 103, 9, 32, 40, 41,
	1034, 1083, 9, 32, 40, 41, 1034, 1083,
	79, 80, 82, 83, 111, 112, 114, 115,
	65, 97, 9, 32, 40, 41, 1034, 1083,
	70, 102, 9, 32, 40, 41, 1034, 1083,
	86, 118, 9, 32, 40, 41, 1034, 1083,
	72, 104, 70, 102, 80, 112, 9, 32,
	40, 41, 1034, 1083, 76, 88, 89, 108,
	120, 121, 83, 115, 65, 97, 9, 32,
	40, 41, 1034, 1083, 84, 116, 9, 32,
	40, 41, 1034, 1083, 80, 112, 69, 101,
	48, 57, 9, 32, 40, 41, 1034, 1083,
	48, 57, 82, 114, 73, 105, 9, 32,
	40, 41, 1034, 1083, 42, 92, 95, 45,
	57, 64, 90, 97, 122, 32, 59, 9,
	10, 40, 41, 32, 59, 9, 10, 40,
	41, 48, 57, 9, 32, 40, 41, 1034,
	1083, 48, 57, 9, 32, 40, 41, 1034,
	1083, 48, 57, 9, 32, 40, 41, 1034,
	1083, 48, 57, 9, 32, 40, 41, 1034,
	1083, 48, 57, 65, 90, 97, 122, 9,
	32, 40, 41, 1034, 1083, 9, 32, 40,
	41, 43, 1034, 1083, 47, 57, 65, 90,
	97, 122, 1546, 1595, 1034, 896, 1151, 1034,
	896, 1151, 1034, 896, 1151, 43, 47, 57,
	65, 90, 97, 122, 1546, 1595, 48, 57,
	9, 32, 40, 41, 1034, 1083, 48, 57,
	9, 32, 40, 41, 1034, 1083, 48, 57,
	9, 32, 40, 41, 1034, 1083, 48, 57,
	9, 32, 40, 41, 1034, 1083, 48, 57,
	9, 32, 40, 41, 1034, 1083, 48, 57,
	9, 32, 40, 41, 45, 1034, 1083, 48,
	57, 65, 70, 97, 102, 9, 32, 40,
	41, 1034, 1083, 9, 32, 40, 41, 1034,
	1083, 48, 57, 65, 86, 97, 118, 48,
	57, 65, 86, 97, 118, 61, 48, 57,
	65, 86, 97, 118, 48, 57, 65, 86,
	97, 118, 61, 48, 57, 65, 86, 97,
	118, 61, 48, 57, 65, 86, 97, 118,
	48, 57, 65, 86, 97, 118, 61, 48,
	57, 65, 86, 97, 118, 32, 59, 9,
	10, 40, 41, 48, 57, 65, 86, 97,
	118, 32, 59, 9, 10, 40, 41, 61,
	61, 61, 61, 61, 1034, 896, 1151, 48,
	57, 65, 70, 97, 102, 9, 32, 40,
	41, 1034, 1083, 48, 57, 65, 70, 97,
	102, 1034, 896, 1151, 1034, 896, 1151, 1034,
	896, 1151, 48, 57, 9, 32, 40, 41,
	1034, 1083, 48, 57, 9, 32, 40, 41,
	1034, 1083, 48, 57, 9, 32, 40, 41,
	1034, 1083, 48, 57, 9, 32, 40, 41,
	1034, 1083, 48, 57, 9, 32, 40, 41,
	1034, 1083, 48, 57, 9, 32, 40, 41,
	45, 1034, 1083, 48, 57, 65, 70, 97,
	102, 32, 59, 9, 10, 40, 41, 48,
	57, 65, 70, 97, 102, 32, 59, 9,
	10, 40, 41, 48, 57, 65, 70, 97,
	102, 1034, 896, 1151, 1034, 896, 1151, 1034,
	896, 1151, 48, 57, 9, 32, 40, 41,
	1034, 1083, 48, 57, 9, 32, 40, 41,
	1034, 1083, 48, 57, 9, 32, 40, 41,
	1034, 1083, 48, 57, 9, 32, 40, 41,
	1034, 1083, 48, 57, 9, 32, 40, 41,
	1034, 1083, 48, 57, 9, 32, 40, 41,
	1034, 1083, 48, 57, 65, 70, 97, 102,
	48, 57, 65, 70, 97, 102, 9, 32,
	40, 41, 2058, 2107, 2314, 2363, 2570, 2619,
	48, 57, 65, 70, 97, 102, 1034, 896,
	1151, 1034, 896, 1151, 1034, 896, 1151, 1034,
	896, 1151, 48, 57, 9, 32, 40, 41,
	1034, 1083, 48, 57, 9, 32, 40, 41,
	46, 1034, 1083, 48, 57, 32, 46, 59,
	9, 10, 40, 41, 48, 57, 1034, 896,
	1151, 48, 57, 9, 32, 40, 41, 1034,
	1083, 48, 57, 9, 32, 40, 41, 1034,
	1083, 48, 57, 65, 70, 97, 102, 48,
	57, 65, 70, 97, 102, 48, 57, 65,
	70, 97, 102, 48, 57, 65, 70, 97,
	102, 58, 48, 57, 65, 70, 97, 102,
	48, 57, 65, 70, 97, 102, 48, 57,
	65, 70, 97, 102, 48, 57, 65, 70,
	97, 102, 32, 58, 59, 9, 10, 40,
	41, 1034, 896, 1151, 48, 57, 65, 70,
	97, 102, 48, 57, 65, 70, 97, 102,
	45, 48, 57, 65, 70, 97, 102, 48,
	57, 65, 70, 97, 102, 32, 45, 59,
	9, 10, 40, 41, 48, 57, 65, 70,
	97, 102, 48, 57, 65, 70, 97, 102,
	45, 48, 57, 65, 70, 97, 102, 48,
	57, 65, 70, 97, 102, 32, 45, 59,
	9, 10, 40, 41, 48, 57, 9, 32,
	40, 41, 1034, 1083, 48, 57, 9, 32,
	40, 41, 1034, 1083, 48, 57, 9, 32,
	40, 41, 1034, 1083, 48, 57, 9, 32,
	40, 41, 1034, 1083, -128, 8, 11, 58,
	60, 127, 32, 59, 9, 10, 40, 41,
	1034, 896, 1151, 1034, 896, 1151, 48, 57,
	9, 32, 40, 41, 1034, 1083, 48, 57,
	9, 32, 40, 41, 1034, 1083, -128, 8,
	11, 58, 60, 127, 9, 32, 40, 41,
	1034, 1083, 9, 32, 40, 41, 1034, 1083,
	-128, 8, 11, 58, 60, 127, 32, 59,
	9, 10, 40, 41, 1034, 896, 1151, 1034,
	896, 1151, 9, 32, 36, 40, 41, 42,
	92, 95, 778, 827, 1034, 1083, 45, 57,
	64, 90, 97, 122, 9, 32, 36, 40,
	41, 42, 58, 92, 95, 1802, 1851, 2058,
	2107, 2314, 2363, 2570, 2619, -128, 8, 11,
	44, 45, 57, 60, 63, 64, 90, 91,
	96, 97, 122, 123, 127, 9, 32, 36,
	40, 41, 42, 65, 67, 68, 69, 72,
	73, 75, 76, 77, 78, 80, 82, 83,
	84, 85, 92, 95, 97, 99, 100, 101,
	104, 105, 107, 108, 109, 110, 112, 114,
	115, 116, 117, 778, 827, 1034, 1083, 45,
	57, 64, 90, 98, 122, 9, 32, 36,
	40, 41, 42, 65, 67, 68, 69, 72,
	73, 75, 76, 77, 78, 80, 82, 83,
	84, 85, 92, 95, 97, 99, 100, 101,
	104, 105, 107, 108, 109, 110, 112, 114,
	115, 116, 117, 778, 827, 1034, 1083, 45,
	47, 48, 57, 64, 90, 98, 122, 9,
	32, 36, 40, 41, 42, 92, 95, 778,
	827, 1034, 1083, 45, 57, 64, 90, 97,
	122, 9, 32, 36, 40, 41, 42, 65,
	67, 68, 69, 72, 73, 75, 76, 77,
	78, 80, 82, 83, 84, 85, 92, 95,
	97, 99, 100, 101, 104, 105, 107, 108,
	109, 110, 112, 114, 115, 116, 117, 778,
	827, 1034, 1083, 45, 47, 48, 57, 64,
	90, 98, 122, 9, 32, 36, 40, 41,
	42, 92, 95, 778, 827, 1034, 1083, 45,
	57, 64, 90, 97, 122, 9, 32, 36,
	40, 41, 42, 58, 92, 95, 1802, 1851,
	2058, 2107, 2314, 2363, 2570, 2619, -128, 8,
	11, 44, 45, 57, 60, 63, 64, 90,
	91, 96, 97, 122, 123, 127, 9, 32,
	36, 40, 41, 42, 58, 65, 67, 68,
	69, 72, 73, 75, 76, 77, 78, 80,
	82, 83, 84, 85, 92, 95, 97, 99,
	100, 101, 104, 105, 107, 108, 109, 110,
	112, 114, 115, 116, 117, 1802, 1851, 2058,
	2107, 2314, 2363, 2570, 2619, -128, 8, 11,
	44, 45, 47, 48, 57, 60, 63, 64,
	90, 91, 96, 98, 122, 123, 127, 9,
	32, 36, 40, 41, 42, 58, 65, 67,
	68, 69, 72, 73, 75, 76, 77, 78,
	80, 82, 83, 84, 85, 92, 95, 97,
	99, 100, 101, 104, 105, 107, 108, 109,
	110, 112, 114, 115, 116, 117, 1802, 1851,
	2058, 2107, 2314, 2363, 2570, 2619, -128, 8,
	11, 44, 45, 47, 48, 57, 60, 63,
	64, 90, 91, 96, 98, 122, 123, 127,
	32, 33, 59, 92, 9, 10, 35, 39,
	40, 41, 42, 126, 9, 32, 40, 41,
	42, 46, 92, 95, 1034, 1083, 45, 57,
	65, 90, 97, 122, 9, 32, 40, 41,
	43, 2058, 2107, 2314, 2363, 2570, 2619, 47,
	57, 65, 90, 97, 122, 1034, 896, 1151,
	9, 32, 40, 41, 65, 67, 68, 69,
	72, 73, 75, 76, 77, 78, 80, 82,
	83, 84, 85, 97, 99, 100, 101, 104,
	105, 107, 108, 109, 110, 112, 114, 115,
	116, 117, 2058, 2107, 2314, 2363, 2570, 2619,
	1034, 896, 1151, 9, 32, 40, 41, 2058,
	2107, 2314, 2363, 2570, 2619, 48, 57, 65,
	70, 97, 102, 1034, 896, 1151, 9, 32,
	40, 41, 1034, 1083, 48, 57, 65, 70,
	97, 102, 9, 32, 40, 41, 2058, 2107,
	2314, 2363, 2570, 2619, 48, 57, 65, 70,
	97, 102, 1034, 896, 1151, 1034, 896, 1151,
	9, 32, 40, 41, 2058, 2107, 2314, 2363,
	2570, 2619, -128, 8, 11, 58, 60, 127,
	1034, 896, 1151, 9, 32, 40, 41, 2058,
	2107, 2314, 2363, 2570, 2619, 1034, 896, 1151,
	9, 32, 40, 41, 2058, 2107, 2314, 2363,
	2570, 2619, 48, 57, 1034, 896, 1151, 9,
	32, 40, 41, 2058, 2107, 2314, 2363, 2570,
	2619, 48, 57, 1034, 896, 1151, 9, 32,
	40, 41, 2058, 2107, 2314, 2363, 2570, 2619,
	48, 57, 1034, 896, 1151, 9, 32, 33,
	40, 41, 49, 50, 2058, 2107, 2314, 2363,
	2570, 2619, 1034, 896, 1151, 9, 32, 40,
	41, 2058, 2107, 2314, 2363, 2570, 2619, 48,
	57, 65, 70, 97, 102, 1034, 896, 1151,
	9, 32, 40, 41, 2058, 2107, 2314, 2363,
	2570, 2619, 48, 57, 65, 70, 97, 102,
	1034, 896, 1151, 4617, 4640, 4648, 4649, 13578,
	13627, 13834, 13883, 14346, 14395, 14602, 14651, 14858,
	14907, 5642, 5504, 5759, 3081, 3104, 3112, 3113,
	3115, 4106, 4155, 3119, 3129, 3137, 3162, 3169,
	3194, 4106, 3968, 4223, 3115, 6153, 6176, 6184,
	6185, 6409, 6432, 6440, 6441, 6665, 6688, 6696,
	6697, 9482, 9531, 9738, 9787, 10250, 10299, 10506,
	10555, 10762, 10811, 11274, 11323, 11530, 11579, 11786,
	11835, 12298, 12347, 12554, 12603, 12810, 12859, 3119,
	3129, 3137, 3162, 3169, 3194, 7690, 8202, 8714,
	7552, 7807, 8064, 8319, 8576, 8831, 9, 32,
	40, 41, 2058, 2107, 2314, 2363, 2570, 2619,
	48, 57, 65, 70, 97, 102, 1034, 896,
	1151, 0
};

static const char _zone_scanner_single_lengths[] = {
	0, 38, 16, 36, 16, 11, 8, 8,
	1, 1, 1, 13, 13, 2, 44, 18,
	38, 8, 2, 10, 12, 12, 4, 2,
	2, 2, 2, 10, 10, 2, 2, 10,
	2, 2, 2, 10, 6, 2, 2, 2,
	10, 4, 2, 2, 10, 2, 2, 2,
	10, 10, 2, 2, 2, 1, 10, 1,
	10, 2, 2, 2, 2, 10, 4, 6,
	36, 2, 2, 2, 2, 2, 2, 2,
	10, 4, 2, 10, 10, 6, 1, 10,
	1, 10, 2, 10, 10, 4, 2, 2,
	2, 10, 10, 6, 2, 2, 2, 10,
	2, 10, 12, 2, 11, 12, 2, 2,
	2, 2, 10, 2, 2, 10, 6, 10,
	2, 2, 2, 10, 10, 8, 2, 10,
	2, 10, 2, 10, 2, 2, 2, 10,
	6, 2, 2, 10, 2, 10, 2, 2,
	0, 10, 2, 2, 10, 1, 38, 4,
	6, 36, 16, 6, 10, 6, 1, 1,
	6, 2, 2, 2, 2, 2, 2, 2,
	6, 36, 1, 16, 36, 1, 6, 10,
	6, 1, 16, 42, 18, 13, 38, 2,
	8, 8, 44, 16, 14, 10, 10, 12,
	12, 14, 12, 14, 10, 14, 16, 14,
	10, 2, 14, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 8, 18, 38, 2,
	18, 44, 16, 14, 10, 10, 12, 12,
	14, 12, 14, 10, 14, 16, 14, 10,
	9, 38, 12, 12, 12, 10, 2, 2,
	10, 2, 2, 2, 10, 2, 10, 2,
	8, 8, 12, 12, 12, 10, 1, 44,
	12, 12, 14, 12, 8, 8, 10, 10,
	12, 10, 12, 8, 12, 14, 12, 8,
	2, 2, 10, 2, 1, 1, 5, 6,
	6, 0, 0, 0, 6, 2, 2, 2,
	4, 0, 0, 0, 4, 4, 2, 0,
	0, 0, 4, 6, 6, 18, 8, 1,
	8, 10, 8, 1, 6, 10, 4, 12,
	8, 1, 0, 0, 0, 4, 8, 1,
	6, 6, 8, 12, 4, 12, 8, 1,
	0, 0, 0, 4, 8, 2, 10, 1,
	1, 1, 1, 2, 2, 11, 1, 1,
	10, 40, 16, 2, 2, 10, 1, 8,
	2, 10, 4, 2, 2, 2, 2, 10,
	10, 2, 2, 10, 2, 2, 2, 10,
	6, 2, 2, 2, 10, 4, 2, 2,
	10, 2, 2, 2, 10, 10, 2, 2,
	2, 1, 10, 1, 10, 2, 2, 2,
	2, 10, 2, 2, 2, 2, 2, 2,
	2, 10, 4, 2, 10, 10, 6, 1,
	10, 1, 10, 2, 10, 10, 4, 2,
	2, 2, 10, 10, 6, 2, 2, 2,
	10, 2, 10, 12, 2, 11, 12, 2,
	2, 2, 2, 10, 2, 2, 10, 6,
	10, 2, 2, 2, 10, 10, 8, 2,
	10, 2, 10, 2, 10, 2, 2, 2,
	10, 6, 2, 2, 10, 2, 10, 2,
	2, 0, 10, 2, 2, 10, 2, 2,
	2, 10, 2, 10, 6, 6, 6, 6,
	0, 10, 1, 1, 1, 6, 7, 8,
	6, 0, 10, 1, 1, 6, 1, 10,
	2, 4, 2, 2, 3, 2, 2, 2,
	2, 1, 1, 2, 2, 2, 1, 2,
	4, 4, 1, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 1, 1, 2, 2,
	2, 1, 1, 1, 2, 1, 1, 2,
	2, 2, 1, 1, 1, 2, 2, 1,
	1, 1, 1, 2, 1, 1, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 4, 2, 2,
	2, 2, 2, 2, 2, 2, 4, 2,
	1, 2, 2, 2, 3, 3, 2, 2,
	2, 2, 1, 1, 2, 2, 2, 1,
	2, 1, 1, 2, 1, 1, 2, 12,
	2, 2, 2, 2, 2, 2, 2, 6,
	2, 2, 2, 2, 2, 2, 4, 2,
	2, 2, 2, 2, 2, 2, 2, 2,
	2, 2, 2, 4, 2, 2, 2, 2,
	2, 2, 2, 2, 2, 2, 2, 2,
	1, 3, 3, 2, 3, 6, 9, 6,
	6, 6, 6, 16, 6, 16, 6, 16,
	6, 12, 2, 10, 2, 1, 6, 10,
	6, 1, 6, 10, 6, 1, 6, 10,
	6, 1, 1, 1, 2, 6, 6, 2,
	1, 3, 6, 9, 2, 1, 0, 6,
	9, 2, 1, 2, 10, 10, 1, 1,
	3, 0, 6, 8, 6, 8, 7, 8,
	6, 6, 6, 8, 6, 8, 7, 8,
	6, 7, 0, 12, 10, 12, 10, 12,
	10, 12, 10, 1, 11, 11, 1, 11,
	11, 10, 1, 11, 11, 10, 1, 11,
	11, 10, 1, 6, 1, 6, 6, 1,
	1, 1, 6, 1, 6, 6, 1, 1,
	0, 6, 6, 6, 6, 6, 9, 2,
	1, 1, 1, 0, 6, 6, 6, 6,
	6, 6, 6, 6, 6, 9, 2, 1,
	1, 1, 1, 1, 0, 6, 6, 6,
	6, 6, 7, 2, 1, 1, 1, 13,
	2, 1, 1, 1, 0, 10, 1, 1,
	1, 1, 0, 6, 6, 6, 6, 6,
	6, 0, 10, 1, 1, 1, 1, 0,
	6, 6, 6, 6, 0, 10, 1, 1,
	1, 0, 6, 10, 6, 6, 6, 7,
	34, 7, 2, 1, 14, 1, 35, 3,
	1, 1, 6, 6, 6, 7, 35, 1,
	1, 6, 6, 6, 7, 35, 1, 1,
	6, 6, 6, 9, 34, 1, 1, 1,
	30, 12, 6, 6, 6, 6, 6, 6,
	6, 6, 6, 6, 6, 6, 9, 6,
	7, 2, 1, 1, 1, 1, 1, 1,
	1, 1, 2, 2, 6, 2, 2, 2,
	6, 2, 6, 8, 2, 6, 4, 2,
	2, 2, 2, 6, 6, 2, 2, 6,
	2, 2, 2, 6, 6, 2, 2, 2,
	6, 4, 2, 2, 6, 2, 2, 2,
	6, 6, 2, 2, 2, 1, 6, 1,
	6, 2, 2, 2, 2, 6, 2, 2,
	2, 2, 2, 2, 2, 6, 4, 2,
	6, 6, 6, 1, 6, 1, 6, 2,
	6, 6, 4, 2, 2, 2, 6, 6,
	6, 2, 2, 2, 6, 2, 6, 8,
	2, 7, 8, 2, 2, 2, 2, 6,
	2, 2, 6, 6, 6, 2, 2, 2,
	6, 6, 8, 2, 6, 2, 6, 2,
	6, 2, 2, 2, 6, 6, 2, 2,
	6, 2, 6, 2, 2, 0, 6, 2,
	2, 6, 3, 2, 2, 0, 6, 6,
	6, 6, 6, 7, 2, 1, 1, 1,
	1, 2, 0, 6, 6, 6, 6, 6,
	7, 6, 6, 0, 1, 0, 1, 1,
	0, 1, 2, 2, 1, 1, 1, 1,
	1, 1, 0, 6, 1, 1, 1, 0,
	6, 6, 6, 6, 6, 7, 2, 0,
	2, 1, 1, 1, 0, 6, 6, 6,
	6, 6, 6, 0, 10, 1, 1, 1,
	1, 0, 6, 7, 3, 1, 0, 6,
	6, 0, 0, 0, 1, 0, 0, 0,
	0, 3, 1, 0, 0, 1, 0, 0,
	3, 0, 0, 1, 0, 0, 3, 0,
	6, 6, 6, 6, 2, 1, 1, 0,
	6, 6, 6, 6, 2, 1, 1, 12,
	17, 42, 42, 12, 42, 12, 17, 47,
	47, 0, 0, 0, 4, 0, 0, 0,
	10, 0, 11, 1, 0, 40, 1, 0,
	10, 1, 6, 0, 10, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	10, 1, 0, 0, 10, 1, 10, 1,
	10, 1, 10, 1, 0, 0, 0, 0,
	13, 1, 0, 10, 1, 0, 10, 1,
	0, 14, 1, 7, 1, 35, 3, 0,
	0, 0, 0, 0, 0, 0, 10, 1,
	0, 0, 0, 0, 0, 0
};

static const char _zone_scanner_range_lengths[] = {
	0, 1, 1, 0, 0, 3, 0, 0,
	0, 0, 1, 3, 3, 2, 4, 1,
	0, 0, 0, 0, 1, 1, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	1, 1, 0, 0, 0, 1, 1, 0,
	0, 1, 1, 1, 1, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0, 2,
	0, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 0, 4, 0, 3, 1, 2,
	3, 3, 4, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 2, 0, 0, 0, 0, 0, 0,
	2, 0, 0, 2, 0, 1, 1, 2,
	0, 4, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	3, 1, 1, 1, 2, 2, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 2,
	3, 3, 2, 2, 2, 2, 1, 4,
	1, 1, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	2, 2, 0, 2, 0, 0, 3, 5,
	5, 1, 1, 1, 5, 2, 2, 2,
	4, 3, 1, 1, 4, 1, 2, 3,
	1, 1, 1, 0, 1, 1, 0, 0,
	1, 1, 1, 1, 0, 3, 3, 3,
	0, 0, 1, 1, 1, 3, 0, 1,
	0, 3, 0, 3, 3, 3, 0, 0,
	1, 1, 1, 3, 0, 2, 3, 1,
	1, 3, 3, 3, 3, 3, 1, 0,
	0, 0, 0, 0, 0, 0, 1, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 1, 1, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 1, 1, 3,
	3, 3, 1, 1, 1, 0, 1, 1,
	3, 3, 3, 1, 1, 1, 1, 1,
	3, 0, 2, 0, 2, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 2,
	0, 0, 0, 0, 0, 0, 0, 2,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 2, 0, 0, 0,
	0, 0, 0, 0, 0, 2, 0, 0,
	0, 0, 0, 2, 0, 0, 2, 0,
	0, 0, 0, 0, 0, 0, 2, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	2, 0, 0, 2, 0, 0, 0, 0,
	0, 2, 0, 0, 0, 2, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	2, 0, 0, 2, 0, 0, 2, 1,
	3, 0, 0, 0, 0, 0, 2, 0,
	0, 0, 0, 0, 0, 2, 0, 0,
	2, 0, 0, 2, 0, 0, 0, 2,
	0, 0, 2, 0, 0, 2, 0, 0,
	2, 0, 0, 0, 2, 0, 0, 2,
	1, 3, 3, 2, 3, 0, 3, 0,
	1, 1, 1, 1, 1, 1, 1, 1,
	1, 3, 3, 1, 3, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 2, 0, 3, 2,
	1, 3, 0, 3, 2, 1, 1, 1,
	3, 2, 1, 2, 0, 3, 1, 3,
	5, 1, 1, 1, 1, 1, 1, 0,
	0, 1, 1, 1, 1, 1, 1, 0,
	0, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 0, 1, 1, 1, 1, 1,
	1, 0, 1, 1, 1, 0, 1, 1,
	1, 0, 1, 0, 1, 1, 1, 1,
	1, 1, 0, 1, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 3, 2,
	1, 1, 1, 1, 1, 1, 1, 3,
	0, 3, 0, 3, 0, 3, 2, 1,
	1, 1, 1, 1, 3, 0, 1, 1,
	3, 0, 3, 0, 1, 1, 1, 0,
	0, 0, 1, 1, 1, 1, 1, 0,
	3, 3, 1, 1, 3, 0, 1, 1,
	3, 3, 3, 1, 1, 1, 1, 1,
	1, 1, 1, 3, 3, 3, 1, 1,
	1, 1, 1, 0, 0, 1, 1, 0,
	0, 3, 0, 1, 0, 1, 3, 3,
	1, 1, 0, 1, 1, 1, 1, 1,
	1, 0, 1, 1, 3, 3, 1, 1,
	0, 1, 1, 3, 0, 1, 1, 1,
	0, 0, 3, 0, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 1, 3, 0,
	3, 0, 1, 1, 1, 1, 1, 1,
	1, 1, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 1, 1, 0,
	0, 0, 3, 2, 2, 1, 1, 1,
	1, 3, 0, 3, 0, 1, 1, 1,
	3, 0, 1, 1, 1, 1, 1, 1,
	3, 0, 3, 3, 3, 3, 3, 3,
	3, 3, 5, 2, 0, 0, 0, 0,
	0, 1, 3, 3, 1, 1, 1, 1,
	1, 1, 1, 1, 1, 3, 2, 3,
	5, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 3, 3, 3, 1, 1, 1,
	1, 1, 1, 1, 3, 1, 1, 1,
	3, 3, 3, 3, 0, 3, 3, 3,
	3, 2, 1, 3, 3, 0, 3, 3,
	2, 3, 3, 0, 3, 3, 2, 1,
	1, 1, 1, 3, 2, 1, 1, 1,
	1, 3, 0, 3, 2, 1, 1, 3,
	8, 3, 4, 3, 4, 3, 8, 9,
	9, 0, 0, 0, 4, 0, 0, 0,
	3, 0, 3, 1, 0, 0, 1, 0,
	3, 1, 3, 0, 3, 1, 1, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	3, 1, 0, 0, 0, 1, 1, 1,
	1, 1, 1, 1, 0, 0, 0, 0,
	0, 1, 0, 3, 1, 0, 3, 1,
	0, 0, 1, 3, 1, 3, 3, 0,
	0, 0, 0, 0, 0, 0, 3, 1,
	0, 0, 0, 0, 0, 0
};

static const short _zone_scanner_index_offsets[] = {
	0, 0, 40, 58, 95, 112, 127, 136,
	145, 147, 149, 152, 169, 186, 191, 240,
	260, 299, 308, 311, 322, 336, 350, 355,
	358, 361, 364, 367, 378, 389, 392, 395,
	406, 409, 412, 415, 426, 433, 436, 439,
	442, 453, 458, 461, 464, 475, 478, 481,
	484, 495, 506, 509, 512, 515, 517, 528,
	530, 541, 544, 547, 550, 553, 564, 569,
	576, 613, 616, 619, 622, 625, 628, 631,
	634, 645, 650, 653, 664, 675, 682, 684,
	695, 697, 708, 711, 722, 733, 738, 741,
	744, 747, 758, 769, 776, 779, 782, 785,
	796, 799, 810, 823, 826, 838, 851, 854,
	857, 860, 863, 874, 877, 880, 891, 898,
	909, 912, 915, 918, 929, 940, 949, 952,
	963, 966, 977, 980, 991, 994, 997, 1000,
	1011, 1018, 1021, 1024, 1035, 1038, 1049, 1052,
	1055, 1057, 1069, 1072, 1075, 1086, 1089, 1129,
	1134, 1141, 1179, 1197, 1205, 1217, 1225, 1228,
	1230, 1237, 1240, 1243, 1246, 1249, 1252, 1255,
	1260, 1267, 1305, 1308, 1326, 1364, 1367, 1375,
	1387, 1395, 1398, 1415, 1462, 1481, 1498, 1538,
	1543, 1555, 1567, 1616, 1633, 1648, 1659, 1670,
	1683, 1696, 1711, 1724, 1739, 1750, 1765, 1782,
	1797, 1808, 1813, 1828, 1831, 1834, 1837, 1840,
	1843, 1848, 1851, 1854, 1859, 1868, 1888, 1928,
	1933, 1952, 2001, 2018, 2033, 2044, 2055, 2068,
	2081, 2096, 2109, 2124, 2135, 2150, 2167, 2182,
	2193, 2206, 2246, 2260, 2274, 2289, 2302, 2305,
	2308, 2319, 2322, 2325, 2328, 2339, 2342, 2353,
	2358, 2370, 2382, 2397, 2412, 2427, 2440, 2443,
	2492, 2506, 2520, 2535, 2548, 2557, 2566, 2577,
	2588, 2601, 2612, 2625, 2634, 2647, 2662, 2675,
	2684, 2689, 2694, 2705, 2710, 2712, 2714, 2723,
	2735, 2747, 2749, 2751, 2753, 2765, 2770, 2775,
	2780, 2789, 2793, 2795, 2797, 2806, 2812, 2817,
	2821, 2823, 2825, 2831, 2838, 2846, 2866, 2875,
	2877, 2887, 2899, 2909, 2912, 2919, 2933, 2941,
	2957, 2966, 2968, 2970, 2972, 2974, 2982, 2991,
	2994, 3001, 3011, 3020, 3036, 3044, 3060, 3069,
	3071, 3073, 3075, 3077, 3085, 3094, 3099, 3113,
	3116, 3119, 3124, 3129, 3135, 3141, 3156, 3159,
	3161, 3172, 3213, 3230, 3233, 3236, 3247, 3250,
	3259, 3262, 3273, 3278, 3281, 3284, 3287, 3290,
	3301, 3312, 3315, 3318, 3329, 3332, 3335, 3338,
	3349, 3356, 3359, 3362, 3365, 3376, 3381, 3384,
	3387, 3398, 3401, 3404, 3407, 3418, 3429, 3432,
	3435, 3438, 3440, 3451, 3453, 3464, 3467, 3470,
	3473, 3476, 3487, 3490, 3493, 3496, 3499, 3502,
	3505, 3508, 3519, 3524, 3527, 3538, 3549, 3556,
	3558, 3569, 3571, 3582, 3585, 3596, 3607, 3612,
	3615, 3618, 3621, 3632, 3643, 3650, 3653, 3656,
	3659, 3670, 3673, 3684, 3697, 3700, 3712, 3725,
	3728, 3731, 3734, 3737, 3748, 3751, 3754, 3765,
	3772, 3783, 3786, 3789, 3792, 3803, 3814, 3823,
	3826, 3837, 3840, 3851, 3854, 3865, 3868, 3871,
	3874, 3885, 3892, 3895, 3898, 3909, 3912, 3923,
	3926, 3929, 3931, 3943, 3946, 3949, 3960, 3963,
	3966, 3969, 3980, 3983, 3994, 4001, 4009, 4017,
	4027, 4031, 4045, 4048, 4051, 4054, 4061, 4070,
	4080, 4090, 4094, 4108, 4111, 4114, 4122, 4125,
	4137, 4143, 4148, 4153, 4156, 4162, 4165, 4168,
	4171, 4174, 4176, 4178, 4181, 4184, 4187, 4189,
	4194, 4199, 4204, 4206, 4209, 4212, 4215, 4218,
	4223, 4226, 4229, 4232, 4235, 4237, 4239, 4242,
	4245, 4248, 4250, 4252, 4254, 4259, 4261, 4263,
	4266, 4269, 4272, 4274, 4276, 4278, 4283, 4286,
	4288, 4290, 4292, 4294, 4299, 4301, 4303, 4308,
	4311, 4314, 4317, 4320, 4323, 4326, 4329, 4334,
	4337, 4340, 4343, 4346, 4349, 4352, 4357, 4360,
	4363, 4368, 4371, 4374, 4379, 4382, 4385, 4390,
	4393, 4395, 4400, 4403, 4406, 4410, 4416, 4419,
	4422, 4425, 4428, 4430, 4432, 4435, 4438, 4441,
	4443, 4448, 4450, 4452, 4457, 4459, 4461, 4466,
	4480, 4486, 4489, 4492, 4495, 4498, 4501, 4506,
	4513, 4516, 4519, 4522, 4525, 4528, 4533, 4538,
	4541, 4546, 4549, 4552, 4557, 4560, 4563, 4566,
	4571, 4574, 4577, 4582, 4587, 4590, 4595, 4598,
	4601, 4606, 4609, 4612, 4615, 4620, 4623, 4626,
	4631, 4634, 4641, 4648, 4653, 4660, 4667, 4680,
	4687, 4695, 4703, 4711, 4729, 4737, 4755, 4763,
	4781, 4789, 4805, 4811, 4823, 4829, 4832, 4840,
	4852, 4860, 4863, 4871, 4883, 4891, 4894, 4902,
	4914, 4922, 4925, 4928, 4931, 4936, 4943, 4953,
	4958, 4961, 4968, 4975, 4988, 4993, 4996, 4998,
	5006, 5019, 5024, 5027, 5032, 5043, 5057, 5060,
	5065, 5074, 5076, 5084, 5094, 5102, 5112, 5121,
	5130, 5137, 5145, 5153, 5163, 5171, 5181, 5190,
	5199, 5206, 5215, 5217, 5231, 5243, 5257, 5269,
	5283, 5295, 5309, 5320, 5323, 5336, 5349, 5352,
	5365, 5378, 5389, 5392, 5405, 5418, 5429, 5432,
	5445, 5458, 5469, 5472, 5479, 5482, 5490, 5498,
	5501, 5504, 5507, 5514, 5517, 5525, 5533, 5536,
	5539, 5541, 5549, 5557, 5565, 5573, 5581, 5594,
	5599, 5602, 5605, 5608, 5610, 5618, 5626, 5634,
	5644, 5651, 5661, 5668, 5678, 5685, 5698, 5703,
	5706, 5709, 5712, 5715, 5718, 5722, 5729, 5737,
	5745, 5755, 5762, 5773, 5776, 5779, 5782, 5785,
	5799, 5802, 5804, 5807, 5810, 5812, 5824, 5827,
	5829, 5834, 5839, 5841, 5849, 5859, 5866, 5874,
	5882, 5892, 5896, 5910, 5913, 5916, 5919, 5922,
	5924, 5932, 5940, 5948, 5958, 5962, 5976, 5979,
	5982, 5985, 5987, 5995, 6006, 6013, 6021, 6029,
	6037, 6072, 6083, 6086, 6089, 6104, 6107, 6146,
	6153, 6156, 6159, 6166, 6174, 6182, 6191, 6228,
	6231, 6234, 6241, 6249, 6257, 6268, 6307, 6310,
	6313, 6320, 6328, 6336, 6349, 6384, 6387, 6390,
	6393, 6424, 6437, 6447, 6454, 6462, 6470, 6478,
	6486, 6494, 6502, 6510, 6518, 6526, 6534, 6547,
	6554, 6565, 6568, 6571, 6574, 6577, 6580, 6583,
	6586, 6589, 6592, 6595, 6598, 6605, 6608, 6611,
	6614, 6621, 6624, 6631, 6640, 6643, 6650, 6655,
	6658, 6661, 6664, 6667, 6674, 6681, 6684, 6687,
	6694, 6697, 6700, 6703, 6710, 6717, 6720, 6723,
	6726, 6733, 6738, 6741, 6744, 6751, 6754, 6757,
	6760, 6767, 6774, 6777, 6780, 6783, 6785, 6792,
	6794, 6801, 6804, 6807, 6810, 6813, 6820, 6823,
	6826, 6829, 6832, 6835, 6838, 6841, 6848, 6853,
	6856, 6863, 6870, 6877, 6879, 6886, 6888, 6895,
	6898, 6905, 6912, 6917, 6920, 6923, 6926, 6933,
	6940, 6947, 6950, 6953, 6956, 6963, 6966, 6973,
	6982, 6985, 6993, 7002, 7005, 7008, 7011, 7014,
	7021, 7024, 7027, 7034, 7041, 7048, 7051, 7054,
	7057, 7064, 7071, 7080, 7083, 7090, 7093, 7100,
	7103, 7110, 7113, 7116, 7119, 7126, 7133, 7136,
	7139, 7146, 7149, 7156, 7159, 7162, 7164, 7172,
	7175, 7178, 7185, 7192, 7197, 7202, 7204, 7212,
	7220, 7228, 7238, 7245, 7256, 7259, 7262, 7265,
	7268, 7273, 7276, 7278, 7286, 7294, 7302, 7310,
	7318, 7329, 7336, 7346, 7350, 7355, 7359, 7364,
	7369, 7373, 7378, 7386, 7391, 7393, 7395, 7397,
	7399, 7401, 7404, 7408, 7418, 7421, 7424, 7427,
	7429, 7437, 7445, 7453, 7461, 7469, 7480, 7485,
	7489, 7497, 7500, 7503, 7506, 7508, 7516, 7524,
	7532, 7540, 7548, 7558, 7562, 7576, 7579, 7582,
	7585, 7588, 7590, 7598, 7607, 7614, 7617, 7619,
	7627, 7637, 7641, 7645, 7649, 7651, 7655, 7659,
	7663, 7667, 7673, 7676, 7680, 7684, 7686, 7690,
	7694, 7700, 7704, 7708, 7710, 7714, 7718, 7724,
	7726, 7734, 7742, 7750, 7760, 7765, 7768, 7771,
	7773, 7781, 7791, 7798, 7808, 7813, 7816, 7819,
	7835, 7861, 7907, 7954, 7970, 8017, 8033, 8059,
	8116, 8173, 8174, 8175, 8176, 8185, 8186, 8187,
	8188, 8202, 8203, 8218, 8221, 8222, 8263, 8266,
	8267, 8281, 8284, 8294, 8295, 8309, 8312, 8315,
	8316, 8317, 8318, 8319, 8320, 8321, 8322, 8323,
	8324, 8338, 8341, 8342, 8343, 8354, 8357, 8369,
	8372, 8384, 8387, 8399, 8402, 8403, 8404, 8405,
	8406, 8420, 8423, 8424, 8438, 8441, 8442, 8456,
	8459, 8460, 8475, 8478, 8489, 8492, 8531, 8538,
	8539, 8540, 8541, 8542, 8543, 8544, 8545, 8559,
	8562, 8563, 8564, 8565, 8566, 8567
};

static const short _zone_scanner_indicies[] = {
	1, 1, 2, 3, 5, 6, 7, 8,
	9, 10, 11, 12, 13, 14, 15, 16,
	17, 18, 19, 5, 6, 7, 8, 9,
	10, 11, 12, 13, 14, 15, 16, 17,
	18, 19, 20, 21, 22, 23, 4, 0,
	25, 25, 26, 27, 29, 30, 31, 32,
	33, 29, 30, 31, 32, 33, 34, 35,
	28, 24, 37, 37, 38, 39, 40, 41,
	42, 43, 44, 45, 46, 47, 48, 49,
	50, 51, 52, 53, 54, 40, 41, 42,
	43, 44, 45, 46, 47, 48, 49, 50,
	51, 52, 53, 54, 55, 56, 36, 58,
	58, 59, 60, 61, 62, 63, 61, 62,
	63, 64, 65, 66, 66, 67, 68, 57,
	70, 70, 72, 73, 74, 75, 76, 69,
	69, 77, 78, 69, 69, 69, 71, 80,
	80, 81, 82, 83, 84, 83, 84, 79,
	86, 86, 87, 88, 89, 90, 89, 90,
	85, 92, 91, 94, 93, 96, 95, 71,
	97, 97, 98, 99, 74, 83, 84, 83,
	100, 101, 102, 83, 103, 69, 69, 69,
	79, 104, 104, 105, 106, 74, 89, 90,
	89, 107, 108, 109, 89, 110, 69, 69,
	69, 79, 92, 112, 91, 111, 79, 113,
	113, 115, 116, 69, 118, 119, 120, 121,
	122, 123, 124, 125, 126, 127, 128, 129,
	130, 131, 132, 74, 118, 119, 120, 121,
	122, 123, 124, 125, 126, 127, 128, 129,
	130, 131, 132, 20, 21, 133, 134, 135,
	136, 137, 138, 69, 69, 117, 69, 114,
	140, 140, 141, 142, 29, 30, 31, 32,
	33, 29, 30, 31, 32, 33, 83, 84,
	143, 144, 28, 139, 146, 146, 147, 148,
	40, 41, 42, 43, 44, 45, 46, 47,
	48, 49, 50, 51, 52, 53, 54, 40,
	41, 42, 43, 44, 45, 46, 47, 48,
	49, 50, 51, 52, 53, 54, 89, 90,
	149, 150, 145, 151, 152, 153, 154, 151,
	152, 153, 154, 36, 155, 155, 36, 156,
	156, 157, 158, 159, 160, 161, 161, 162,
	163, 57, 80, 83, 80, 81, 82, 84,
	164, 83, 164, 165, 166, 167, 95, 79,
	86, 89, 86, 87, 88, 90, 168, 89,
	168, 169, 170, 111, 95, 79, 171, 172,
	171, 172, 36, 173, 173, 36, 174, 174,
	36, 175, 175, 36, 176, 176, 36, 177,
	177, 178, 179, 180, 181, 182, 182, 183,
	184, 57, 185, 185, 186, 187, 188, 189,
	190, 190, 191, 192, 57, 193, 193, 36,
	194, 194, 36, 195, 195, 196, 197, 198,
	199, 200, 200, 201, 202, 57, 203, 203,
	36, 204, 204, 36, 205, 205, 36, 206,
	206, 207, 208, 209, 210, 211, 211, 212,
	213, 57, 214, 215, 216, 214, 215, 216,
	36, 217, 217, 36, 218, 218, 36, 219,
	219, 36, 220, 220, 221, 222, 223, 224,
	225, 225, 226, 227, 57, 228, 229, 228,
	229, 36, 230, 230, 36, 231, 231, 36,
	232, 232, 233, 234, 235, 236, 237, 237,
	238, 239, 57, 240, 240, 36, 241, 241,
	36, 242, 242, 36, 243, 243, 244, 245,
	246, 247, 248, 248, 249, 250, 57, 251,
	251, 252, 253, 254, 255, 256, 256, 257,
	258, 57, 259, 259, 36, 260, 260, 36,
	261, 262, 36, 263, 36, 264, 264, 265,
	266, 267, 268, 269, 269, 270, 271, 57,
	272, 36, 273, 273, 274, 275, 276, 277,
	278, 278, 279, 280, 57, 281, 281, 36,
	282, 282, 36, 283, 283, 36, 284, 284,
	36, 285, 285, 286, 287, 288, 289, 290,
	290, 291, 292, 57, 293, 294, 293, 294,
	36, 295, 295, 296, 297, 298, 299, 36,
	300, 300, 301, 302, 303, 304, 305, 306,
	307, 308, 309, 310, 311, 312, 313, 314,
	315, 316, 317, 303, 304, 305, 306, 307,
	308, 309, 310, 311, 312, 313, 314, 315,
	316, 317, 318, 319, 36, 294, 294, 36,
	320, 320, 36, 321, 321, 36, 322, 322,
	36, 323, 323, 36, 324, 324, 36, 325,
	325, 36, 326, 326, 327, 328, 329, 330,
	331, 331, 332, 333, 57, 334, 335, 334,
	335, 36, 336, 336, 36, 337, 337, 338,
	339, 340, 341, 342, 342, 343, 344, 57,
	345, 345, 346, 347, 348, 349, 350, 350,
	351, 352, 57, 353, 354, 355, 356, 355,
	356, 36, 357, 36, 358, 358, 359, 360,
	361, 362, 363, 363, 364, 365, 57, 366,
	36, 367, 367, 368, 369, 370, 371, 372,
	372, 373, 374, 57, 375, 375, 36, 376,
	376, 377, 378, 379, 380, 381, 381, 382,
	383, 57, 384, 384, 385, 386, 387, 388,
	389, 389, 390, 391, 57, 392, 393, 392,
	393, 36, 394, 394, 36, 395, 395, 36,
	396, 396, 36, 397, 397, 398, 399, 400,
	401, 402, 402, 403, 404, 57, 405, 405,
	406, 407, 408, 409, 410, 410, 411, 412,
	57, 413, 414, 415, 413, 414, 415, 36,
	416, 416, 36, 417, 417, 36, 418, 418,
	36, 419, 419, 420, 421, 422, 423, 424,
	424, 425, 426, 57, 427, 427, 36, 428,
	428, 429, 430, 431, 432, 433, 433, 434,
	435, 57, 436, 436, 437, 438, 439, 439,
	440, 441, 442, 442, 443, 444, 57, 445,
	445, 36, 446, 446, 447, 448, 449, 450,
	451, 452, 452, 453, 454, 57, 455, 455,
	456, 457, 458, 458, 459, 460, 461, 461,
	462, 463, 57, 464, 464, 36, 465, 465,
	36, 466, 466, 36, 467, 467, 36, 468,
	468, 469, 470, 471, 472, 473, 473, 474,
	475, 57, 476, 476, 36, 477, 477, 36,
	478, 478, 479, 480, 481, 482, 483, 483,
	484, 485, 57, 486, 487, 488, 486, 487,
	488, 36, 489, 489, 490, 491, 492, 493,
	494, 494, 495, 496, 57, 497, 497, 36,
	498, 498, 36, 499, 499, 36, 500, 500,
	501, 502, 503, 504, 505, 505, 506, 507,
	57, 508, 508, 509, 510, 511, 512, 513,
	513, 514, 515, 57, 516, 517, 518, 519,
	516, 517, 518, 519, 36, 520, 520, 36,
	521, 521, 522, 523, 524, 525, 526, 526,
	527, 528, 57, 529, 529, 36, 530, 530,
	531, 532, 533, 534, 535, 535, 536, 537,
	57, 538, 538, 36, 539, 539, 540, 541,
	542, 543, 544, 544, 545, 546, 57, 547,
	547, 36, 548, 548, 36, 549, 549, 36,
	550, 550, 551, 552, 553, 554, 555, 555,
	556, 557, 57, 558, 559, 560, 558, 559,
	560, 36, 561, 561, 36, 562, 562, 36,
	563, 563, 564, 565, 566, 567, 568, 568,
	569, 570, 57, 571, 571, 36, 572, 572,
	573, 574, 575, 576, 577, 577, 578, 579,
	57, 580, 580, 36, 581, 581, 36, 583,
	582, 585, 585, 586, 587, 589, 590, 591,
	591, 592, 593, 588, 584, 594, 594, 36,
	595, 595, 36, 596, 596, 597, 598, 599,
	600, 601, 601, 602, 603, 57, 605, 604,
	36, 606, 606, 607, 608, 5, 6, 7,
	8, 9, 10, 11, 12, 13, 14, 15,
	16, 17, 18, 19, 5, 6, 7, 8,
	9, 10, 11, 12, 13, 14, 15, 16,
	17, 18, 19, 20, 21, 609, 610, 4,
	0, 611, 294, 611, 294, 36, 612, 612,
	613, 614, 615, 616, 36, 617, 617, 618,
	619, 621, 622, 623, 624, 625, 626, 627,
	628, 629, 630, 631, 632, 633, 634, 635,
	621, 622, 623, 624, 625, 626, 627, 628,
	629, 630, 631, 632, 633, 634, 635, 636,
	637, 620, 582, 638, 638, 639, 640, 642,
	643, 644, 645, 646, 642, 643, 644, 645,
	646, 647, 648, 641, 24, 638, 638, 639,
	640, 647, 648, 649, 24, 651, 652, 653,
	654, 655, 651, 652, 653, 654, 655, 650,
	24, 656, 656, 657, 658, 660, 661, 659,
	24, 663, 662, 36, 665, 664, 667, 668,
	669, 667, 668, 669, 666, 670, 670, 666,
	671, 671, 666, 672, 672, 666, 673, 673,
	666, 674, 674, 666, 675, 675, 666, 676,
	676, 676, 676, 666, 678, 678, 679, 680,
	681, 682, 677, 683, 683, 684, 685, 5,
	6, 7, 8, 9, 10, 11, 12, 13,
	14, 15, 16, 17, 18, 19, 5, 6,
	7, 8, 9, 10, 11, 12, 13, 14,
	15, 16, 17, 18, 19, 686, 687, 4,
	582, 690, 688, 689, 692, 692, 693, 694,
	29, 30, 31, 32, 33, 29, 30, 31,
	32, 33, 695, 696, 28, 691, 697, 697,
	698, 699, 5, 6, 7, 8, 9, 10,
	11, 12, 13, 14, 15, 16, 17, 18,
	19, 5, 6, 7, 8, 9, 10, 11,
	12, 13, 14, 15, 16, 17, 18, 19,
	700, 701, 4, 582, 703, 702, 36, 25,
	25, 26, 27, 34, 35, 704, 24, 706,
	707, 708, 709, 710, 706, 707, 708, 709,
	710, 705, 24, 711, 711, 712, 713, 715,
	716, 714, 24, 718, 717, 36, 720, 720,
	721, 722, 61, 62, 63, 61, 62, 63,
	723, 724, 66, 66, 725, 726, 719, 727,
	727, 728, 729, 69, 118, 119, 120, 121,
	122, 123, 124, 125, 126, 127, 128, 129,
	130, 131, 132, 74, 118, 119, 120, 121,
	122, 123, 124, 125, 126, 127, 128, 129,
	130, 131, 132, 730, 731, 69, 69, 732,
	733, 69, 69, 117, 69, 584, 735, 735,
	736, 737, 61, 62, 63, 61, 62, 63,
	83, 84, 738, 739, 740, 741, 742, 743,
	734, 744, 744, 745, 746, 74, 89, 90,
	747, 107, 108, 109, 748, 110, 69, 69,
	69, 79, 749, 749, 750, 751, 5, 6,
	7, 8, 9, 10, 11, 12, 13, 14,
	15, 16, 17, 18, 19, 5, 6, 7,
	8, 9, 10, 11, 12, 13, 14, 15,
	16, 17, 18, 19, 89, 90, 752, 753,
	4, 0, 92, 755, 91, 754, 85, 756,
	756, 757, 758, 759, 760, 759, 760, 91,
	91, 91, 79, 761, 761, 762, 763, 92,
	91, 92, 91, 91, 91, 91, 85, 764,
	764, 765, 766, 69, 118, 119, 120, 121,
	122, 123, 124, 125, 126, 127, 128, 129,
	130, 131, 132, 74, 118, 119, 120, 121,
	122, 123, 124, 125, 126, 127, 128, 129,
	130, 131, 132, 89, 90, 752, 767, 108,
	109, 752, 768, 69, 69, 117, 69, 114,
	80, 80, 81, 82, 151, 152, 153, 154,
	151, 152, 153, 154, 83, 84, 83, 84,
	734, 80, 80, 81, 82, 214, 215, 216,
	214, 215, 216, 83, 84, 83, 84, 734,
	80, 80, 81, 82, 259, 259, 83, 84,
	83, 84, 734, 80, 80, 81, 82, 281,
	281, 83, 84, 83, 84, 734, 80, 80,
	81, 82, 611, 294, 611, 294, 83, 84,
	83, 84, 734, 80, 80, 81, 82, 334,
	335, 334, 335, 83, 84, 83, 84, 734,
	80, 80, 81, 82, 353, 354, 355, 356,
	355, 356, 83, 84, 83, 84, 734, 80,
	80, 81, 82, 392, 393, 392, 393, 83,
	84, 83, 84, 734, 80, 80, 81, 82,
	413, 414, 415, 413, 414, 415, 83, 84,
	83, 84, 734, 80, 80, 81, 82, 476,
	476, 83, 84, 83, 84, 734, 80, 80,
	81, 82, 486, 487, 488, 486, 487, 488,
	83, 84, 83, 84, 734, 80, 80, 81,
	82, 516, 517, 518, 519, 516, 517, 518,
	519, 83, 84, 83, 84, 734, 80, 80,
	81, 82, 558, 559, 560, 558, 559, 560,
	83, 84, 83, 84, 734, 80, 80, 81,
	82, 594, 594, 83, 84, 83, 84, 734,
	92, 770, 91, 769, 79, 80, 80, 81,
	82, 667, 668, 669, 667, 668, 669, 83,
	84, 83, 84, 771, 772, 772, 666, 773,
	773, 666, 774, 774, 666, 775, 775, 666,
	776, 776, 666, 777, 777, 777, 777, 666,
	778, 778, 666, 779, 779, 666, 780, 780,
	780, 780, 666, 782, 782, 783, 784, 83,
	84, 785, 786, 781, 788, 788, 789, 790,
	29, 30, 31, 32, 33, 29, 30, 31,
	32, 33, 83, 84, 791, 792, 28, 787,
	793, 793, 794, 795, 5, 6, 7, 8,
	9, 10, 11, 12, 13, 14, 15, 16,
	17, 18, 19, 5, 6, 7, 8, 9,
	10, 11, 12, 13, 14, 15, 16, 17,
	18, 19, 89, 90, 796, 797, 4, 0,
	92, 799, 91, 798, 145, 801, 801, 802,
	803, 61, 62, 63, 61, 62, 63, 83,
	84, 804, 805, 740, 741, 806, 807, 800,
	808, 808, 809, 810, 69, 118, 119, 120,
	121, 122, 123, 124, 125, 126, 127, 128,
	129, 130, 131, 132, 74, 118, 119, 120,
	121, 122, 123, 124, 125, 126, 127, 128,
	129, 130, 131, 132, 89, 90, 811, 767,
	108, 109, 812, 768, 69, 69, 117, 69,
	114, 782, 782, 783, 784, 151, 152, 153,
	154, 151, 152, 153, 154, 83, 84, 785,
	786, 800, 782, 782, 783, 784, 214, 215,
	216, 214, 215, 216, 83, 84, 785, 786,
	800, 782, 782, 783, 784, 259, 259, 83,
	84, 785, 786, 800, 782, 782, 783, 784,
	281, 281, 83, 84, 785, 786, 800, 782,
	782, 783, 784, 611, 294, 611, 294, 83,
	84, 785, 786, 800, 782, 782, 783, 784,
	334, 335, 334, 335, 83, 84, 785, 786,
	800, 782, 782, 783, 784, 353, 354, 355,
	356, 355, 356, 83, 84, 785, 786, 800,
	782, 782, 783, 784, 392, 393, 392, 393,
	83, 84, 785, 786, 800, 782, 782, 783,
	784, 413, 414, 415, 413, 414, 415, 83,
	84, 785, 786, 800, 782, 782, 783, 784,
	476, 476, 83, 84, 785, 786, 800, 782,
	782, 783, 784, 486, 487, 488, 486, 487,
	488, 83, 84, 785, 786, 800, 782, 782,
	783, 784, 516, 517, 518, 519, 516, 517,
	518, 519, 83, 84, 785, 786, 800, 782,
	782, 783, 784, 558, 559, 560, 558, 559,
	560, 83, 84, 785, 786, 800, 782, 782,
	783, 784, 594, 594, 83, 84, 785, 786,
	800, 813, 813, 94, 815, 816, 93, 93,
	817, 818, 93, 93, 93, 814, 819, 819,
	820, 821, 5, 6, 7, 8, 9, 10,
	11, 12, 13, 14, 15, 16, 17, 18,
	19, 5, 6, 7, 8, 9, 10, 11,
	12, 13, 14, 15, 16, 17, 18, 19,
	83, 84, 822, 823, 4, 114, 80, 83,
	80, 81, 82, 84, 824, 825, 824, 826,
	827, 828, 688, 79, 86, 89, 86, 87,
	88, 90, 829, 755, 829, 830, 831, 754,
	688, 85, 756, 759, 756, 757, 758, 760,
	832, 825, 832, 833, 834, 835, 91, 769,
	79, 761, 92, 761, 762, 763, 836, 755,
	836, 837, 838, 91, 769, 79, 839, 839,
	36, 840, 840, 36, 841, 841, 842, 843,
	844, 845, 846, 846, 847, 848, 57, 849,
	849, 36, 850, 850, 36, 851, 851, 36,
	852, 852, 853, 854, 855, 856, 857, 857,
	858, 859, 57, 860, 860, 36, 861, 861,
	862, 863, 864, 865, 866, 866, 867, 868,
	57, 665, 870, 664, 869, 79, 871, 871,
	872, 873, 874, 760, 874, 760, 664, 664,
	664, 79, 875, 875, 876, 877, 878, 91,
	878, 91, 664, 664, 664, 85, 871, 874,
	871, 872, 873, 760, 879, 825, 879, 880,
	881, 835, 664, 869, 79, 875, 878, 875,
	876, 877, 91, 882, 755, 882, 883, 884,
	769, 664, 869, 79, 756, 759, 756, 757,
	758, 760, 885, 759, 885, 886, 887, 167,
	91, 111, 79, 761, 92, 761, 762, 763,
	888, 92, 888, 889, 890, 91, 111, 79,
	892, 891, 71, 893, 893, 894, 895, 69,
	118, 119, 120, 121, 122, 123, 124, 125,
	126, 127, 128, 129, 130, 131, 132, 74,
	118, 119, 120, 121, 122, 123, 124, 125,
	126, 127, 128, 129, 130, 131, 132, 83,
	84, 822, 896, 101, 102, 822, 897, 69,
	69, 117, 69, 114, 80, 83, 80, 81,
	82, 84, 898, 825, 898, 899, 900, 835,
	891, 79, 86, 89, 86, 87, 88, 90,
	901, 755, 901, 902, 903, 769, 891, 79,
	678, 678, 679, 680, 151, 152, 153, 154,
	151, 152, 153, 154, 681, 682, 904, 678,
	678, 679, 680, 214, 215, 216, 214, 215,
	216, 681, 682, 904, 678, 678, 679, 680,
	259, 259, 681, 682, 904, 678, 678, 679,
	680, 281, 281, 681, 682, 904, 678, 678,
	679, 680, 611, 294, 611, 294, 681, 682,
	904, 678, 678, 679, 680, 334, 335, 334,
	335, 681, 682, 904, 678, 678, 679, 680,
	353, 354, 355, 356, 355, 356, 681, 682,
	904, 678, 678, 679, 680, 392, 393, 392,
	393, 681, 682, 904, 678, 678, 679, 680,
	413, 414, 415, 413, 414, 415, 681, 682,
	904, 678, 678, 679, 680, 476, 476, 681,
	682, 904, 678, 678, 679, 680, 486, 487,
	488, 486, 487, 488, 681, 682, 904, 678,
	678, 679, 680, 516, 517, 518, 519, 516,
	517, 518, 519, 681, 682, 904, 678, 678,
	679, 680, 558, 559, 560, 558, 559, 560,
	681, 682, 904, 678, 678, 679, 680, 594,
	594, 681, 682, 904, 665, 906, 664, 905,
	85, 665, 908, 664, 907, 145, 678, 678,
	679, 680, 293, 294, 293, 294, 681, 682,
	904, 92, 910, 91, 909, 145, 912, 911,
	914, 913, 916, 917, 918, 919, 916, 916,
	916, 916, 915, 920, 921, 922, 920, 923,
	921, 920, 920, 921, 921, 921, 915, 924,
	925, 925, 924, 926, 925, 924, 924, 925,
	925, 925, 915, 927, 921, 929, 928, 930,
	928, 931, 932, 933, 931, 934, 932, 931,
	931, 932, 932, 932, 928, 924, 924, 924,
	924, 915, 935, 935, 935, 935, 915, 938,
	939, 937, 937, 936, 940, 937, 940, 939,
	940, 937, 941, 937, 936, 937, 943, 937,
	942, 944, 942, 945, 942, 946, 947, 946,
	949, 946, 947, 948, 947, 942, 950, 951,
	952, 950, 950, 936, 940, 940, 940, 940,
	953, 950, 954, 950, 942, 955, 942, 956,
	942, 957, 958, 959, 957, 957, 942, 961,
	961, 962, 963, 964, 965, 960, 961, 961,
	962, 963, 964, 965, 967, 966, 969, 969,
	970, 971, 973, 974, 975, 976, 977, 973,
	974, 975, 976, 977, 978, 979, 978, 979,
	972, 968, 981, 981, 982, 983, 984, 985,
	984, 985, 980, 987, 986, 969, 969, 970,
	971, 978, 979, 978, 979, 988, 968, 991,
	992, 993, 994, 995, 991, 992, 993, 994,
	995, 990, 989, 996, 996, 997, 998, 1000,
	1001, 1000, 1001, 999, 968, 1003, 1002, 960,
	1005, 1005, 1006, 1007, 1008, 1009, 1004, 1005,
	1005, 1006, 1007, 1010, 1011, 1012, 1010, 1008,
	1009, 1010, 1010, 1010, 1004, 1013, 1014, 1015,
	1013, 1013, 1013, 1013, 1004, 1017, 1017, 1018,
	1019, 1020, 1020, 1021, 1020, 1022, 1023, 1022,
	1023, 1020, 1020, 1020, 1016, 1024, 1024, 1025,
	1026, 1027, 1028, 1027, 1028, 1016, 1030, 1029,
	1031, 1013, 1033, 1032, 1034, 1032, 1035, 1036,
	1037, 1035, 1035, 1035, 1035, 1032, 1017, 1017,
	1018, 1019, 1022, 1023, 1022, 1023, 1016, 1039,
	1038, 1004, 1040, 1040, 1041, 1042, 1043, 1044,
	689, 1040, 1040, 1041, 1042, 1043, 1044, 1045,
	1045, 1045, 1046, 1048, 1048, 1049, 1050, 1051,
	1052, 1051, 1053, 1047, 1055, 1055, 1056, 1057,
	1058, 1059, 1060, 1058, 1061, 1062, 1061, 1063,
	1058, 1058, 1058, 1054, 1065, 1066, 1067, 1065,
	1065, 1065, 1065, 1064, 1068, 1068, 1069, 1070,
	1071, 1071, 1072, 1071, 1073, 1074, 1073, 1074,
	1071, 1071, 1071, 1054, 1075, 1075, 1076, 1077,
	1061, 1062, 1061, 1062, 85, 1079, 1078, 1080,
	1065, 1082, 1081, 1083, 1081, 1084, 1085, 1086,
	1084, 1084, 1084, 1084, 1081, 1068, 1068, 1069,
	1070, 1073, 1074, 1073, 1074, 1054, 1079, 1088,
	1078, 1087, 85, 1089, 1089, 1090, 1091, 1058,
	1059, 1060, 1058, 1092, 1093, 1058, 1058, 1058,
	1064, 1095, 1094, 689, 1097, 1096, 689, 1099,
	1099, 1099, 1099, 1098, 1100, 1100, 1100, 1100,
	1098, 1101, 1102, 1101, 1101, 1101, 1098, 1103,
	1104, 1103, 1103, 1103, 1098, 1104, 1104, 1105,
	1106, 1099, 1107, 1108, 1109, 1109, 1110, 1111,
	1099, 1099, 1099, 1098, 1113, 1112, 1098, 1104,
	1098, 1115, 1115, 1116, 1117, 1118, 1119, 1120,
	1120, 1121, 1122, 1114, 1123, 1123, 1124, 1125,
	1126, 1127, 1128, 1129, 1130, 1131, 1132, 1133,
	1134, 1135, 1136, 1137, 1138, 1139, 1140, 1126,
	1127, 1128, 1129, 1130, 1131, 1132, 1133, 1134,
	1135, 1136, 1137, 1138, 1139, 1140, 1141, 1142,
	1143, 1143, 1144, 1145, 1114, 1146, 1146, 1147,
	1148, 1149, 1150, 1151, 1149, 1150, 1151, 1152,
	1153, 1154, 1154, 1155, 1156, 1114, 1157, 1157,
	1114, 1158, 1158, 1114, 1159, 1159, 1160, 1161,
	1162, 1163, 1164, 1164, 1165, 1166, 1114, 1168,
	1167, 1114, 1169, 1170, 1171, 1172, 1169, 1170,
	1171, 1172, 1114, 1173, 1173, 1114, 1174, 1174,
	1175, 1176, 1177, 1178, 1179, 1179, 1180, 1181,
	1114, 1182, 1183, 1182, 1183, 1114, 1184, 1184,
	1114, 1185, 1185, 1114, 1186, 1186, 1114, 1187,
	1187, 1114, 1188, 1188, 1189, 1190, 1191, 1192,
	1193, 1193, 1194, 1195, 1114, 1196, 1196, 1197,
	1198, 1199, 1200, 1201, 1201, 1202, 1203, 1114,
	1204, 1204, 1114, 1205, 1205, 1114, 1206, 1206,
	1207, 1208, 1209, 1210, 1211, 1211, 1212, 1213,
	1114, 1214, 1214, 1114, 1215, 1215, 1114, 1216,
	1216, 1114, 1217, 1217, 1218, 1219, 1220, 1221,
	1222, 1222, 1223, 1224, 1114, 1225, 1226, 1227,
	1225, 1226, 1227, 1114, 1228, 1228, 1114, 1229,
	1229, 1114, 1230, 1230, 1114, 1231, 1231, 1232,
	1233, 1234, 1235, 1236, 1236, 1237, 1238, 1114,
	1239, 1240, 1239, 1240, 1114, 1241, 1241, 1114,
	1242, 1242, 1114, 1243, 1243, 1244, 1245, 1246,
	1247, 1248, 1248, 1249, 1250, 1114, 1251, 1251,
	1114, 1252, 1252, 1114, 1253, 1253, 1114, 1254,
	1254, 1255, 1256, 1257, 1258, 1259, 1259, 1260,
	1261, 1114, 1262, 1262, 1263, 1264, 1265, 1266,
	1267, 1267, 1268, 1269, 1114, 1270, 1270, 1114,
	1271, 1271, 1114, 1272, 1273, 1114, 1274, 1114,
	1275, 1275, 1276, 1277, 1278, 1279, 1280, 1280,
	1281, 1282, 1114, 1283, 1114, 1284, 1284, 1285,
	1286, 1287, 1288, 1289, 1289, 1290, 1291, 1114,
	1292, 1292, 1114, 1293, 1293, 1114, 1294, 1294,
	1114, 1295, 1295, 1114, 1296, 1296, 1297, 1298,
	1299, 1300, 1301, 1301, 1302, 1303, 1114, 1304,
	1304, 1114, 1305, 1305, 1114, 1306, 1306, 1114,
	1307, 1307, 1114, 1308, 1308, 1114, 1309, 1309,
	1114, 1310, 1310, 1114, 1311, 1311, 1312, 1313,
	1314, 1315, 1316, 1316, 1317, 1318, 1114, 1319,
	1320, 1319, 1320, 1114, 1321, 1321, 1114, 1322,
	1322, 1323, 1324, 1325, 1326, 1327, 1327, 1328,
	1329, 1114, 1330, 1330, 1331, 1332, 1333, 1334,
	1335, 1335, 1336, 1337, 1114, 1338, 1339, 1340,
	1341, 1340, 1341, 1114, 1342, 1114, 1343, 1343,
	1344, 1345, 1346, 1347, 1348, 1348, 1349, 1350,
	1114, 1351, 1114, 1352, 1352, 1353, 1354, 1355,
	1356, 1357, 1357, 1358, 1359, 1114, 1360, 1360,
	1114, 1361, 1361, 1362, 1363, 1364, 1365, 1366,
	1366, 1367, 1368, 1114, 1369, 1369, 1370, 1371,
	1372, 1373, 1374, 1374, 1375, 1376, 1114, 1377,
	1378, 1377, 1378, 1114, 1379, 1379, 1114, 1380,
	1380, 1114, 1381, 1381, 1114, 1382, 1382, 1383,
	1384, 1385, 1386, 1387, 1387, 1388, 1389, 1114,
	1390, 1390, 1391, 1392, 1393, 1394, 1395, 1395,
	1396, 1397, 1114, 1398, 1399, 1400, 1398, 1399,
	1400, 1114, 1401, 1401, 1114, 1402, 1402, 1114,
	1403, 1403, 1114, 1404, 1404, 1405, 1406, 1407,
	1408, 1409, 1409, 1410, 1411, 1114, 1412, 1412,
	1114, 1413, 1413, 1414, 1415, 1416, 1417, 1418,
	1418, 1419, 1420, 1114, 1421, 1421, 1422, 1423,
	1424, 1424, 1425, 1426, 1427, 1427, 1428, 1429,
	1114, 1430, 1430, 1114, 1431, 1431, 1432, 1433,
	1434, 1435, 1436, 1437, 1437, 1438, 1439, 1114,
	1440, 1440, 1441, 1442, 1443, 1443, 1444, 1445,
	1446, 1446, 1447, 1448, 1114, 1449, 1449, 1114,
	1450, 1450, 1114, 1451, 1451, 1114, 1452, 1452,
	1114, 1453, 1453, 1454, 1455, 1456, 1457, 1458,
	1458, 1459, 1460, 1114, 1461, 1461, 1114, 1462,
	1462, 1114, 1463, 1463, 1464, 1465, 1466, 1467,
	1468, 1468, 1469, 1470, 1114, 1471, 1472, 1473,
	1471, 1472, 1473, 1114, 1474, 1474, 1475, 1476,
	1477, 1478, 1479, 1479, 1480, 1481, 1114, 1482,
	1482, 1114, 1483, 1483, 1114, 1484, 1484, 1114,
	1485, 1485, 1486, 1487, 1488, 1489, 1490, 1490,
	1491, 1492, 1114, 1493, 1493, 1494, 1495, 1496,
	1497, 1498, 1498, 1499, 1500, 1114, 1501, 1502,
	1503, 1504, 1501, 1502, 1503, 1504, 1114, 1505,
	1505, 1114, 1506, 1506, 1507, 1508, 1509, 1510,
	1511, 1511, 1512, 1513, 1114, 1514, 1514, 1114,
	1515, 1515, 1516, 1517, 1518, 1519, 1520, 1520,
	1521, 1522, 1114, 1523, 1523, 1114, 1524, 1524,
	1525, 1526, 1527, 1528, 1529, 1529, 1530, 1531,
	1114, 1532, 1532, 1114, 1533, 1533, 1114, 1534,
	1534, 1114, 1535, 1535, 1536, 1537, 1538, 1539,
	1540, 1540, 1541, 1542, 1114, 1543, 1544, 1545,
	1543, 1544, 1545, 1114, 1546, 1546, 1114, 1547,
	1547, 1114, 1548, 1548, 1549, 1550, 1551, 1552,
	1553, 1553, 1554, 1555, 1114, 1556, 1556, 1114,
	1557, 1557, 1558, 1559, 1560, 1561, 1562, 1562,
	1563, 1564, 1114, 1565, 1565, 1114, 1566, 1566,
	1114, 1567, 1114, 1568, 1568, 1569, 1570, 1572,
	1573, 1574, 1574, 1575, 1576, 1571, 1114, 1577,
	1577, 1114, 1578, 1578, 1114, 1579, 1579, 1580,
	1581, 1582, 1583, 1584, 1584, 1585, 1586, 1114,
	1587, 1587, 1114, 1588, 1588, 1114, 1589, 1589,
	1114, 1590, 1590, 1591, 1592, 1593, 1594, 1595,
	1595, 1596, 1597, 1114, 1598, 1598, 1114, 1599,
	1599, 1600, 1601, 1602, 1603, 1604, 1604, 1605,
	1606, 1114, 1608, 1608, 1609, 1610, 1611, 1612,
	1607, 1608, 1608, 1609, 1610, 1611, 1612, 1614,
	1613, 1615, 1615, 1616, 1617, 1619, 1620, 1618,
	1613, 1622, 1622, 1623, 1624, 1626, 1627, 1625,
	1625, 1625, 1621, 1628, 1628, 1628, 1621, 1629,
	1629, 1630, 1631, 1632, 1633, 1634, 1634, 1635,
	1636, 1625, 1625, 1625, 1621, 1638, 1637, 1621,
	1640, 1639, 1607, 1642, 1641, 1607, 1643, 1643,
	1644, 1645, 1646, 1647, 1607, 1643, 1643, 1644,
	1645, 1648, 1646, 1647, 1649, 1613, 1650, 1650,
	1651, 1652, 1654, 1654, 1655, 1656, 1653, 1613,
	1657, 1657, 1658, 1659, 1661, 1662, 1660, 1660,
	1660, 1621, 1663, 1663, 1663, 1621, 1664, 1664,
	1665, 1666, 1667, 1668, 1669, 1669, 1670, 1671,
	1660, 1660, 1660, 1621, 1673, 1672, 1621, 1675,
	1674, 1607, 1676, 1676, 1677, 1678, 1679, 1680,
	1653, 1613, 1682, 1681, 1607, 1685, 1686, 1687,
	1688, 1689, 1685, 1686, 1687, 1688, 1689, 1684,
	1683, 1690, 1690, 1690, 1690, 1691, 1683, 1692,
	1693, 1692, 1693, 1683, 1694, 1694, 1694, 1694,
	1683, 1695, 1695, 1683, 1696, 1697, 1696, 1696,
	1696, 1683, 1698, 1698, 1683, 1699, 1699, 1683,
	1700, 1700, 1683, 1701, 1701, 1683, 1702, 1683,
	1703, 1683, 1704, 1704, 1683, 1705, 1705, 1683,
	1706, 1706, 1683, 1707, 1683, 1708, 1708, 1708,
	1708, 1683, 1709, 1710, 1709, 1710, 1683, 1711,
	1712, 1711, 1712, 1683, 1713, 1683, 1714, 1714,
	1683, 1715, 1715, 1683, 1716, 1716, 1683, 1717,
	1717, 1683, 1718, 1718, 1718, 1718, 1683, 1719,
	1719, 1683, 1720, 1720, 1683, 1721, 1721, 1683,
	1722, 1723, 1683, 1724, 1683, 1725, 1683, 1726,
	1726, 1683, 1727, 1727, 1683, 1728, 1728, 1683,
	1729, 1683, 1730, 1683, 1731, 1683, 1732, 1732,
	1732, 1732, 1683, 1733, 1683, 1734, 1683, 1735,
	1735, 1683, 1736, 1736, 1683, 1737, 1737, 1683,
	1738, 1683, 1739, 1683, 1740, 1683, 1741, 1741,
	1741, 1741, 1683, 1742, 1743, 1683, 1744, 1683,
	1745, 1683, 1746, 1683, 1747, 1683, 1748, 1748,
	1748, 1748, 1683, 1749, 1683, 1750, 1683, 1751,
	1751, 1751, 1751, 1683, 1752, 1752, 1683, 1753,
	1753, 1683, 1754, 1754, 1683, 1755, 1755, 1683,
	1756, 1756, 1683, 1757, 1757, 1683, 1758, 1758,
	1683, 1759, 1759, 1759, 1759, 1683, 1760, 1760,
	1683, 1761, 1761, 1683, 1762, 1762, 1683, 1763,
	1763, 1683, 1764, 1764, 1683, 1765, 1765, 1683,
	1766, 1767, 1766, 1767, 1683, 1768, 1768, 1683,
	1769, 1769, 1683, 1770, 1770, 1770, 1770, 1683,
	1771, 1771, 1683, 1772, 1772, 1683, 1773, 1773,
	1773, 1773, 1683, 1774, 1774, 1683, 1775, 1775,
	1683, 1776, 1777, 1776, 1777, 1683, 1778, 1778,
	1683, 1779, 1683, 1780, 1780, 1780, 1780, 1683,
	1781, 1781, 1683, 1782, 1782, 1683, 1783, 1784,
	1785, 1683, 1786, 1787, 1786, 1786, 1786, 1683,
	1788, 1788, 1683, 1789, 1789, 1683, 1790, 1790,
	1683, 1791, 1791, 1683, 1792, 1683, 1793, 1683,
	1794, 1794, 1683, 1795, 1795, 1683, 1796, 1796,
	1683, 1797, 1683, 1798, 1798, 1798, 1798, 1683,
	1799, 1683, 1800, 1683, 1801, 1801, 1801, 1801,
	1683, 1802, 1683, 1803, 1683, 1804, 1804, 1804,
	1804, 1683, 1807, 1808, 1809, 1810, 1811, 1812,
	1807, 1808, 1809, 1810, 1811, 1812, 1806, 1805,
	1813, 1813, 1813, 1813, 1814, 1805, 1815, 1815,
	1805, 1816, 1816, 1805, 1817, 1817, 1805, 1818,
	1818, 1805, 1819, 1819, 1805, 1820, 1820, 1820,
	1820, 1805, 1821, 1822, 1823, 1821, 1822, 1823,
	1805, 1824, 1824, 1805, 1825, 1825, 1805, 1826,
	1826, 1805, 1827, 1827, 1805, 1828, 1828, 1805,
	1829, 1829, 1829, 1829, 1805, 1830, 1831, 1830,
	1831, 1805, 1832, 1832, 1805, 1833, 1833, 1833,
	1833, 1805, 1834, 1834, 1805, 1835, 1835, 1805,
	1836, 1836, 1836, 1836, 1805, 1837, 1837, 1805,
	1838, 1838, 1805, 1839, 1839, 1805, 1840, 1840,
	1840, 1840, 1805, 1841, 1841, 1805, 1842, 1842,
	1805, 1843, 1843, 1843, 1843, 1805, 1844, 1845,
	1844, 1845, 1805, 1846, 1846, 1805, 1847, 1847,
	1847, 1847, 1805, 1848, 1848, 1805, 1849, 1849,
	1805, 1850, 1850, 1850, 1850, 1805, 1851, 1851,
	1805, 1852, 1852, 1805, 1853, 1853, 1805, 1854,
	1854, 1854, 1854, 1805, 1855, 1855, 1805, 1856,
	1856, 1805, 1857, 1857, 1857, 1857, 1805, 1859,
	1859, 1858, 1860, 1861, 1860, 1860, 1860, 1861,
	1858, 1862, 1862, 1862, 1862, 1862, 1862, 71,
	1863, 1863, 1863, 1863, 71, 1864, 1864, 1864,
	1864, 1864, 1864, 71, 1865, 1865, 1866, 1867,
	1868, 1869, 71, 1870, 1870, 1871, 1872, 1873,
	1873, 1873, 1874, 1875, 1873, 1873, 1873, 71,
	1876, 1876, 1877, 1878, 1879, 1880, 71, 1882,
	1882, 1883, 1884, 1886, 1887, 1885, 1881, 1888,
	1888, 1889, 1890, 1892, 1893, 1891, 1881, 1894,
	1894, 1895, 1896, 1898, 1899, 1897, 1881, 1901,
	1901, 1902, 1903, 1905, 1906, 1907, 1908, 1909,
	1905, 1906, 1907, 1908, 1909, 1910, 1911, 1904,
	1900, 1912, 1912, 1913, 1914, 1916, 1917, 1915,
	1881, 1918, 1918, 1919, 1920, 1922, 1923, 1924,
	1925, 1926, 1922, 1923, 1924, 1925, 1926, 1927,
	1928, 1921, 1900, 1929, 1929, 1930, 1931, 1933,
	1934, 1932, 1881, 1935, 1935, 1936, 1937, 1939,
	1940, 1941, 1942, 1943, 1939, 1940, 1941, 1942,
	1943, 1944, 1945, 1938, 1900, 1946, 1946, 1947,
	1948, 1950, 1951, 1949, 1881, 1952, 1952, 1954,
	1955, 1956, 1957, 1958, 1954, 1955, 1956, 1957,
	1958, 1952, 1952, 1953, 1900, 1952, 1952, 1952,
	1952, 1959, 1900, 1961, 1962, 1963, 1964, 1965,
	1961, 1962, 1963, 1964, 1965, 1960, 1900, 1966,
	1966, 1966, 1966, 1967, 1900, 1969, 1968, 71,
	1935, 1935, 1936, 1937, 1944, 1945, 1970, 1900,
	1972, 1973, 1974, 1975, 1976, 1972, 1973, 1974,
	1975, 1976, 1971, 1900, 1977, 1977, 1978, 1979,
	1981, 1982, 1980, 1900, 1984, 1983, 71, 1918,
	1918, 1919, 1920, 1927, 1928, 1985, 1900, 1987,
	1988, 1989, 1990, 1991, 1987, 1988, 1989, 1990,
	1991, 1986, 1900, 1992, 1992, 1993, 1994, 1996,
	1997, 1995, 1900, 1999, 1998, 71, 1901, 1901,
	1902, 1903, 1910, 1911, 2000, 1900, 2002, 2003,
	2004, 2005, 2006, 2002, 2003, 2004, 2005, 2006,
	2001, 1900, 2007, 2007, 2008, 2009, 2011, 2012,
	2010, 1900, 2014, 2013, 71, 2016, 2015, 71,
	2018, 2017, 71, 71, 71, 71, 71, 2019,
	2020, 2020, 2021, 2022, 2023, 2024, 71, 2026,
	2026, 2027, 2028, 2029, 2030, 2025, 2025, 2025,
	71, 2031, 2031, 2031, 2031, 71, 2033, 2032,
	71, 2034, 2034, 2034, 2034, 2034, 2034, 71,
	2035, 2035, 2036, 2037, 2038, 2039, 71, 2040,
	2040, 2041, 2042, 2043, 2043, 2043, 2044, 2045,
	2043, 2043, 2043, 71, 2046, 2046, 2046, 2046,
	71, 2048, 2047, 71, 2049, 1881, 2050, 2050,
	2051, 2052, 2054, 2055, 2053, 1881, 2056, 2056,
	2057, 2058, 2059, 2059, 2059, 2060, 2061, 2059,
	2059, 2059, 71, 2062, 2062, 2062, 2062, 71,
	2064, 2063, 71, 2066, 2066, 2066, 2066, 2065,
	2067, 2067, 2068, 2069, 2070, 2071, 2072, 2072,
	2073, 2074, 2066, 2076, 2076, 2077, 2078, 2079,
	2080, 2081, 2081, 2082, 2083, 2075, 2075, 2075,
	2066, 2085, 2084, 2066, 2086, 2086, 2086, 2086,
	1858, 2087, 2088, 2087, 2087, 2087, 2088, 2088,
	2088, 1858, 2090, 2089, 2091, 2091, 2092, 2093,
	2095, 2096, 2094, 2089, 2097, 2097, 2098, 2099,
	2101, 2102, 2103, 2104, 2100, 2089, 2105, 2105,
	2106, 2107, 2109, 2110, 2108, 2089, 2111, 2111,
	2112, 2113, 2101, 2102, 2115, 2116, 2114, 2089,
	2117, 2117, 2118, 2119, 2120, 2122, 2123, 2121,
	2089, 2124, 2124, 2125, 2126, 2101, 2102, 2127,
	2128, 2089, 2129, 2129, 2130, 2131, 2132, 2133,
	2089, 2129, 2129, 2130, 2131, 2132, 2133, 2134,
	2089, 2135, 2135, 2136, 2137, 2139, 2140, 2138,
	2089, 2141, 2141, 2142, 2143, 2145, 2146, 2147,
	2148, 2144, 2089, 2149, 2149, 2150, 2151, 2153,
	2154, 2152, 2089, 2155, 2155, 2156, 2157, 2145,
	2146, 2159, 2160, 2158, 2089, 2161, 2161, 2162,
	2163, 2164, 2166, 2167, 2165, 2089, 2168, 2168,
	2169, 2170, 2145, 2146, 2171, 2172, 2089, 2173,
	2173, 2174, 2175, 2176, 2177, 2089, 2173, 2173,
	2174, 2175, 2178, 2176, 2177, 2179, 2089, 2180,
	2089, 2181, 2181, 2182, 2183, 2184, 2186, 2187,
	2188, 2189, 2189, 2190, 2191, 2185, 2089, 2192,
	2192, 2193, 2194, 2196, 2197, 2198, 2198, 2199,
	2200, 2195, 2089, 2201, 2201, 2202, 2203, 2204,
	2206, 2207, 2208, 2209, 2209, 2210, 2211, 2205,
	2089, 2212, 2212, 2213, 2214, 2216, 2217, 2198,
	2198, 2218, 2219, 2215, 2089, 2220, 2220, 2221,
	2222, 2223, 2225, 2226, 2227, 2228, 2228, 2229,
	2230, 2224, 2089, 2231, 2231, 2232, 2233, 2235,
	2236, 2198, 2198, 2237, 2238, 2234, 2089, 2239,
	2239, 2240, 2241, 2242, 2239, 2244, 2245, 2246,
	2246, 2247, 2248, 2243, 2089, 2249, 2249, 2250,
	2251, 2252, 2253, 2198, 2198, 2254, 2255, 2089,
	2257, 2256, 2089, 2258, 2258, 2259, 2260, 2258,
	2262, 2263, 2264, 2264, 2265, 2266, 2261, 2089,
	2239, 2239, 2240, 2241, 2239, 2244, 2245, 2246,
	2246, 2247, 2248, 2267, 2089, 2269, 2268, 2089,
	2270, 2270, 2271, 2272, 2274, 2275, 2276, 2277,
	2277, 2278, 2279, 2273, 2089, 2220, 2220, 2221,
	2222, 2225, 2226, 2227, 2228, 2228, 2229, 2230,
	2280, 2089, 2231, 2231, 2232, 2233, 2235, 2236,
	2198, 2198, 2237, 2238, 2089, 2282, 2281, 2089,
	2283, 2283, 2284, 2285, 2287, 2288, 2289, 2290,
	2290, 2291, 2292, 2286, 2089, 2201, 2201, 2202,
	2203, 2206, 2207, 2208, 2209, 2209, 2210, 2211,
	2293, 2089, 2212, 2212, 2213, 2214, 2216, 2217,
	2198, 2198, 2218, 2219, 2089, 2295, 2294, 2089,
	2296, 2296, 2297, 2298, 2300, 2301, 2302, 2303,
	2303, 2304, 2305, 2299, 2089, 2181, 2181, 2182,
	2183, 2186, 2187, 2188, 2189, 2189, 2190, 2191,
	2306, 2089, 2192, 2192, 2193, 2194, 2196, 2197,
	2198, 2198, 2199, 2200, 2089, 2308, 2307, 2089,
	2309, 2309, 2310, 2311, 2312, 2313, 2089, 2315,
	2314, 2089, 2316, 2316, 2317, 2318, 2320, 2321,
	2319, 2089, 2161, 2161, 2162, 2163, 2166, 2167,
	2322, 2089, 2324, 2323, 2089, 2326, 2325, 2089,
	2328, 2327, 2089, 2329, 2329, 2330, 2331, 2332,
	2333, 2089, 2335, 2334, 2089, 2336, 2336, 2337,
	2338, 2340, 2341, 2339, 2089, 2117, 2117, 2118,
	2119, 2122, 2123, 2342, 2089, 2344, 2343, 2089,
	2346, 2345, 2089, 2347, 1881, 2348, 2348, 2349,
	2350, 2352, 2353, 2351, 1881, 2354, 2354, 2355,
	2356, 2358, 2359, 2357, 1881, 2360, 2360, 2361,
	2362, 2364, 2365, 2363, 1881, 2366, 2366, 2367,
	2368, 2370, 2371, 2369, 1881, 2372, 2372, 2373,
	2374, 2376, 2377, 2375, 1881, 2378, 2378, 2379,
	2380, 2381, 2381, 2381, 2382, 2383, 2381, 2381,
	2381, 71, 2384, 2384, 2384, 2384, 71, 2386,
	2385, 71, 2388, 2387, 71, 2390, 2389, 71,
	2391, 1881, 2392, 2392, 2393, 2394, 2396, 2397,
	2395, 1881, 2398, 2398, 2399, 2400, 2402, 2403,
	2401, 1881, 2404, 2404, 2405, 2406, 2408, 2409,
	2407, 1881, 2411, 2411, 2412, 2413, 2414, 2415,
	2410, 2410, 2410, 71, 2416, 2416, 2417, 2418,
	2419, 2420, 71, 2422, 2422, 2423, 2424, 2425,
	2426, 2421, 2421, 2421, 71, 2427, 2427, 2428,
	2429, 2430, 2431, 71, 2433, 2433, 2434, 2435,
	2436, 2437, 2432, 2432, 2432, 71, 2438, 2438,
	2439, 2440, 2441, 2442, 71, 2443, 2443, 2444,
	2445, 2446, 2446, 2446, 2447, 2448, 2446, 2446,
	2446, 71, 2449, 2449, 2449, 2449, 71, 2451,
	2450, 71, 2453, 2452, 71, 2455, 2454, 71,
	2457, 2456, 71, 2459, 2458, 71, 2460, 2460,
	2460, 71, 2461, 2461, 2462, 2463, 2464, 2465,
	71, 2461, 2461, 2462, 2463, 2464, 2465, 2466,
	1881, 2467, 2467, 2468, 2469, 2471, 2472, 2470,
	1881, 2473, 2473, 2474, 2475, 2477, 2478, 2476,
	2476, 2476, 71, 2479, 2479, 2480, 2481, 2482,
	2483, 71, 2479, 2479, 2480, 2481, 2484, 2482,
	2483, 2484, 2484, 2484, 71, 2485, 2485, 71,
	2487, 2486, 71, 2489, 2488, 71, 2491, 2490,
	71, 2493, 2493, 2494, 2495, 2496, 2497, 2498,
	2499, 2500, 2501, 2501, 2502, 2503, 2492, 2504,
	2505, 2492, 2506, 2492, 2508, 2508, 2507, 2510,
	2509, 2507, 2511, 2492, 2512, 2512, 2513, 2514,
	2516, 2517, 2518, 2518, 2519, 2520, 2515, 2492,
	2522, 2521, 71, 2523, 2492, 2524, 2524, 2524,
	2524, 2507, 2526, 2525, 2525, 2525, 2507, 2527,
	1881, 2528, 2528, 2529, 2530, 2532, 2533, 2531,
	1881, 2534, 2534, 2535, 2536, 2538, 2539, 2537,
	2537, 2537, 71, 2540, 2540, 2541, 2542, 2543,
	2544, 71, 2540, 2540, 2541, 2542, 2543, 2544,
	2545, 1881, 2546, 2546, 2547, 2548, 2550, 2551,
	2549, 1881, 2553, 2553, 2554, 2555, 2557, 2558,
	2556, 2556, 2556, 2552, 2559, 2559, 2559, 2552,
	2560, 2560, 2561, 2562, 2563, 2564, 2565, 2565,
	2566, 2567, 2556, 2556, 2556, 2552, 2569, 2568,
	2552, 2571, 2570, 71, 2573, 2572, 71, 2575,
	2574, 71, 2576, 1881, 2577, 2577, 2578, 2579,
	2581, 2582, 2580, 1881, 2583, 2583, 2584, 2585,
	2587, 2588, 2586, 1881, 2589, 2589, 2590, 2591,
	2593, 2594, 2592, 1881, 2595, 2595, 2596, 2597,
	2599, 2600, 2598, 2598, 2598, 2552, 2601, 2601,
	2601, 2552, 2602, 2602, 2603, 2604, 2605, 2606,
	2607, 2607, 2608, 2609, 2598, 2598, 2598, 2552,
	2611, 2610, 2552, 2613, 2612, 71, 2615, 2614,
	71, 2616, 1881, 2617, 2617, 2618, 2619, 2621,
	2622, 2620, 1881, 2624, 2624, 2625, 2626, 2627,
	2628, 2629, 2630, 2631, 2632, 2623, 2633, 2633,
	2634, 2635, 2636, 2637, 2623, 2633, 2633, 2634,
	2635, 2636, 2637, 2639, 2638, 2640, 2640, 2641,
	2642, 2644, 2645, 2643, 2638, 2646, 2646, 2647,
	2648, 2649, 2650, 2651, 2623, 2653, 2653, 2654,
	2655, 2656, 2656, 2657, 2658, 2659, 2659, 2660,
	2661, 2662, 2662, 2662, 2662, 2663, 2664, 2662,
	2662, 2665, 2666, 2667, 2668, 2662, 2662, 2669,
	2670, 2671, 2672, 2662, 2662, 2673, 2674, 2652,
	2653, 2653, 2654, 2655, 2676, 2663, 2664, 2676,
	2676, 2676, 2675, 2662, 2662, 2675, 2678, 2677,
	2675, 2656, 2656, 2657, 2658, 2662, 2662, 2662,
	2662, 2667, 2668, 2662, 2662, 2669, 2670, 2675,
	2680, 2679, 2675, 2676, 2653, 2653, 2654, 2655,
	2656, 2656, 2657, 2658, 2659, 2659, 2660, 2661,
	2662, 2662, 2662, 2662, 2663, 2664, 2662, 2662,
	2665, 2666, 2667, 2668, 2662, 2662, 2669, 2670,
	2671, 2672, 2662, 2662, 2673, 2674, 2676, 2676,
	2676, 2675, 2678, 2680, 2682, 2677, 2679, 2681,
	2675, 2684, 2683, 2623, 2686, 2685, 2623, 2687,
	2687, 2688, 2689, 2690, 2691, 2623, 2687, 2687,
	2688, 2689, 2690, 2691, 2692, 2638, 2693, 2693,
	2694, 2695, 2697, 2698, 2696, 2638, 2700, 2700,
	2701, 2702, 2703, 2704, 2705, 2703, 2699, 2707,
	2708, 2708, 2709, 2710, 2711, 2711, 2712, 2713,
	2714, 2714, 2715, 2716, 2717, 2717, 2717, 2717,
	2718, 2719, 2717, 2717, 2720, 2721, 2722, 2723,
	2717, 2717, 2724, 2725, 2726, 2727, 2717, 2717,
	2728, 2729, 2707, 2706, 2731, 2730, 2623, 2733,
	2732, 2623, 2734, 2734, 2735, 2736, 2737, 2738,
	2623, 2734, 2734, 2735, 2736, 2737, 2738, 2739,
	2638, 2740, 2740, 2741, 2742, 2744, 2745, 2743,
	2638, 2746, 2746, 2747, 2748, 2749, 2750, 2751,
	2749, 2749, 2749, 2699, 2752, 2753, 2753, 2754,
	2755, 2756, 2756, 2757, 2758, 2759, 2759, 2760,
	2761, 2762, 2762, 2762, 2762, 2763, 2764, 2762,
	2762, 2765, 2766, 2767, 2768, 2762, 2762, 2769,
	2770, 2771, 2772, 2762, 2762, 2773, 2774, 2752,
	2752, 2752, 2706, 2776, 2775, 2623, 2778, 2777,
	2623, 2779, 2779, 2780, 2781, 2782, 2783, 2623,
	2779, 2779, 2780, 2781, 2782, 2783, 2784, 2638,
	2785, 2785, 2786, 2787, 2789, 2790, 2788, 2638,
	2791, 2791, 2792, 2793, 2794, 2794, 2794, 2795,
	2796, 2794, 2794, 2794, 2623, 2797, 2797, 2798,
	2799, 2800, 2800, 2801, 2802, 2803, 2803, 2804,
	2805, 2806, 2806, 2806, 2806, 2807, 2808, 2806,
	2806, 2809, 2810, 2811, 2812, 2806, 2806, 2813,
	2814, 2815, 2816, 2806, 2806, 2817, 2818, 2652,
	2820, 2819, 2623, 2822, 2821, 2623, 2824, 2823,
	71, 2826, 2827, 2828, 2829, 2830, 2831, 2832,
	2833, 2834, 2835, 2836, 2837, 2838, 2839, 2840,
	2826, 2827, 2828, 2829, 2830, 2831, 2832, 2833,
	2834, 2835, 2836, 2837, 2838, 2839, 2840, 2825,
	2841, 2841, 2842, 2843, 2844, 2845, 2846, 2844,
	2845, 2846, 2847, 2848, 2825, 2849, 2849, 2850,
	2851, 2853, 2854, 2852, 2852, 2852, 71, 2855,
	2855, 2856, 2857, 2858, 2859, 71, 2855, 2855,
	2856, 2857, 2858, 2859, 2860, 1881, 2861, 2861,
	2862, 2863, 2865, 2866, 2864, 1881, 2867, 2867,
	2868, 2869, 2871, 2872, 2870, 1881, 2873, 2873,
	2874, 2875, 2877, 2878, 2876, 1881, 2880, 2880,
	2881, 2882, 2884, 2885, 2883, 2879, 2886, 2886,
	2887, 2888, 2890, 2891, 2889, 2879, 2892, 2892,
	2893, 2894, 2896, 2897, 2895, 2879, 2898, 2898,
	2899, 2900, 2902, 2903, 2901, 2879, 2904, 2904,
	2905, 2906, 2908, 2909, 2907, 1881, 2910, 2910,
	2911, 2912, 2914, 2915, 2913, 1881, 2916, 2916,
	2917, 2918, 2919, 2919, 2919, 2920, 2921, 2919,
	2919, 2919, 71, 2922, 2922, 2923, 2924, 2925,
	2926, 71, 2927, 2927, 2928, 2929, 2930, 2931,
	2932, 2930, 2930, 2930, 71, 2933, 2933, 71,
	2935, 2934, 71, 2937, 2936, 71, 2939, 2938,
	71, 2941, 2940, 71, 2943, 2942, 71, 2945,
	2944, 71, 2947, 2946, 71, 2949, 2948, 71,
	2950, 2950, 2825, 2951, 2951, 2825, 2952, 2952,
	2953, 2954, 2955, 2956, 2825, 2957, 2957, 2825,
	2958, 2958, 2825, 2959, 2959, 2825, 2960, 2960,
	2961, 2962, 2963, 2964, 2825, 2965, 2965, 2825,
	2966, 2966, 2967, 2968, 2969, 2970, 2825, 2971,
	2972, 2973, 2974, 2971, 2972, 2973, 2974, 2825,
	2975, 2975, 2825, 2976, 2976, 2977, 2978, 2979,
	2980, 2825, 2981, 2982, 2981, 2982, 2825, 2983,
	2983, 2825, 2984, 2984, 2825, 2985, 2985, 2825,
	2986, 2986, 2825, 2987, 2987, 2988, 2989, 2990,
	2991, 2825, 2992, 2992, 2993, 2994, 2995, 2996,
	2825, 2997, 2997, 2825, 2998, 2998, 2825, 2999,
	2999, 3000, 3001, 3002, 3003, 2825, 3004, 3004,
	2825, 3005, 3005, 2825, 3006, 3006, 2825, 3007,
	3007, 3008, 3009, 3010, 3011, 2825, 3012, 3013,
	3014, 3012, 3013, 3014, 2825, 3015, 3015, 2825,
	3016, 3016, 2825, 3017, 3017, 2825, 3018, 3018,
	3019, 3020, 3021, 3022, 2825, 3023, 3024, 3023,
	3024, 2825, 3025, 3025, 2825, 3026, 3026, 2825,
	3027, 3027, 3028, 3029, 3030, 3031, 2825, 3032,
	3032, 2825, 3033, 3033, 2825, 3034, 3034, 2825,
	3035, 3035, 3036, 3037, 3038, 3039, 2825, 3040,
	3040, 3041, 3042, 3043, 3044, 2825, 3045, 3045,
	2825, 3046, 3046, 2825, 3047, 3048, 2825, 3049,
	2825, 3050, 3050, 3051, 3052, 3053, 3054, 2825,
	3055, 2825, 3056, 3056, 3057, 3058, 3059, 3060,
	2825, 3061, 3061, 2825, 3062, 3062, 2825, 3063,
	3063, 2825, 3064, 3064, 2825, 3065, 3065, 3066,
	3067, 3068, 3069, 2825, 3070, 3070, 2825, 3071,
	3071, 2825, 3072, 3072, 2825, 3073, 3073, 2825,
	3074, 3074, 2825, 3075, 3075, 2825, 3076, 3076,
	2825, 3077, 3077, 3078, 3079, 3080, 3081, 2825,
	3082, 3083, 3082, 3083, 2825, 3084, 3084, 2825,
	3085, 3085, 3086, 3087, 3088, 3089, 2825, 3090,
	3090, 3091, 3092, 3093, 3094, 2825, 3095, 3096,
	3097, 3098, 3097, 3098, 2825, 3099, 2825, 3100,
	3100, 3101, 3102, 3103, 3104, 2825, 3105, 2825,
	3106, 3106, 3107, 3108, 3109, 3110, 2825, 3111,
	3111, 2825, 3112, 3112, 3113, 3114, 3115, 3116,
	2825, 3117, 3117, 3118, 3119, 3120, 3121, 2825,
	3122, 3123, 3122, 3123, 2825, 3124, 3124, 2825,
	3125, 3125, 2825, 3126, 3126, 2825, 3127, 3127,
	3128, 3129, 3130, 3131, 2825, 3132, 3132, 3133,
	3134, 3135, 3136, 2825, 3137, 3138, 3139, 3137,
	3138, 3139, 2825, 3140, 3140, 2825, 3141, 3141,
	2825, 3142, 3142, 2825, 3143, 3143, 3144, 3145,
	3146, 3147, 2825, 3148, 3148, 2825, 3149, 3149,
	3150, 3151, 3152, 3153, 2825, 3154, 3154, 3155,
	3156, 3157, 3157, 3158, 3159, 2825, 3160, 3160,
	2825, 3161, 3161, 3162, 3163, 3164, 3165, 3166,
	2825, 3167, 3167, 3168, 3169, 3170, 3170, 3171,
	3172, 2825, 3173, 3173, 2825, 3174, 3174, 2825,
	3175, 3175, 2825, 3176, 3176, 2825, 3177, 3177,
	3178, 3179, 3180, 3181, 2825, 3182, 3182, 2825,
	3183, 3183, 2825, 3184, 3184, 3185, 3186, 3187,
	3188, 2825, 3189, 3190, 3191, 3189, 3190, 3191,
	2825, 3192, 3192, 3193, 3194, 3195, 3196, 2825,
	3197, 3197, 2825, 3198, 3198, 2825, 3199, 3199,
	2825, 3200, 3200, 3201, 3202, 3203, 3204, 2825,
	3205, 3205, 3206, 3207, 3208, 3209, 2825, 3210,
	3211, 3212, 3213, 3210, 3211, 3212, 3213, 2825,
	3214, 3214, 2825, 3215, 3215, 3216, 3217, 3218,
	3219, 2825, 3220, 3220, 2825, 3221, 3221, 3222,
	3223, 3224, 3225, 2825, 3226, 3226, 2825, 3227,
	3227, 3228, 3229, 3230, 3231, 2825, 3232, 3232,
	2825, 3233, 3233, 2825, 3234, 3234, 2825, 3235,
	3235, 3236, 3237, 3238, 3239, 2825, 3240, 3241,
	3242, 3240, 3241, 3242, 2825, 3243, 3243, 2825,
	3244, 3244, 2825, 3245, 3245, 3246, 3247, 3248,
	3249, 2825, 3250, 3250, 2825, 3251, 3251, 3252,
	3253, 3254, 3255, 2825, 3256, 3256, 2825, 3257,
	3257, 2825, 3259, 3258, 3260, 3260, 3261, 3262,
	3264, 3265, 3263, 3258, 3266, 3266, 2825, 3267,
	3267, 2825, 3268, 3268, 3269, 3270, 3271, 3272,
	2825, 3273, 3273, 3273, 3273, 3273, 3273, 71,
	3274, 3274, 3274, 3274, 71, 3275, 3275, 3275,
	3275, 71, 3276, 1881, 3277, 3277, 3278, 3279,
	3281, 3282, 3280, 1881, 3283, 3283, 3284, 3285,
	3287, 3288, 3286, 1881, 3289, 3289, 3290, 3291,
	3293, 3294, 3292, 1881, 3295, 3295, 3296, 3297,
	3299, 3300, 3298, 3298, 3298, 71, 3301, 3301,
	3302, 3303, 3304, 3305, 71, 3301, 3301, 3302,
	3303, 3306, 3304, 3305, 3306, 3306, 3306, 71,
	3307, 3307, 71, 3309, 3308, 71, 3311, 3310,
	71, 3313, 3312, 71, 3314, 3314, 3314, 3314,
	71, 3315, 3315, 71, 3316, 1881, 3317, 3317,
	3318, 3319, 3321, 3322, 3320, 1881, 3323, 3323,
	3324, 3325, 3327, 3328, 3326, 1881, 3329, 3329,
	3330, 3331, 3333, 3334, 3332, 1881, 3335, 3335,
	3336, 3337, 3339, 3340, 3338, 1881, 3341, 3341,
	3342, 3343, 3345, 3346, 3344, 1881, 3347, 3347,
	3348, 3349, 3350, 3352, 3353, 3351, 3351, 3351,
	2552, 3354, 3354, 3355, 3356, 3357, 3358, 2552,
	3360, 3360, 3361, 3362, 3364, 3365, 3363, 3363,
	3363, 3359, 3366, 3366, 3366, 3359, 3368, 3367,
	3367, 3367, 3359, 3369, 3369, 3369, 3359, 3371,
	3370, 3370, 3370, 3359, 3373, 3372, 3372, 3372,
	3359, 3374, 3374, 3374, 3359, 3376, 3375, 3375,
	3375, 3359, 3377, 3377, 3377, 3377, 3378, 3378,
	3378, 3359, 3379, 3379, 3379, 3379, 71, 3380,
	3359, 3376, 3359, 3373, 3359, 3381, 3359, 3371,
	3359, 3383, 3382, 71, 3384, 3384, 3384, 2552,
	3354, 3354, 3355, 3356, 3357, 3358, 3385, 3385,
	3385, 2552, 3387, 3386, 71, 3389, 3388, 71,
	3391, 3390, 71, 3392, 1881, 3393, 3393, 3394,
	3395, 3397, 3398, 3396, 1881, 3399, 3399, 3400,
	3401, 3403, 3404, 3402, 1881, 3405, 3405, 3406,
	3407, 3409, 3410, 3408, 1881, 3411, 3411, 3412,
	3413, 3415, 3416, 3414, 1881, 3417, 3417, 3418,
	3419, 3421, 3422, 3420, 1881, 3423, 3423, 3424,
	3425, 3426, 3428, 3429, 3427, 3427, 3427, 2552,
	3430, 3430, 3430, 3430, 2552, 3431, 3431, 3431,
	2552, 3430, 3430, 3430, 3430, 3432, 3432, 3432,
	2552, 3434, 3433, 71, 3436, 3435, 71, 3438,
	3437, 71, 3439, 1881, 3440, 3440, 3441, 3442,
	3444, 3445, 3443, 1881, 3446, 3446, 3447, 3448,
	3450, 3451, 3449, 1881, 3452, 3452, 3453, 3454,
	3456, 3457, 3455, 1881, 3458, 3458, 3459, 3460,
	3462, 3463, 3461, 1881, 3464, 3464, 3465, 3466,
	3468, 3469, 3467, 1881, 3470, 3470, 3471, 3472,
	3474, 3475, 3473, 3473, 3473, 2552, 3476, 3476,
	3476, 2552, 3477, 3477, 3478, 3479, 3480, 3481,
	3482, 3482, 3483, 3484, 3473, 3473, 3473, 2552,
	3486, 3485, 2552, 3488, 3487, 71, 3490, 3489,
	71, 3492, 3491, 71, 3493, 1881, 3494, 3494,
	3495, 3496, 3498, 3499, 3497, 1881, 3500, 3500,
	3501, 3502, 3503, 3504, 3505, 3503, 1858, 3506,
	3507, 3506, 3506, 3506, 3507, 1858, 3509, 3508,
	71, 3510, 1881, 3511, 3511, 3512, 3513, 3515,
	3516, 3514, 1881, 3517, 3517, 3518, 3519, 3521,
	3522, 3520, 3520, 3520, 2552, 3523, 3523, 3523,
	2552, 3524, 3524, 3524, 2552, 3525, 3525, 3525,
	2552, 3527, 3526, 3528, 3528, 3528, 2552, 3529,
	3529, 3529, 2552, 3530, 3530, 3530, 2552, 3531,
	3531, 3531, 2552, 3533, 3527, 3533, 3533, 3533,
	3532, 3535, 3534, 71, 3536, 3536, 3536, 2552,
	3537, 3537, 3537, 2552, 3539, 3538, 3540, 3540,
	3540, 2552, 3541, 3541, 3541, 2552, 3542, 3539,
	3542, 3542, 3542, 3538, 3543, 3543, 3543, 2552,
	3544, 3544, 3544, 2552, 3545, 3538, 3546, 3546,
	3546, 2552, 3547, 3547, 3547, 2552, 3548, 3545,
	3548, 3548, 3548, 3538, 3549, 1881, 3550, 3550,
	3551, 3552, 3554, 3555, 3553, 1881, 3556, 3556,
	3557, 3558, 3560, 3561, 3559, 1881, 3562, 3562,
	3563, 3564, 3566, 3567, 3565, 1881, 3569, 3569,
	3570, 3571, 3572, 3573, 3568, 3568, 3568, 71,
	3574, 3574, 3574, 3574, 71, 3576, 3575, 71,
	3578, 3577, 71, 3579, 1881, 3580, 3580, 3581,
	3582, 3584, 3585, 3583, 1881, 3587, 3587, 3588,
	3589, 3590, 3591, 3586, 3586, 3586, 71, 3592,
	3592, 3593, 3594, 3595, 3596, 71, 3598, 3598,
	3599, 3600, 3601, 3602, 3597, 3597, 3597, 71,
	3603, 3603, 3603, 3603, 71, 3605, 3604, 71,
	3607, 3606, 71, 3609, 3609, 3610, 3611, 3612,
	3613, 3613, 3613, 3614, 3615, 3616, 3617, 3613,
	3613, 3613, 3608, 3618, 3618, 3619, 3620, 3621,
	3622, 69, 3623, 3622, 3614, 3615, 3624, 3625,
	3626, 3627, 3628, 3629, 69, 69, 3622, 69,
	3622, 69, 3622, 69, 781, 3631, 3631, 3610,
	3632, 3633, 3613, 3634, 3635, 3636, 3637, 3638,
	3639, 3640, 3641, 3642, 3643, 3644, 3645, 3646,
	3647, 3648, 3613, 3613, 3634, 3635, 3636, 3637,
	3638, 3639, 3640, 3641, 3642, 3643, 3644, 3645,
	3646, 3647, 3648, 3614, 3615, 3649, 3650, 3613,
	3613, 3613, 3630, 3631, 3631, 3610, 3632, 3633,
	3613, 3653, 3654, 3655, 3656, 3657, 3658, 3659,
	3660, 3661, 3662, 3663, 3664, 3665, 3666, 3667,
	3613, 3613, 3653, 3654, 3655, 3656, 3657, 3658,
	3659, 3660, 3661, 3662, 3663, 3664, 3665, 3666,
	3667, 3614, 3615, 3649, 3650, 3613, 3652, 3613,
	3613, 3651, 3669, 3669, 3670, 3671, 3672, 3673,
	3673, 3673, 3674, 3675, 3676, 3677, 3673, 3673,
	3673, 3668, 3609, 3609, 3610, 3678, 3679, 3613,
	3653, 3654, 3655, 3656, 3657, 3658, 3659, 3660,
	3661, 3662, 3663, 3664, 3665, 3666, 3667, 3613,
	3613, 3653, 3654, 3655, 3656, 3657, 3658, 3659,
	3660, 3661, 3662, 3663, 3664, 3665, 3666, 3667,
	3614, 3615, 3680, 3617, 3613, 3652, 3613, 3613,
	3651, 3681, 3681, 3610, 3682, 3683, 3613, 3613,
	3613, 83, 84, 3684, 3685, 3613, 3613, 3613,
	781, 3686, 3686, 3619, 3687, 3688, 3622, 69,
	3623, 3622, 83, 84, 3684, 3689, 101, 102,
	3684, 3690, 69, 69, 3622, 69, 3622, 69,
	3622, 69, 781, 3618, 3618, 3619, 3620, 3621,
	3622, 69, 3693, 3694, 3695, 3696, 3697, 3698,
	3699, 3700, 3701, 3702, 3703, 3704, 3705, 3706,
	3707, 3623, 3622, 3693, 3694, 3695, 3696, 3697,
	3698, 3699, 3700, 3701, 3702, 3703, 3704, 3705,
	3706, 3707, 3614, 3615, 3624, 3625, 3626, 3627,
	3628, 3629, 69, 69, 3622, 3692, 69, 3622,
	69, 3622, 69, 3691, 3686, 3686, 3619, 3687,
	3688, 3622, 69, 3693, 3694, 3695, 3696, 3697,
	3698, 3699, 3700, 3701, 3702, 3703, 3704, 3705,
	3706, 3707, 3623, 3622, 3693, 3694, 3695, 3696,
	3697, 3698, 3699, 3700, 3701, 3702, 3703, 3704,
	3705, 3706, 3707, 83, 84, 3708, 3689, 101,
	102, 3708, 3690, 69, 69, 3622, 3692, 69,
	3622, 69, 3622, 69, 3691, 689, 689, 689,
	940, 937, 940, 939, 940, 937, 941, 937,
	936, 689, 689, 689, 1089, 1089, 1090, 1091,
	1058, 1059, 1060, 1058, 1092, 1093, 1058, 1058,
	1058, 1064, 689, 1104, 1104, 1105, 1106, 1099,
	1107, 1108, 1109, 1109, 1110, 1111, 1099, 1099,
	1099, 1098, 1113, 1112, 1098, 689, 1123, 1123,
	1124, 1125, 1126, 1127, 1128, 1129, 1130, 1131,
	1132, 1133, 1134, 1135, 1136, 1137, 1138, 1139,
	1140, 1126, 1127, 1128, 1129, 1130, 1131, 1132,
	1133, 1134, 1135, 1136, 1137, 1138, 1139, 1140,
	1141, 1142, 1143, 1143, 1144, 1145, 1114, 1168,
	1167, 1114, 689, 1629, 1629, 1630, 1631, 1632,
	1633, 1634, 1634, 1635, 1636, 1625, 1625, 1625,
	1621, 1638, 1637, 1621, 1657, 1657, 1658, 1659,
	1661, 1662, 1660, 1660, 1660, 1621, 1607, 1664,
	1664, 1665, 1666, 1667, 1668, 1669, 1669, 1670,
	1671, 1660, 1660, 1660, 1621, 1673, 1672, 1621,
	1675, 1674, 1607, 689, 689, 689, 689, 689,
	689, 689, 689, 689, 2076, 2076, 2077, 2078,
	2079, 2080, 2081, 2081, 2082, 2083, 2075, 2075,
	2075, 2066, 2085, 2084, 2066, 689, 689, 2249,
	2249, 2250, 2251, 2252, 2253, 2198, 2198, 2254,
	2255, 2089, 2257, 2256, 2089, 2231, 2231, 2232,
	2233, 2235, 2236, 2198, 2198, 2237, 2238, 2234,
	2089, 2269, 2268, 2089, 2212, 2212, 2213, 2214,
	2216, 2217, 2198, 2198, 2218, 2219, 2215, 2089,
	2282, 2281, 2089, 2192, 2192, 2193, 2194, 2196,
	2197, 2198, 2198, 2199, 2200, 2195, 2089, 2295,
	2294, 2089, 689, 689, 689, 689, 2493, 2493,
	2494, 2495, 2496, 2497, 2498, 2499, 2500, 2501,
	2501, 2502, 2503, 2492, 2522, 2521, 71, 689,
	2560, 2560, 2561, 2562, 2563, 2564, 2565, 2565,
	2566, 2567, 2556, 2556, 2556, 2552, 2569, 2568,
	2552, 689, 2602, 2602, 2603, 2604, 2605, 2606,
	2607, 2607, 2608, 2609, 2598, 2598, 2598, 2552,
	2611, 2610, 2552, 689, 2656, 2656, 2657, 2658,
	2662, 2662, 2662, 2662, 2667, 2668, 2662, 2662,
	2669, 2670, 2675, 2680, 2679, 2675, 2653, 2653,
	2654, 2655, 2676, 2663, 2664, 2676, 2676, 2676,
	2675, 2678, 2677, 2675, 2676, 2653, 2653, 2654,
	2655, 2656, 2656, 2657, 2658, 2659, 2659, 2660,
	2661, 2662, 2662, 2662, 2662, 2663, 2664, 2662,
	2662, 2665, 2666, 2667, 2668, 2662, 2662, 2669,
	2670, 2671, 2672, 2662, 2662, 2673, 2674, 2676,
	2676, 2676, 2675, 2678, 2680, 2682, 2677, 2679,
	2681, 2675, 689, 689, 689, 689, 689, 689,
	689, 3477, 3477, 3478, 3479, 3480, 3481, 3482,
	3482, 3483, 3484, 3473, 3473, 3473, 2552, 3486,
	3485, 2552, 689, 689, 689, 689, 689, 689,
	0
};

static const short _zone_scanner_trans_targs[] = {
	0, 1, 1, 1, 2, 4, 17, 36,
	50, 57, 143, 73, 77, 85, 91, 107,
	110, 117, 128, 138, 1127, 151, 1132, 264,
	0, 3, 3, 3, 2, 166, 166, 166,
	166, 166, 3, 169, 0, 3, 3, 3,
	4, 17, 36, 50, 57, 62, 73, 77,
	85, 91, 107, 110, 117, 128, 138, 3,
	169, 0, 5, 5, 5, 230, 233, 237,
	5, 10, 6, 11, 20, 6, 5, 0,
	5, 5, 9, 5, 10, 11, 20, 0,
	7, 7, 7, 1127, 8, 0, 7, 7,
	7, 1127, 8, 8, 1127, 6, 6, 10,
	5, 12, 12, 12, 13, 1133, 176, 244,
	12, 12, 12, 13, 1133, 176, 244, 13,
	1128, 14, 0, 14, 14, 15, 172, 179,
	180, 181, 182, 183, 184, 185, 186, 187,
	188, 189, 190, 191, 192, 1135, 239, 1133,
	240, 1136, 242, 0, 16, 16, 16, 1129,
	267, 0, 16, 16, 16, 1129, 267, 18,
	22, 29, 32, 19, 5, 5, 5, 5,
	10, 6, 11, 20, 21, 21, 21, 13,
	21, 21, 21, 23, 28, 24, 25, 26,
	27, 5, 5, 5, 5, 10, 6, 11,
	20, 5, 5, 5, 5, 10, 6, 11,
	20, 30, 31, 5, 5, 5, 5, 10,
	6, 11, 20, 33, 34, 35, 5, 5,
	5, 5, 10, 6, 11, 20, 37, 41,
	49, 38, 39, 40, 5, 5, 5, 5,
	10, 6, 11, 20, 42, 45, 43, 44,
	5, 5, 5, 5, 10, 6, 11, 20,
	46, 47, 48, 5, 5, 5, 5, 10,
	6, 11, 20, 5, 5, 5, 5, 10,
	6, 11, 20, 51, 52, 53, 55, 54,
	5, 5, 5, 5, 10, 6, 11, 20,
	56, 5, 5, 5, 5, 10, 6, 11,
	20, 58, 59, 60, 61, 5, 5, 5,
	5, 10, 6, 11, 20, 63, 66, 64,
	64, 64, 64, 141, 64, 64, 64, 4,
	17, 36, 50, 57, 65, 73, 77, 85,
	91, 107, 110, 117, 128, 138, 64, 141,
	67, 68, 69, 70, 71, 72, 5, 5,
	5, 5, 10, 6, 11, 20, 74, 76,
	75, 5, 5, 5, 5, 10, 6, 11,
	20, 5, 5, 5, 5, 10, 6, 11,
	20, 78, 80, 82, 84, 79, 5, 5,
	5, 5, 10, 6, 11, 20, 81, 5,
	5, 5, 5, 10, 6, 11, 20, 83,
	5, 5, 5, 5, 10, 6, 11, 20,
	5, 5, 5, 5, 10, 6, 11, 20,
	86, 90, 87, 88, 89, 5, 5, 5,
	5, 10, 6, 11, 20, 5, 5, 5,
	5, 10, 6, 11, 20, 92, 96, 98,
	93, 94, 95, 5, 5, 5, 5, 10,
	6, 11, 20, 97, 5, 5, 5, 5,
	10, 6, 11, 20, 5, 5, 5, 99,
	5, 10, 6, 11, 20, 100, 5, 5,
	5, 101, 5, 10, 6, 11, 20, 5,
	5, 5, 102, 5, 10, 6, 11, 20,
	103, 104, 105, 106, 5, 5, 5, 5,
	10, 6, 11, 20, 108, 109, 5, 5,
	5, 5, 10, 6, 11, 20, 111, 112,
	116, 5, 5, 5, 5, 10, 6, 11,
	20, 113, 114, 115, 5, 5, 5, 5,
	10, 6, 11, 20, 5, 5, 5, 5,
	10, 6, 11, 20, 118, 120, 122, 124,
	119, 5, 5, 5, 5, 10, 6, 11,
	20, 121, 5, 5, 5, 5, 10, 6,
	11, 20, 123, 5, 5, 5, 5, 10,
	6, 11, 20, 125, 126, 127, 5, 5,
	5, 5, 10, 6, 11, 20, 129, 132,
	134, 130, 131, 5, 5, 5, 5, 10,
	6, 11, 20, 133, 5, 5, 5, 5,
	10, 6, 11, 20, 135, 136, 0, 137,
	0, 5, 5, 5, 137, 5, 10, 6,
	11, 20, 139, 140, 5, 5, 5, 5,
	10, 6, 11, 20, 141, 64, 142, 142,
	142, 1130, 265, 144, 145, 145, 145, 145,
	150, 145, 145, 145, 146, 4, 17, 36,
	50, 57, 65, 73, 77, 85, 91, 107,
	110, 117, 128, 138, 145, 150, 64, 64,
	64, 146, 147, 147, 147, 147, 147, 64,
	141, 148, 148, 149, 149, 149, 149, 149,
	64, 64, 64, 148, 64, 141, 150, 145,
	151, 1127, 0, 153, 195, 201, 154, 155,
	156, 157, 158, 159, 1131, 0, 161, 161,
	161, 161, 162, 161, 161, 161, 161, 162,
	162, 0, 161, 0, 164, 164, 164, 164,
	165, 164, 164, 164, 164, 165, 165, 164,
	167, 167, 168, 168, 168, 168, 168, 3,
	3, 3, 167, 3, 169, 169, 3, 0,
	171, 171, 171, 171, 246, 247, 248, 171,
	171, 171, 171, 246, 247, 248, 0, 173,
	173, 173, 1128, 13, 1133, 176, 1134, 244,
	173, 173, 173, 1128, 1134, 174, 174, 174,
	1132, 175, 175, 1132, 177, 177, 177, 1127,
	8, 177, 177, 177, 178, 178, 178, 193,
	228, 193, 1135, 0, 196, 197, 198, 199,
	200, 1131, 202, 203, 1131, 0, 174, 174,
	174, 1132, 175, 0, 206, 206, 206, 1130,
	207, 206, 206, 206, 1130, 207, 207, 1130,
	0, 209, 209, 209, 1135, 193, 1136, 228,
	209, 209, 209, 1135, 1136, 225, 0, 225,
	225, 225, 226, 174, 174, 174, 1132, 175,
	227, 1132, 227, 227, 175, 227, 227, 227,
	229, 229, 229, 193, 229, 229, 229, 231,
	232, 5, 5, 5, 5, 10, 6, 11,
	20, 234, 235, 236, 5, 5, 5, 5,
	10, 6, 11, 20, 238, 5, 5, 5,
	5, 10, 6, 11, 20, 239, 1135, 241,
	241, 241, 1127, 241, 241, 241, 1127, 243,
	243, 243, 243, 243, 243, 245, 245, 245,
	245, 245, 245, 246, 171, 178, 178, 178,
	193, 228, 249, 249, 249, 249, 249, 249,
	0, 264, 1132, 265, 1130, 267, 1129, 269,
	1137, 269, 1137, 0, 271, 277, 278, 273,
	1138, 271, 272, 273, 1138, 271, 273, 274,
	0, 275, 276, 1138, 271, 272, 273, 1138,
	0, 280, 285, 281, 1139, 1140, 0, 282,
	283, 284, 1139, 280, 1140, 281, 285, 286,
	287, 0, 288, 289, 290, 285, 286, 287,
	0, 292, 292, 292, 292, 299, 0, 293,
	0, 294, 294, 294, 293, 296, 296, 296,
	296, 296, 1141, 295, 0, 294, 294, 294,
	1141, 295, 295, 1141, 297, 0, 297, 298,
	298, 298, 298, 298, 294, 294, 294, 297,
	1141, 295, 299, 292, 0, 301, 301, 301,
	301, 311, 302, 310, 306, 302, 303, 306,
	0, 304, 304, 304, 302, 306, 1142, 305,
	304, 304, 304, 1142, 305, 305, 1142, 307,
	0, 308, 309, 302, 303, 306, 311, 301,
	313, 313, 313, 313, 328, 314, 0, 0,
	315, 315, 315, 1143, 319, 325, 0, 315,
	315, 315, 316, 324, 320, 1143, 319, 325,
	0, 316, 317, 320, 318, 318, 318, 316,
	320, 1143, 319, 318, 318, 318, 319, 1143,
	321, 0, 322, 323, 316, 317, 320, 325,
	1144, 326, 326, 326, 326, 327, 327, 326,
	328, 313, 0, 330, 331, 332, 335, 333,
	333, 333, 333, 333, 334, 1145, 1146, 1147,
	334, 333, 0, 337, 337, 337, 337, 342,
	1148, 1149, 1150, 337, 337, 337, 338, 343,
	360, 374, 381, 386, 394, 398, 406, 412,
	428, 431, 438, 449, 459, 337, 342, 1148,
	1149, 1150, 337, 337, 337, 339, 462, 466,
	337, 342, 1148, 1149, 1150, 340, 341, 337,
	337, 337, 337, 342, 1148, 1149, 1150, 342,
	337, 344, 346, 353, 356, 345, 337, 337,
	337, 337, 342, 1148, 1149, 1150, 347, 352,
	348, 349, 350, 351, 337, 337, 337, 337,
	342, 1148, 1149, 1150, 337, 337, 337, 337,
	342, 1148, 1149, 1150, 354, 355, 337, 337,
	337, 337, 342, 1148, 1149, 1150, 357, 358,
	359, 337, 337, 337, 337, 342, 1148, 1149,
	1150, 361, 365, 373, 362, 363, 364, 337,
	337, 337, 337, 342, 1148, 1149, 1150, 366,
	369, 367, 368, 337, 337, 337, 337, 342,
	1148, 1149, 1150, 370, 371, 372, 337, 337,
	337, 337, 342, 1148, 1149, 1150, 337, 337,
	337, 337, 342, 1148, 1149, 1150, 375, 376,
	377, 379, 378, 337, 337, 337, 337, 342,
	1148, 1149, 1150, 380, 337, 337, 337, 337,
	342, 1148, 1149, 1150, 382, 383, 384, 385,
	337, 337, 337, 337, 342, 1148, 1149, 1150,
	387, 388, 389, 390, 391, 392, 393, 337,
	337, 337, 337, 342, 1148, 1149, 1150, 395,
	397, 396, 337, 337, 337, 337, 342, 1148,
	1149, 1150, 337, 337, 337, 337, 342, 1148,
	1149, 1150, 399, 401, 403, 405, 400, 337,
	337, 337, 337, 342, 1148, 1149, 1150, 402,
	337, 337, 337, 337, 342, 1148, 1149, 1150,
	404, 337, 337, 337, 337, 342, 1148, 1149,
	1150, 337, 337, 337, 337, 342, 1148, 1149,
	1150, 407, 411, 408, 409, 410, 337, 337,
	337, 337, 342, 1148, 1149, 1150, 337, 337,
	337, 337, 342, 1148, 1149, 1150, 413, 417,
	419, 414, 415, 416, 337, 337, 337, 337,
	342, 1148, 1149, 1150, 418, 337, 337, 337,
	337, 342, 1148, 1149, 1150, 337, 337, 337,
	420, 337, 342, 1148, 1149, 1150, 421, 337,
	337, 337, 422, 337, 342, 1148, 1149, 1150,
	337, 337, 337, 423, 337, 342, 1148, 1149,
	1150, 424, 425, 426, 427, 337, 337, 337,
	337, 342, 1148, 1149, 1150, 429, 430, 337,
	337, 337, 337, 342, 1148, 1149, 1150, 432,
	433, 437, 337, 337, 337, 337, 342, 1148,
	1149, 1150, 434, 435, 436, 337, 337, 337,
	337, 342, 1148, 1149, 1150, 337, 337, 337,
	337, 342, 1148, 1149, 1150, 439, 441, 443,
	445, 440, 337, 337, 337, 337, 342, 1148,
	1149, 1150, 442, 337, 337, 337, 337, 342,
	1148, 1149, 1150, 444, 337, 337, 337, 337,
	342, 1148, 1149, 1150, 446, 447, 448, 337,
	337, 337, 337, 342, 1148, 1149, 1150, 450,
	453, 455, 451, 452, 337, 337, 337, 337,
	342, 1148, 1149, 1150, 454, 337, 337, 337,
	337, 342, 1148, 1149, 1150, 456, 457, 458,
	337, 337, 337, 458, 337, 342, 1148, 1149,
	1150, 460, 461, 337, 337, 337, 337, 342,
	1148, 1149, 1150, 463, 464, 465, 337, 337,
	337, 337, 342, 1148, 1149, 1150, 467, 337,
	337, 337, 337, 342, 1148, 1149, 1150, 0,
	469, 469, 469, 469, 476, 0, 470, 471,
	471, 471, 470, 471, 475, 0, 471, 471,
	471, 472, 471, 475, 473, 473, 473, 473,
	473, 474, 1151, 1152, 1153, 474, 473, 475,
	471, 476, 469, 478, 478, 478, 478, 486,
	479, 485, 1154, 1154, 1154, 485, 1155, 1154,
	1158, 480, 480, 480, 481, 480, 484, 482,
	482, 482, 482, 482, 483, 1155, 1156, 1157,
	483, 482, 484, 480, 480, 480, 480, 480,
	484, 486, 478, 0, 488, 489, 504, 543,
	551, 564, 1159, 488, 490, 491, 1159, 492,
	1159, 493, 494, 495, 496, 497, 498, 499,
	500, 501, 502, 503, 1159, 505, 534, 506,
	512, 507, 508, 509, 510, 511, 1159, 513,
	514, 515, 516, 525, 517, 518, 519, 520,
	521, 522, 523, 524, 1159, 526, 527, 528,
	529, 530, 531, 532, 533, 1159, 535, 540,
	536, 537, 538, 539, 1159, 541, 542, 1159,
	544, 545, 546, 547, 548, 549, 550, 1159,
	552, 553, 554, 555, 556, 557, 558, 561,
	559, 560, 1159, 562, 563, 1159, 565, 566,
	567, 570, 568, 569, 1159, 571, 572, 573,
	585, 588, 1159, 574, 575, 576, 577, 578,
	579, 580, 581, 582, 583, 584, 1159, 586,
	587, 1159, 589, 590, 1159, 0, 592, 593,
	599, 616, 619, 625, 629, 1160, 592, 594,
	595, 596, 597, 598, 1160, 600, 606, 612,
	601, 602, 603, 604, 605, 1160, 607, 609,
	608, 1160, 610, 611, 1160, 613, 614, 615,
	1160, 617, 618, 1160, 620, 622, 621, 1160,
	623, 624, 1160, 626, 627, 628, 1160, 630,
	631, 1160, 0, 633, 1161, 633, 635, 1162,
	637, 638, 638, 638, 638, 667, 638, 638,
	638, 639, 638, 667, 640, 640, 640, 640,
	666, 0, 640, 640, 640, 641, 640, 666,
	642, 642, 642, 641, 642, 665, 642, 642,
	642, 643, 642, 665, 0, 644, 644, 644,
	643, 662, 662, 662, 662, 662, 644, 661,
	644, 644, 644, 645, 644, 661, 646, 646,
	646, 645, 658, 658, 658, 658, 658, 646,
	657, 646, 646, 646, 647, 646, 657, 648,
	648, 648, 647, 654, 654, 654, 654, 654,
	648, 653, 648, 648, 648, 649, 648, 653,
	1163, 649, 650, 650, 650, 650, 650, 651,
	651, 652, 652, 652, 652, 652, 1163, 651,
	653, 648, 655, 655, 656, 656, 656, 656,
	656, 648, 648, 648, 655, 648, 653, 657,
	646, 659, 659, 660, 660, 660, 660, 660,
	646, 646, 646, 659, 646, 657, 661, 644,
	663, 663, 664, 664, 664, 664, 664, 644,
	644, 644, 663, 644, 661, 665, 642, 666,
	640, 667, 638, 669, 670, 670, 670, 670,
	672, 671, 670, 670, 670, 670, 672, 1164,
	672, 670, 674, 675, 675, 675, 675, 677,
	675, 675, 675, 676, 675, 677, 1165, 677,
	675, 679, 680, 680, 680, 679, 680, 682,
	680, 680, 680, 681, 680, 682, 1166, 682,
	680, 684, 0, 685, 685, 685, 685, 686,
	1167, 1168, 1169, 684, 685, 685, 685, 685,
	686, 1167, 1168, 1169, 686, 685, 688, 1170,
	688, 0, 690, 691, 691, 691, 690, 691,
	743, 691, 691, 691, 692, 696, 738, 691,
	743, 693, 693, 693, 692, 693, 742, 693,
	693, 693, 694, 693, 742, 695, 695, 695,
	740, 694, 695, 739, 695, 695, 695, 695,
	739, 697, 697, 697, 697, 737, 698, 699,
	699, 699, 698, 699, 736, 699, 699, 699,
	700, 704, 731, 699, 736, 701, 701, 701,
	700, 701, 735, 701, 701, 701, 702, 701,
	735, 703, 703, 703, 733, 702, 703, 732,
	703, 703, 703, 703, 732, 705, 705, 705,
	705, 730, 706, 707, 707, 708, 708, 708,
	727, 707, 729, 708, 726, 1171, 1178, 1179,
	708, 708, 708, 709, 708, 726, 1171, 1178,
	1179, 710, 710, 710, 723, 709, 725, 710,
	722, 1171, 1176, 1177, 710, 710, 710, 711,
	710, 722, 1176, 1177, 712, 712, 712, 719,
	711, 721, 712, 718, 1171, 1174, 1175, 712,
	712, 712, 713, 712, 718, 1174, 1175, 714,
	714, 714, 716, 713, 714, 715, 1171, 1172,
	1173, 714, 714, 714, 714, 715, 1172, 1173,
	715, 714, 714, 714, 714, 717, 714, 715,
	1171, 1172, 1173, 717, 718, 712, 712, 712,
	712, 720, 721, 712, 718, 1171, 1174, 1175,
	720, 722, 710, 710, 710, 710, 724, 725,
	710, 722, 1171, 1176, 1177, 724, 726, 708,
	708, 708, 708, 728, 729, 708, 726, 1171,
	1178, 1179, 728, 730, 705, 705, 705, 705,
	705, 730, 732, 703, 703, 703, 703, 734,
	703, 732, 734, 735, 701, 736, 699, 737,
	697, 697, 697, 697, 697, 737, 739, 695,
	695, 695, 695, 741, 695, 739, 741, 742,
	693, 743, 691, 745, 746, 746, 746, 745,
	746, 754, 746, 746, 746, 747, 746, 754,
	748, 748, 748, 747, 748, 753, 748, 748,
	748, 749, 748, 753, 750, 750, 750, 749,
	750, 752, 750, 750, 750, 751, 750, 752,
	1180, 752, 750, 753, 748, 754, 746, 756,
	757, 757, 757, 756, 757, 771, 757, 757,
	757, 758, 757, 771, 759, 759, 759, 758,
	759, 770, 760, 759, 759, 759, 759, 770,
	761, 761, 761, 761, 769, 762, 761, 761,
	761, 761, 769, 763, 763, 763, 763, 768,
	764, 763, 763, 763, 763, 768, 765, 765,
	765, 765, 767, 765, 765, 765, 766, 765,
	767, 1181, 767, 765, 768, 763, 769, 761,
	770, 759, 771, 757, 773, 774, 774, 774,
	774, 782, 775, 776, 776, 776, 775, 776,
	781, 776, 776, 776, 777, 776, 781, 778,
	778, 778, 778, 780, 779, 1182, 780, 778,
	781, 776, 782, 774, 0, 783, 784, 783,
	783, 785, 791, 783, 790, 1183, 1184, 1185,
	785, 791, 786, 0, 787, 787, 788, 789,
	783, 783, 783, 789, 783, 790, 1183, 1184,
	1185, 790, 783, 792, 793, 793, 788, 795,
	796, 796, 796, 795, 796, 806, 796, 796,
	796, 797, 796, 806, 798, 798, 798, 798,
	805, 799, 800, 800, 800, 799, 800, 804,
	0, 800, 800, 800, 801, 800, 804, 802,
	802, 802, 802, 802, 803, 1186, 1187, 1188,
	803, 802, 804, 800, 805, 798, 806, 796,
	808, 809, 809, 809, 808, 809, 816, 809,
	809, 809, 810, 809, 816, 811, 811, 811,
	810, 811, 815, 811, 811, 811, 812, 811,
	815, 813, 813, 813, 813, 813, 814, 1189,
	1190, 1191, 814, 813, 815, 811, 816, 809,
	818, 819, 819, 819, 818, 819, 855, 0,
	819, 819, 819, 820, 834, 841, 848, 819,
	855, 821, 821, 821, 821, 833, 0, 822,
	823, 823, 823, 822, 823, 832, 823, 823,
	823, 824, 823, 832, 0, 825, 825, 825,
	828, 828, 828, 830, 830, 830, 1192, 825,
	827, 1195, 1196, 828, 829, 1193, 1194, 830,
	831, 1197, 1198, 0, 826, 827, 825, 829,
	828, 831, 830, 832, 823, 833, 821, 835,
	835, 835, 835, 840, 836, 837, 837, 837,
	836, 837, 839, 0, 837, 837, 837, 838,
	837, 839, 0, 838, 825, 825, 825, 828,
	828, 828, 830, 830, 830, 1192, 825, 827,
	1195, 1196, 828, 829, 1193, 1194, 830, 831,
	1197, 1198, 839, 837, 840, 835, 842, 842,
	842, 842, 847, 843, 844, 844, 844, 843,
	844, 846, 844, 844, 844, 845, 844, 846,
	845, 825, 825, 825, 828, 828, 828, 830,
	830, 830, 1192, 825, 827, 1195, 1196, 828,
	829, 1193, 1194, 830, 831, 1197, 1198, 846,
	844, 847, 842, 849, 849, 849, 849, 854,
	850, 851, 851, 851, 850, 851, 853, 851,
	851, 851, 852, 851, 853, 825, 825, 825,
	828, 828, 828, 830, 830, 830, 1192, 825,
	827, 1195, 1196, 828, 829, 1193, 1194, 830,
	831, 1197, 1198, 853, 851, 854, 849, 855,
	819, 0, 857, 891, 908, 922, 929, 934,
	942, 946, 954, 960, 976, 979, 986, 997,
	1007, 858, 858, 858, 882, 885, 889, 858,
	881, 858, 858, 858, 859, 858, 881, 860,
	860, 860, 860, 880, 861, 862, 862, 862,
	861, 862, 879, 862, 862, 862, 863, 862,
	879, 864, 864, 864, 863, 864, 878, 0,
	864, 864, 864, 865, 864, 878, 866, 866,
	866, 865, 866, 877, 866, 866, 866, 867,
	866, 877, 868, 868, 868, 867, 868, 876,
	868, 868, 868, 869, 868, 876, 870, 870,
	870, 869, 870, 875, 870, 870, 870, 871,
	870, 875, 872, 872, 872, 872, 874, 872,
	872, 872, 873, 872, 874, 1199, 874, 872,
	875, 870, 876, 868, 877, 866, 878, 864,
	879, 862, 880, 860, 881, 858, 883, 884,
	858, 858, 858, 858, 881, 886, 887, 888,
	858, 858, 858, 858, 881, 890, 858, 858,
	858, 858, 881, 892, 894, 901, 904, 893,
	858, 858, 858, 858, 881, 895, 900, 896,
	897, 898, 899, 858, 858, 858, 858, 881,
	858, 858, 858, 858, 881, 902, 903, 858,
	858, 858, 858, 881, 905, 906, 907, 858,
	858, 858, 858, 881, 909, 913, 921, 910,
	911, 912, 858, 858, 858, 858, 881, 914,
	917, 915, 916, 858, 858, 858, 858, 881,
	918, 919, 920, 858, 858, 858, 858, 881,
	858, 858, 858, 858, 881, 923, 924, 925,
	927, 926, 858, 858, 858, 858, 881, 928,
	858, 858, 858, 858, 881, 930, 931, 932,
	933, 858, 858, 858, 858, 881, 935, 936,
	937, 938, 939, 940, 941, 858, 858, 858,
	858, 881, 943, 945, 944, 858, 858, 858,
	858, 881, 858, 858, 858, 858, 881, 947,
	949, 951, 953, 948, 858, 858, 858, 858,
	881, 950, 858, 858, 858, 858, 881, 952,
	858, 858, 858, 858, 881, 858, 858, 858,
	858, 881, 955, 959, 956, 957, 958, 858,
	858, 858, 858, 881, 858, 858, 858, 858,
	881, 961, 965, 967, 962, 963, 964, 858,
	858, 858, 858, 881, 966, 858, 858, 858,
	858, 881, 858, 858, 858, 968, 858, 881,
	969, 858, 858, 858, 970, 858, 881, 858,
	858, 858, 971, 858, 881, 972, 973, 974,
	975, 858, 858, 858, 858, 881, 977, 978,
	858, 858, 858, 858, 881, 980, 981, 985,
	858, 858, 858, 858, 881, 982, 983, 984,
	858, 858, 858, 858, 881, 858, 858, 858,
	858, 881, 987, 989, 991, 993, 988, 858,
	858, 858, 858, 881, 990, 858, 858, 858,
	858, 881, 992, 858, 858, 858, 858, 881,
	994, 995, 996, 858, 858, 858, 858, 881,
	998, 1001, 1003, 999, 1000, 858, 858, 858,
	858, 881, 1002, 858, 858, 858, 858, 881,
	1004, 1005, 0, 1006, 858, 858, 858, 1006,
	858, 881, 1008, 1009, 858, 858, 858, 858,
	881, 1011, 1012, 1200, 1014, 1015, 1015, 1015,
	1014, 1015, 1023, 1015, 1015, 1015, 1016, 1015,
	1023, 1017, 1017, 1017, 1016, 1017, 1022, 1017,
	1017, 1017, 1018, 1017, 1022, 1019, 1019, 1019,
	1019, 1021, 1020, 1201, 1021, 1019, 1022, 1017,
	1023, 1015, 1025, 1202, 1027, 1028, 1028, 1028,
	1027, 1028, 1054, 1028, 1028, 1028, 1029, 1028,
	1054, 1030, 1030, 1030, 1029, 1030, 1053, 1030,
	1030, 1030, 1031, 1030, 1053, 1032, 1032, 1032,
	1031, 1032, 1052, 1032, 1032, 1032, 1033, 1050,
	1032, 1052, 1034, 1034, 1034, 1034, 1049, 0,
	1034, 1034, 1034, 1035, 1034, 1049, 1036, 1037,
	1047, 1038, 1039, 1046, 1040, 1044, 1041, 1042,
	1042, 1043, 1035, 1203, 1045, 1048, 1049, 1034,
	1051, 1050, 1052, 1032, 1053, 1030, 1054, 1028,
	1056, 1057, 1057, 1057, 1056, 1057, 1067, 1057,
	1057, 1057, 1058, 1057, 1067, 1059, 1059, 1059,
	1058, 1059, 1066, 1059, 1059, 1059, 1060, 1059,
	1066, 1061, 1061, 1061, 1060, 1061, 1065, 1061,
	1061, 1061, 1062, 1063, 1061, 1065, 1204, 1064,
	1063, 1065, 1061, 1066, 1059, 1067, 1057, 1069,
	1070, 1070, 1070, 1069, 1070, 1080, 1070, 1070,
	1070, 1071, 1070, 1080, 1072, 1072, 1072, 1071,
	1072, 1079, 1072, 1072, 1072, 1073, 1072, 1079,
	1074, 1074, 1074, 1073, 1074, 1078, 1074, 1074,
	1074, 1075, 1074, 1078, 1076, 1076, 1076, 1076,
	1076, 1077, 1205, 1206, 1207, 1077, 1076, 1078,
	1074, 1079, 1072, 1080, 1070, 1082, 1083, 1083,
	1083, 1082, 1083, 1085, 1083, 1083, 1083, 1084,
	1083, 1085, 1208, 1084, 1085, 1083, 1087, 1088,
	1088, 1088, 1087, 1088, 1098, 1088, 1088, 1088,
	1089, 1088, 1098, 1090, 1091, 1092, 0, 1093,
	1094, 1095, 1096, 1097, 0, 1209, 1098, 1088,
	1100, 1101, 0, 1102, 1103, 1104, 1210, 1106,
	1107, 1108, 1109, 1110, 1211, 1112, 1113, 1113,
	1113, 1112, 1113, 1118, 1113, 1113, 1113, 1114,
	1113, 1118, 1115, 1115, 1115, 1114, 1115, 1117,
	1116, 1115, 1115, 1115, 1115, 1117, 1212, 1117,
	1115, 1118, 1113, 1120, 1121, 1121, 1121, 1120,
	1121, 1126, 1122, 1121, 1121, 1121, 1121, 1126,
	1123, 1123, 1123, 1123, 1125, 1124, 1123, 1123,
	1123, 1123, 1125, 1213, 1125, 1123, 1126, 1121,
	0, 1, 152, 1, 1, 160, 1127, 151,
	1132, 264, 14, 194, 14, 14, 204, 224,
	1135, 239, 1133, 240, 1136, 242, 0, 142,
	142, 142, 170, 250, 251, 252, 253, 266,
	255, 256, 257, 258, 259, 260, 261, 262,
	263, 1130, 265, 0, 163, 170, 250, 251,
	252, 253, 254, 255, 256, 257, 258, 259,
	260, 261, 262, 263, 0, 1, 152, 1,
	1, 160, 1127, 151, 1132, 264, 1, 1,
	1132, 174, 174, 174, 1132, 175, 178, 178,
	178, 193, 228, 0, 205, 208, 210, 211,
	212, 213, 214, 215, 216, 217, 218, 219,
	220, 221, 222, 223, 1132
};

static const short _zone_scanner_trans_actions[] = {
	2012, 0, 5, 7, 532, 679, 679, 679,
	679, 679, 679, 679, 679, 679, 679, 679,
	679, 679, 679, 679, 3, 0, 3, 0,
	2140, 99, 694, 697, 41, 55, 53, 51,
	0, 57, 691, 99, 359, 0, 5, 7,
	93, 93, 93, 93, 93, 93, 93, 93,
	93, 93, 93, 93, 93, 93, 93, 3,
	0, 1684, 1687, 2556, 2560, 0, 0, 0,
	2552, 1687, 2568, 3807, 2568, 353, 0, 351,
	5, 7, 357, 3, 0, 367, 353, 1669,
	11, 400, 403, 1904, 11, 13, 0, 5,
	7, 1813, 0, 9, 1884, 1678, 355, 9,
	394, 11, 376, 382, 11, 3802, 1675, 1675,
	0, 5, 7, 0, 2540, 353, 353, 9,
	1880, 0, 3382, 5, 7, 2000, 2240, 2240,
	2240, 2240, 2240, 2240, 2240, 2240, 2240, 2240,
	2240, 2240, 2240, 2240, 2240, 3, 0, 1672,
	353, 367, 353, 4128, 700, 2244, 2248, 3557,
	700, 1681, 0, 5, 7, 370, 0, 0,
	0, 0, 0, 0, 1810, 3216, 3220, 3212,
	1810, 3224, 4027, 3224, 391, 1872, 1876, 391,
	9, 385, 388, 0, 0, 0, 0, 0,
	0, 1783, 3072, 3076, 3068, 1783, 3080, 3982,
	3080, 1780, 3056, 3060, 3052, 1780, 3064, 3977,
	3064, 0, 0, 1741, 2848, 2852, 2844, 1741,
	2856, 3912, 2856, 0, 0, 0, 1693, 2592,
	2596, 2588, 1693, 2600, 3832, 2600, 0, 0,
	0, 0, 0, 0, 1768, 2992, 2996, 2988,
	1768, 3000, 3957, 3000, 0, 0, 0, 0,
	1744, 2864, 2868, 2860, 1744, 2872, 3917, 2872,
	0, 0, 0, 1765, 2976, 2980, 2972, 1765,
	2984, 3952, 2984, 1750, 2896, 2900, 2892, 1750,
	2904, 3927, 2904, 0, 0, 0, 0, 0,
	1801, 3168, 3172, 3164, 1801, 3176, 4012, 3176,
	0, 1804, 3184, 3188, 3180, 1804, 3192, 4017,
	3192, 0, 0, 0, 0, 1702, 2640, 2644,
	2636, 1702, 2648, 3847, 2648, 0, 0, 97,
	685, 688, 682, 97, 0, 5, 7, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 3, 0,
	0, 0, 0, 0, 0, 0, 1756, 2928,
	2932, 2924, 1756, 2936, 3937, 2936, 0, 0,
	0, 1723, 2752, 2756, 2748, 1723, 2760, 3882,
	2760, 1738, 2832, 2836, 2828, 1738, 2840, 3907,
	2840, 0, 0, 0, 0, 0, 1792, 3120,
	3124, 3116, 1792, 3128, 3997, 3128, 0, 1795,
	3136, 3140, 3132, 1795, 3144, 4002, 3144, 0,
	1729, 2784, 2788, 2780, 1729, 2792, 3892, 2792,
	1798, 3152, 3156, 3148, 1798, 3160, 4007, 3160,
	0, 0, 0, 0, 0, 1705, 2656, 2660,
	2652, 1705, 2664, 3852, 2664, 1708, 2672, 2676,
	2668, 1708, 2680, 3857, 2680, 0, 0, 0,
	0, 0, 0, 1735, 2816, 2820, 2812, 1735,
	2824, 3902, 2824, 0, 1789, 3104, 3108, 3100,
	1789, 3112, 3992, 3112, 1690, 2576, 2580, 0,
	2572, 1690, 2584, 3827, 2584, 0, 1762, 2960,
	2964, 0, 2956, 1762, 2968, 3947, 2968, 1771,
	3008, 3012, 0, 3004, 1771, 3016, 3962, 3016,
	0, 0, 0, 0, 1774, 3024, 3028, 3020,
	1774, 3032, 3967, 3032, 0, 0, 1699, 2624,
	2628, 2620, 1699, 2632, 3842, 2632, 0, 0,
	0, 1714, 2704, 2708, 2700, 1714, 2712, 3867,
	2712, 0, 0, 0, 1759, 2944, 2948, 2940,
	1759, 2952, 3942, 2952, 1720, 2736, 2740, 2732,
	1720, 2744, 3877, 2744, 0, 0, 0, 0,
	0, 1696, 2608, 2612, 2604, 1696, 2616, 3837,
	2616, 0, 1786, 3088, 3092, 3084, 1786, 3096,
	3987, 3096, 0, 1732, 2800, 2804, 2796, 1732,
	2808, 3897, 2808, 0, 0, 0, 1753, 2912,
	2916, 2908, 1753, 2920, 3932, 2920, 0, 0,
	0, 0, 0, 1777, 3040, 3044, 3036, 1777,
	3048, 3972, 3048, 0, 1711, 2688, 2692, 2684,
	1711, 2696, 3862, 2696, 0, 0, 544, 532,
	2016, 601, 2120, 2124, 41, 2116, 601, 2128,
	3512, 2128, 0, 0, 1807, 3200, 3204, 3196,
	1807, 3208, 4022, 3208, 9, 394, 0, 5,
	7, 3, 0, 0, 97, 685, 688, 682,
	97, 0, 5, 7, 532, 95, 95, 95,
	95, 95, 95, 95, 95, 95, 95, 95,
	95, 95, 95, 95, 3, 0, 99, 694,
	697, 41, 55, 53, 51, 0, 57, 691,
	99, 2144, 41, 55, 53, 51, 0, 57,
	619, 2176, 2180, 3522, 2172, 619, 9, 394,
	9, 394, 91, 87, 87, 87, 0, 0,
	0, 0, 0, 0, 85, 37, 35, 487,
	490, 484, 35, 0, 5, 7, 3, 0,
	9, 0, 394, 3367, 496, 1944, 1952, 1936,
	496, 0, 5, 7, 3, 0, 9, 394,
	2144, 41, 55, 53, 51, 0, 57, 619,
	2176, 2180, 3522, 2172, 619, 9, 394, 1992,
	1964, 3332, 3347, 3317, 1964, 4044, 3357, 0,
	5, 7, 3, 0, 367, 353, 2548, 2564,
	3812, 3817, 4158, 2564, 4220, 3822, 4213, 3822,
	0, 5, 7, 370, 1852, 0, 5, 7,
	370, 0, 9, 1880, 406, 1888, 1896, 3267,
	406, 9, 373, 379, 0, 5, 7, 0,
	353, 9, 1880, 2520, 0, 0, 0, 0,
	0, 79, 0, 0, 75, 1984, 493, 1940,
	1948, 3307, 493, 4178, 1956, 3322, 3337, 4038,
	1956, 0, 5, 7, 370, 0, 9, 1880,
	3372, 3352, 4050, 4056, 4171, 3352, 4227, 4062,
	0, 5, 7, 370, 1852, 1960, 505, 3327,
	3342, 3312, 1960, 11, 376, 382, 1828, 11,
	391, 3242, 1872, 1876, 391, 9, 385, 388,
	391, 1872, 1876, 391, 9, 385, 388, 0,
	0, 1726, 2768, 2772, 2764, 1726, 2776, 3887,
	2776, 0, 0, 0, 1717, 2720, 2724, 2716,
	1717, 2728, 3872, 2728, 0, 1747, 2880, 2884,
	2876, 1747, 2888, 3922, 2888, 9, 394, 406,
	1888, 1896, 3277, 9, 373, 379, 3228, 391,
	1872, 1876, 9, 385, 388, 391, 1872, 1876,
	9, 385, 388, 9, 394, 11, 376, 382,
	11, 1675, 391, 1872, 1876, 9, 385, 388,
	508, 9, 394, 9, 394, 9, 1880, 418,
	1908, 15, 421, 29, 1928, 27, 0, 454,
	1912, 19, 21, 0, 445, 424, 17, 427,
	436, 23, 23, 3287, 430, 433, 25, 451,
	640, 63, 0, 0, 1, 637, 2188, 643,
	67, 67, 646, 649, 2184, 69, 63, 0,
	0, 65, 643, 67, 67, 649, 69, 69,
	73, 0, 5, 7, 3, 0, 535, 532,
	3517, 11, 400, 403, 41, 55, 53, 51,
	0, 57, 3272, 11, 412, 0, 5, 7,
	2196, 0, 9, 3252, 2144, 2132, 41, 55,
	53, 51, 0, 57, 613, 2148, 2152, 3522,
	4134, 613, 9, 394, 77, 0, 5, 7,
	3, 0, 3527, 658, 2200, 19, 21, 0,
	415, 448, 1916, 1920, 424, 17, 4032, 448,
	0, 5, 7, 2204, 0, 9, 3257, 427,
	439, 23, 23, 430, 433, 25, 9, 394,
	0, 5, 7, 3, 0, 661, 81, 667,
	664, 2208, 2212, 4140, 664, 664, 673, 0,
	5, 7, 3532, 670, 2216, 2220, 0, 0,
	83, 19, 21, 0, 1924, 3292, 3297, 424,
	17, 4164, 1924, 0, 5, 7, 9, 3262,
	427, 442, 23, 23, 430, 433, 25, 9,
	3247, 0, 5, 7, 3, 0, 9, 394,
	9, 394, 123, 115, 117, 119, 0, 121,
	0, 5, 7, 3, 0, 1, 364, 1,
	9, 394, 323, 321, 1594, 1597, 1591, 321,
	2492, 3797, 2492, 0, 5, 7, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 3, 0, 1600,
	1844, 1600, 237, 1216, 1219, 0, 0, 0,
	1213, 237, 2324, 3587, 2324, 0, 0, 263,
	1333, 1336, 1330, 263, 2376, 3652, 2376, 9,
	394, 0, 0, 0, 0, 0, 319, 1585,
	1588, 1582, 319, 2488, 3792, 2488, 0, 0,
	0, 0, 0, 0, 301, 1504, 1507, 1501,
	301, 2452, 3747, 2452, 299, 1495, 1498, 1492,
	299, 2448, 3742, 2448, 0, 0, 273, 1378,
	1381, 1375, 273, 2396, 3677, 2396, 0, 0,
	0, 241, 1234, 1237, 1231, 241, 2332, 3597,
	2332, 0, 0, 0, 0, 0, 0, 291,
	1459, 1462, 1456, 291, 2432, 3722, 2432, 0,
	0, 0, 0, 275, 1387, 1390, 1384, 275,
	2400, 3682, 2400, 0, 0, 0, 289, 1450,
	1453, 1447, 289, 2428, 3717, 2428, 279, 1405,
	1408, 1402, 279, 2408, 3692, 2408, 0, 0,
	0, 0, 0, 313, 1558, 1561, 1555, 313,
	2476, 3777, 2476, 0, 315, 1567, 1570, 1564,
	315, 2480, 3782, 2480, 0, 0, 0, 0,
	247, 1261, 1264, 1258, 247, 2344, 3612, 2344,
	0, 0, 0, 0, 0, 0, 0, 283,
	1423, 1426, 1420, 283, 2416, 3702, 2416, 0,
	0, 0, 261, 1324, 1327, 1321, 261, 2372,
	3647, 2372, 271, 1369, 1372, 1366, 271, 2392,
	3672, 2392, 0, 0, 0, 0, 0, 307,
	1531, 1534, 1528, 307, 2464, 3762, 2464, 0,
	309, 1540, 1543, 1537, 309, 2468, 3767, 2468,
	0, 265, 1342, 1345, 1339, 265, 2380, 3657,
	2380, 311, 1549, 1552, 1546, 311, 2472, 3772,
	2472, 0, 0, 0, 0, 0, 249, 1270,
	1273, 1267, 249, 2348, 3617, 2348, 251, 1279,
	1282, 1276, 251, 2352, 3622, 2352, 0, 0,
	0, 0, 0, 0, 269, 1360, 1363, 1357,
	269, 2388, 3667, 2388, 0, 305, 1522, 1525,
	1519, 305, 2460, 3757, 2460, 239, 1225, 1228,
	0, 1222, 239, 2328, 3592, 2328, 0, 287,
	1441, 1444, 0, 1438, 287, 2424, 3712, 2424,
	293, 1468, 1471, 0, 1465, 293, 2436, 3727,
	2436, 0, 0, 0, 0, 295, 1477, 1480,
	1474, 295, 2440, 3732, 2440, 0, 0, 245,
	1252, 1255, 1249, 245, 2340, 3607, 2340, 0,
	0, 0, 255, 1297, 1300, 1294, 255, 2360,
	3632, 2360, 0, 0, 0, 285, 1432, 1435,
	1429, 285, 2420, 3707, 2420, 259, 1315, 1318,
	1312, 259, 2368, 3642, 2368, 0, 0, 0,
	0, 0, 243, 1243, 1246, 1240, 243, 2336,
	3602, 2336, 0, 303, 1513, 1516, 1510, 303,
	2456, 3752, 2456, 0, 267, 1351, 1354, 1348,
	267, 2384, 3662, 2384, 0, 0, 0, 281,
	1414, 1417, 1411, 281, 2412, 3697, 2412, 0,
	0, 0, 0, 0, 297, 1486, 1489, 1483,
	297, 2444, 3737, 2444, 0, 253, 1288, 1291,
	1285, 253, 2356, 3627, 2356, 0, 0, 532,
	235, 1207, 1210, 41, 1204, 235, 2320, 3582,
	2320, 0, 0, 317, 1576, 1579, 1573, 317,
	2484, 3787, 2484, 0, 0, 0, 257, 1306,
	1309, 1303, 257, 2364, 3637, 2364, 0, 277,
	1396, 1399, 1393, 277, 2404, 3687, 2404, 337,
	0, 5, 7, 3, 0, 538, 532, 49,
	607, 610, 41, 604, 49, 2308, 0, 5,
	7, 111, 3, 0, 113, 0, 5, 7,
	3, 0, 733, 1840, 733, 9, 394, 9,
	394, 9, 394, 0, 5, 7, 3, 0,
	532, 532, 361, 1820, 1824, 41, 1, 1816,
	361, 0, 5, 7, 111, 3, 0, 113,
	0, 5, 7, 3, 0, 733, 1840, 733,
	9, 394, 9, 394, 49, 607, 610, 604,
	49, 9, 394, 343, 532, 0, 0, 0,
	0, 0, 565, 41, 0, 0, 742, 0,
	745, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 751, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 763, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 766, 0, 0, 0,
	0, 0, 0, 0, 0, 769, 0, 0,
	0, 0, 0, 0, 772, 0, 0, 775,
	0, 0, 0, 0, 0, 0, 0, 778,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 781, 0, 0, 784, 0, 0,
	0, 0, 0, 0, 739, 0, 0, 0,
	0, 0, 748, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 754, 0,
	0, 757, 0, 0, 760, 345, 532, 0,
	0, 0, 0, 0, 0, 577, 41, 0,
	0, 0, 0, 0, 805, 0, 0, 0,
	0, 0, 0, 0, 0, 808, 0, 0,
	0, 802, 0, 0, 796, 0, 0, 0,
	799, 0, 0, 814, 0, 0, 0, 793,
	0, 0, 787, 0, 0, 0, 790, 0,
	0, 811, 706, 703, 2260, 101, 511, 514,
	511, 39, 520, 523, 517, 39, 0, 5,
	7, 511, 3, 0, 39, 520, 523, 517,
	39, 541, 0, 5, 7, 532, 3, 0,
	47, 595, 598, 41, 592, 47, 0, 5,
	7, 532, 3, 0, 2136, 47, 595, 598,
	41, 55, 53, 51, 0, 57, 592, 47,
	0, 5, 7, 532, 3, 0, 47, 595,
	598, 41, 55, 53, 51, 0, 57, 592,
	47, 0, 5, 7, 532, 3, 0, 47,
	595, 598, 41, 55, 53, 51, 0, 57,
	592, 47, 0, 5, 7, 532, 3, 0,
	589, 41, 55, 53, 51, 0, 57, 2144,
	41, 55, 53, 51, 0, 57, 2156, 3522,
	9, 394, 2144, 41, 55, 53, 51, 0,
	57, 616, 2164, 2168, 3522, 2160, 616, 9,
	394, 2144, 41, 55, 53, 51, 0, 57,
	616, 2164, 2168, 3522, 2160, 616, 9, 394,
	2144, 41, 55, 53, 51, 0, 57, 616,
	2164, 2168, 3522, 2160, 616, 9, 394, 9,
	394, 9, 394, 457, 33, 472, 475, 469,
	33, 457, 0, 5, 7, 3, 0, 466,
	9, 394, 511, 39, 520, 523, 517, 39,
	0, 5, 7, 511, 3, 0, 514, 9,
	394, 532, 45, 583, 586, 41, 580, 45,
	0, 5, 7, 511, 3, 0, 514, 9,
	394, 2192, 655, 33, 472, 475, 469, 33,
	1932, 3302, 1932, 457, 0, 5, 7, 3,
	0, 652, 1836, 652, 9, 394, 703, 2276,
	101, 1660, 2496, 325, 1606, 1609, 41, 1603,
	325, 0, 5, 7, 532, 0, 0, 3,
	0, 329, 1624, 1627, 41, 1621, 329, 0,
	5, 7, 3507, 3, 0, 547, 2048, 2052,
	0, 41, 2044, 547, 0, 5, 7, 3,
	0, 0, 5, 7, 3, 0, 532, 327,
	1615, 1618, 41, 1612, 327, 0, 5, 7,
	532, 0, 0, 3, 0, 331, 1633, 1636,
	41, 1630, 331, 0, 5, 7, 3507, 3,
	0, 550, 2060, 2064, 0, 41, 2056, 550,
	0, 5, 7, 3, 0, 0, 5, 7,
	3, 0, 0, 3502, 4152, 553, 2072, 2076,
	0, 41, 553, 2068, 553, 3482, 4104, 3482,
	0, 5, 7, 3502, 3, 0, 1657, 1848,
	1657, 556, 2084, 2088, 0, 41, 556, 2080,
	556, 3487, 4110, 3487, 0, 5, 7, 3502,
	3, 0, 1848, 1657, 559, 2096, 2100, 0,
	41, 559, 2092, 559, 3492, 4116, 3492, 0,
	5, 7, 3502, 3, 0, 1848, 1657, 562,
	2108, 2112, 0, 41, 2104, 562, 3497, 4122,
	3497, 0, 5, 7, 3, 0, 1848, 1657,
	9, 394, 2040, 3472, 3477, 3387, 3467, 2040,
	4098, 4206, 4098, 529, 9, 394, 2036, 3457,
	3462, 3387, 2036, 3452, 2036, 4092, 4199, 4092,
	529, 9, 394, 2032, 3442, 3447, 3387, 2032,
	3437, 2032, 4086, 4192, 4086, 529, 9, 394,
	2028, 3427, 3432, 3387, 2028, 3422, 2028, 4080,
	4185, 4080, 529, 9, 394, 335, 1651, 1654,
	1648, 335, 9, 394, 2024, 3412, 3417, 3387,
	3407, 2024, 529, 9, 394, 9, 394, 9,
	394, 333, 1642, 1645, 1639, 333, 9, 394,
	2020, 3397, 3402, 3387, 3392, 2020, 529, 9,
	394, 9, 394, 532, 45, 583, 586, 41,
	580, 45, 0, 5, 7, 532, 3, 0,
	45, 583, 586, 41, 580, 45, 0, 5,
	7, 532, 3, 0, 45, 583, 586, 41,
	580, 45, 0, 5, 7, 511, 3, 0,
	514, 9, 394, 9, 394, 9, 394, 532,
	45, 583, 586, 41, 580, 45, 0, 5,
	7, 532, 3, 0, 45, 583, 586, 41,
	580, 45, 457, 0, 5, 7, 3, 0,
	33, 472, 475, 469, 33, 457, 0, 5,
	7, 3, 0, 33, 472, 475, 469, 33,
	457, 0, 5, 7, 3, 0, 33, 472,
	475, 469, 33, 0, 5, 7, 511, 3,
	0, 514, 9, 394, 9, 394, 9, 394,
	9, 394, 9, 394, 349, 0, 5, 7,
	3, 0, 532, 45, 583, 586, 41, 580,
	45, 0, 5, 7, 347, 3, 0, 0,
	5, 7, 3, 0, 125, 1, 9, 394,
	9, 394, 9, 394, 727, 0, 715, 5,
	7, 718, 721, 3, 0, 1, 364, 1,
	107, 109, 0, 2252, 703, 101, 103, 532,
	724, 2300, 2304, 41, 2296, 724, 2292, 3577,
	2292, 9, 394, 0, 703, 101, 105, 532,
	45, 583, 586, 41, 580, 45, 0, 5,
	7, 347, 3, 0, 0, 5, 7, 3,
	0, 532, 43, 571, 574, 41, 568, 43,
	730, 0, 5, 7, 111, 3, 0, 113,
	0, 5, 7, 3, 0, 1, 364, 1,
	9, 394, 9, 394, 9, 394, 9, 394,
	532, 43, 571, 574, 41, 568, 43, 0,
	5, 7, 532, 3, 0, 43, 571, 574,
	41, 568, 43, 0, 5, 7, 111, 3,
	0, 113, 0, 5, 7, 3, 0, 1,
	364, 1, 9, 394, 9, 394, 9, 394,
	532, 43, 571, 574, 41, 568, 43, 817,
	0, 5, 7, 143, 145, 147, 149, 3,
	0, 0, 5, 7, 3, 0, 2004, 532,
	43, 571, 574, 41, 568, 43, 0, 5,
	7, 0, 3, 0, 2316, 0, 5, 7,
	0, 5, 7, 0, 5, 7, 1, 3,
	0, 364, 1, 3, 0, 364, 1, 3,
	0, 364, 1, 820, 125, 9, 394, 9,
	394, 9, 394, 9, 394, 9, 394, 0,
	5, 7, 3, 0, 532, 43, 571, 574,
	41, 568, 43, 2256, 0, 5, 7, 703,
	3, 0, 3562, 101, 709, 2268, 2272, 709,
	2268, 2272, 709, 2268, 2272, 2260, 2264, 709,
	3567, 2260, 2264, 709, 3567, 2260, 2264, 709,
	3567, 2260, 9, 394, 9, 394, 0, 5,
	7, 3, 0, 532, 43, 571, 574, 41,
	568, 43, 0, 5, 7, 703, 3, 0,
	101, 712, 2284, 2288, 712, 2284, 2288, 712,
	2284, 2288, 2276, 2280, 712, 3572, 2276, 2280,
	712, 3572, 2276, 2280, 712, 3572, 2276, 9,
	394, 9, 394, 0, 5, 7, 3, 0,
	532, 43, 571, 574, 41, 568, 43, 0,
	5, 7, 511, 3, 0, 39, 520, 523,
	39, 520, 523, 39, 520, 523, 514, 517,
	39, 1996, 514, 517, 39, 1996, 514, 517,
	39, 1996, 514, 9, 394, 9, 394, 9,
	394, 823, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 151, 829, 832, 0, 0, 0, 826,
	151, 0, 5, 7, 347, 3, 0, 0,
	5, 7, 3, 0, 532, 43, 571, 574,
	41, 568, 43, 0, 5, 7, 532, 3,
	0, 47, 595, 598, 41, 592, 47, 634,
	0, 5, 7, 622, 3, 0, 61, 628,
	631, 59, 625, 61, 0, 5, 7, 622,
	3, 0, 61, 628, 631, 59, 625, 61,
	0, 5, 7, 532, 3, 0, 45, 583,
	586, 41, 580, 45, 0, 5, 7, 511,
	3, 0, 39, 520, 523, 517, 39, 0,
	5, 7, 125, 3, 0, 1, 9, 394,
	9, 394, 9, 394, 9, 394, 9, 394,
	9, 394, 9, 394, 9, 394, 0, 0,
	177, 946, 949, 943, 177, 0, 0, 0,
	171, 919, 922, 916, 171, 0, 191, 1009,
	1012, 1006, 191, 0, 0, 0, 0, 0,
	233, 1198, 1201, 1195, 233, 0, 0, 0,
	0, 0, 0, 215, 1117, 1120, 1114, 215,
	213, 1108, 1111, 1105, 213, 0, 0, 187,
	991, 994, 988, 187, 0, 0, 0, 155,
	847, 850, 844, 155, 0, 0, 0, 0,
	0, 0, 205, 1072, 1075, 1069, 205, 0,
	0, 0, 0, 189, 1000, 1003, 997, 189,
	0, 0, 0, 203, 1063, 1066, 1060, 203,
	193, 1018, 1021, 1015, 193, 0, 0, 0,
	0, 0, 227, 1171, 1174, 1168, 227, 0,
	229, 1180, 1183, 1177, 229, 0, 0, 0,
	0, 161, 874, 877, 871, 161, 0, 0,
	0, 0, 0, 0, 0, 197, 1036, 1039,
	1033, 197, 0, 0, 0, 175, 937, 940,
	934, 175, 185, 982, 985, 979, 185, 0,
	0, 0, 0, 0, 221, 1144, 1147, 1141,
	221, 0, 223, 1153, 1156, 1150, 223, 0,
	179, 955, 958, 952, 179, 225, 1162, 1165,
	1159, 225, 0, 0, 0, 0, 0, 163,
	883, 886, 880, 163, 165, 892, 895, 889,
	165, 0, 0, 0, 0, 0, 0, 183,
	973, 976, 970, 183, 0, 219, 1135, 1138,
	1132, 219, 153, 838, 841, 0, 835, 153,
	0, 201, 1054, 1057, 0, 1051, 201, 207,
	1081, 1084, 0, 1078, 207, 0, 0, 0,
	0, 209, 1090, 1093, 1087, 209, 0, 0,
	159, 865, 868, 862, 159, 0, 0, 0,
	169, 910, 913, 907, 169, 0, 0, 0,
	199, 1045, 1048, 1042, 199, 173, 928, 931,
	925, 173, 0, 0, 0, 0, 0, 157,
	856, 859, 853, 157, 0, 217, 1126, 1129,
	1123, 217, 0, 181, 964, 967, 961, 181,
	0, 0, 0, 195, 1027, 1030, 1024, 195,
	0, 0, 0, 0, 0, 211, 1099, 1102,
	1096, 211, 0, 167, 901, 904, 898, 167,
	0, 0, 2008, 532, 45, 583, 586, 41,
	580, 45, 0, 0, 231, 1189, 1192, 1186,
	231, 511, 526, 1, 532, 45, 583, 586,
	41, 580, 45, 0, 5, 7, 532, 3,
	0, 43, 571, 574, 41, 568, 43, 0,
	5, 7, 347, 3, 0, 0, 5, 7,
	3, 0, 125, 1, 9, 394, 9, 394,
	9, 394, 125, 1, 532, 43, 571, 574,
	41, 568, 43, 0, 5, 7, 532, 3,
	0, 43, 571, 574, 41, 568, 43, 0,
	5, 7, 532, 3, 0, 45, 583, 586,
	41, 580, 45, 0, 5, 7, 31, 460,
	3, 0, 33, 472, 475, 469, 33, 736,
	0, 5, 7, 463, 3, 0, 129, 131,
	0, 133, 135, 0, 137, 0, 139, 141,
	0, 478, 127, 1, 0, 0, 9, 394,
	113, 111, 9, 394, 9, 394, 9, 394,
	532, 43, 571, 574, 41, 568, 43, 0,
	5, 7, 532, 3, 0, 43, 571, 574,
	41, 568, 43, 0, 5, 7, 532, 3,
	0, 45, 583, 586, 41, 580, 45, 0,
	5, 7, 31, 460, 3, 0, 466, 113,
	111, 9, 394, 9, 394, 9, 394, 532,
	43, 571, 574, 41, 568, 43, 0, 5,
	7, 532, 3, 0, 43, 571, 574, 41,
	568, 43, 0, 5, 7, 532, 3, 0,
	43, 571, 574, 41, 568, 43, 0, 5,
	7, 111, 3, 0, 113, 0, 5, 7,
	3, 0, 1, 364, 1, 9, 394, 9,
	394, 9, 394, 9, 394, 532, 45, 583,
	586, 41, 580, 45, 0, 5, 7, 703,
	3, 0, 2260, 101, 9, 394, 532, 45,
	583, 586, 41, 580, 45, 0, 5, 7,
	1666, 3, 0, 113, 111, 113, 2312, 341,
	111, 113, 111, 113, 2516, 2512, 9, 394,
	1663, 113, 2508, 339, 111, 113, 2500, 1663,
	113, 339, 111, 113, 2504, 532, 45, 583,
	586, 41, 580, 45, 0, 5, 7, 532,
	3, 0, 45, 583, 586, 41, 580, 45,
	71, 0, 5, 7, 3, 0, 1, 9,
	394, 9, 394, 532, 43, 571, 574, 41,
	568, 43, 457, 0, 5, 7, 3, 0,
	33, 472, 475, 469, 33, 71, 0, 5,
	7, 3, 0, 1, 9, 394, 9, 394,
	502, 499, 0, 1972, 1976, 481, 397, 11,
	1968, 499, 499, 353, 1860, 1868, 2532, 2544,
	1832, 499, 2524, 1675, 3237, 2536, 1988, 499,
	1860, 1868, 2236, 2236, 2236, 2236, 2236, 2236,
	2236, 2236, 2236, 2236, 2236, 2236, 2236, 2236,
	2236, 1832, 499, 3362, 3377, 3552, 3552, 3552,
	3552, 3552, 3552, 3552, 3552, 3552, 3552, 3552,
	3552, 3552, 3552, 3552, 1980, 2232, 89, 3542,
	3547, 2228, 2224, 676, 3537, 2232, 1860, 1868,
	1832, 409, 1892, 1900, 3282, 409, 409, 1856,
	1864, 409, 2528, 4068, 4074, 4146, 4146, 4146,
	4146, 4146, 4146, 4146, 4146, 4146, 4146, 4146,
	4146, 4146, 4146, 4146, 3232
};

static const short _zone_scanner_eof_actions[] = {
	0, 2012, 2140, 359, 1684, 351, 1669, 13,
	13, 351, 351, 1669, 1669, 1669, 3382, 4128,
	1681, 359, 359, 1684, 1669, 1669, 359, 359,
	359, 359, 359, 1684, 1684, 359, 359, 1684,
	359, 359, 359, 1684, 359, 359, 359, 359,
	1684, 359, 359, 359, 1684, 359, 359, 359,
	1684, 1684, 359, 359, 359, 359, 1684, 359,
	1684, 359, 359, 359, 359, 1684, 359, 359,
	359, 359, 359, 359, 359, 359, 359, 359,
	1684, 359, 359, 1684, 1684, 359, 359, 1684,
	359, 1684, 359, 1684, 1684, 359, 359, 359,
	359, 1684, 1684, 359, 359, 359, 359, 1684,
	359, 1684, 1684, 359, 1684, 1684, 359, 359,
	359, 359, 1684, 359, 359, 1684, 359, 1684,
	359, 359, 359, 1684, 1684, 359, 359, 1684,
	359, 1684, 359, 1684, 359, 359, 359, 1684,
	359, 359, 359, 1684, 359, 1684, 359, 359,
	544, 2016, 359, 359, 1684, 359, 2012, 359,
	359, 544, 2140, 2140, 2140, 2140, 359, 13,
	91, 91, 91, 91, 91, 91, 91, 91,
	37, 544, 0, 3367, 544, 359, 2140, 2140,
	2140, 359, 1992, 2016, 2548, 1669, 2012, 13,
	1669, 13, 3382, 2548, 2548, 2548, 2548, 2548,
	2548, 2548, 2548, 2548, 2548, 2548, 2548, 2548,
	2548, 1669, 2520, 91, 91, 91, 91, 91,
	91, 91, 91, 91, 1984, 4178, 2012, 1681,
	3372, 3382, 3372, 3372, 3372, 3372, 3372, 3372,
	3372, 3372, 3372, 3372, 3372, 3372, 3372, 3372,
	505, 3382, 1669, 13, 1669, 1669, 359, 359,
	1684, 359, 359, 359, 1684, 359, 1684, 1669,
	1669, 13, 1669, 1669, 1669, 1669, 351, 3382,
	1669, 1669, 508, 508, 508, 508, 508, 508,
	508, 508, 508, 508, 508, 508, 508, 508,
	13, 1681, 508, 1681, 0, 0, 29, 29,
	29, 436, 436, 436, 436, 29, 29, 640,
	640, 2188, 2188, 2188, 2188, 640, 65, 2188,
	2188, 2188, 2188, 73, 535, 3517, 412, 412,
	3517, 2132, 3517, 73, 77, 77, 77, 415,
	415, 415, 439, 439, 439, 439, 415, 77,
	0, 81, 667, 673, 83, 673, 13, 13,
	442, 442, 442, 442, 673, 13, 83, 0,
	0, 123, 123, 123, 123, 123, 123, 123,
	323, 323, 323, 323, 323, 323, 323, 323,
	323, 323, 323, 323, 323, 323, 323, 323,
	323, 323, 323, 323, 323, 323, 323, 323,
	323, 323, 323, 323, 323, 323, 323, 323,
	323, 323, 323, 323, 323, 323, 323, 323,
	323, 323, 323, 323, 323, 323, 323, 323,
	323, 323, 323, 323, 323, 323, 323, 323,
	323, 323, 323, 323, 323, 323, 323, 323,
	323, 323, 323, 323, 323, 323, 323, 323,
	323, 323, 323, 323, 323, 323, 323, 323,
	323, 323, 323, 323, 323, 323, 323, 323,
	323, 323, 323, 323, 323, 323, 323, 323,
	323, 323, 323, 323, 323, 323, 323, 323,
	323, 323, 323, 323, 323, 323, 323, 323,
	323, 323, 323, 323, 323, 323, 323, 323,
	323, 323, 323, 323, 323, 323, 323, 323,
	323, 323, 323, 323, 337, 538, 538, 2308,
	2308, 2308, 2308, 337, 337, 337, 538, 538,
	2308, 2308, 2308, 2308, 337, 538, 337, 343,
	343, 343, 343, 343, 343, 343, 343, 343,
	343, 343, 343, 343, 343, 343, 343, 343,
	343, 343, 343, 343, 343, 343, 343, 343,
	343, 343, 343, 343, 343, 343, 343, 343,
	343, 343, 343, 343, 343, 343, 343, 343,
	343, 343, 343, 343, 343, 343, 343, 343,
	343, 343, 343, 343, 343, 343, 343, 343,
	343, 343, 343, 343, 343, 343, 343, 343,
	343, 343, 343, 343, 343, 343, 343, 343,
	343, 343, 343, 343, 343, 343, 343, 343,
	343, 343, 343, 343, 343, 343, 343, 343,
	343, 343, 343, 343, 343, 343, 343, 343,
	343, 343, 343, 343, 343, 343, 343, 345,
	345, 345, 345, 345, 345, 345, 345, 345,
	345, 345, 345, 345, 345, 345, 345, 345,
	345, 345, 345, 345, 345, 345, 345, 345,
	345, 345, 345, 345, 345, 345, 345, 345,
	345, 345, 345, 345, 345, 345, 345, 345,
	706, 706, 351, 351, 351, 351, 351, 351,
	541, 541, 541, 2136, 541, 2136, 541, 2136,
	541, 2136, 2136, 2136, 2136, 351, 2136, 2136,
	2136, 351, 2136, 2136, 2136, 351, 2136, 2136,
	2136, 351, 351, 351, 351, 351, 351, 351,
	351, 351, 351, 351, 351, 351, 541, 541,
	351, 351, 351, 655, 655, 655, 655, 706,
	706, 1660, 1660, 1660, 1660, 1660, 1660, 1660,
	1660, 1660, 1660, 1660, 1660, 1660, 1660, 1660,
	1660, 1660, 1660, 1660, 1660, 1660, 1660, 1660,
	1660, 1660, 1660, 1660, 1660, 1660, 1660, 1660,
	1660, 1660, 1660, 1660, 1660, 1660, 1660, 1660,
	1660, 1660, 1660, 1660, 1660, 1660, 1660, 1660,
	1660, 1660, 1660, 1660, 1660, 1660, 1660, 1660,
	541, 541, 541, 541, 541, 541, 351, 351,
	351, 351, 351, 541, 541, 541, 541, 351,
	351, 351, 351, 351, 351, 351, 351, 351,
	351, 351, 351, 351, 351, 351, 541, 541,
	351, 351, 351, 351, 351, 351, 351, 727,
	727, 727, 2252, 2252, 727, 727, 351, 727,
	2252, 2252, 541, 541, 351, 351, 541, 541,
	730, 730, 730, 730, 351, 351, 351, 541,
	541, 541, 541, 730, 730, 730, 730, 351,
	351, 541, 541, 817, 817, 2004, 2004, 817,
	2316, 820, 820, 820, 820, 820, 820, 820,
	817, 817, 817, 2004, 2004, 2256, 3562, 817,
	817, 817, 2004, 2004, 2256, 3562, 817, 817,
	817, 2004, 2004, 817, 2316, 817, 817, 351,
	823, 823, 351, 351, 541, 541, 541, 541,
	634, 634, 634, 634, 541, 541, 351, 351,
	351, 351, 351, 351, 351, 351, 351, 351,
	351, 351, 823, 823, 823, 823, 823, 823,
	823, 823, 823, 823, 823, 823, 823, 823,
	823, 823, 823, 823, 823, 823, 823, 823,
	823, 823, 823, 823, 823, 823, 823, 823,
	823, 823, 823, 823, 823, 823, 823, 823,
	823, 823, 823, 823, 823, 823, 823, 823,
	823, 823, 823, 823, 823, 823, 823, 823,
	823, 823, 823, 823, 823, 823, 823, 823,
	823, 823, 823, 823, 823, 823, 823, 823,
	823, 823, 823, 823, 823, 823, 823, 823,
	823, 823, 823, 823, 823, 823, 823, 823,
	823, 823, 823, 823, 823, 823, 823, 823,
	823, 823, 823, 823, 823, 823, 823, 823,
	823, 823, 823, 823, 823, 823, 823, 823,
	823, 823, 823, 823, 823, 823, 823, 823,
	823, 823, 823, 823, 823, 2008, 2008, 823,
	823, 823, 351, 351, 351, 541, 541, 541,
	541, 351, 351, 351, 351, 351, 351, 351,
	351, 351, 541, 541, 541, 541, 541, 541,
	730, 730, 736, 736, 736, 736, 736, 736,
	736, 736, 736, 351, 736, 736, 736, 736,
	736, 351, 730, 730, 351, 351, 351, 541,
	541, 541, 541, 541, 541, 730, 730, 730,
	730, 351, 351, 351, 541, 541, 541, 541,
	541, 541, 730, 730, 730, 730, 351, 351,
	351, 541, 541, 706, 706, 351, 541, 541,
	730, 730, 730, 730, 2312, 730, 730, 730,
	730, 2516, 351, 730, 730, 2508, 730, 730,
	2508, 730, 730, 2508, 730, 730, 2508, 541,
	541, 541, 541, 351, 351, 351, 351, 541,
	541, 351, 351, 351, 351, 351, 351, 0,
	0, 0, 0, 89, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0
};






__attribute__((visibility("default")))
int zs_init(
	zs_scanner_t *s,
	const char *origin,
	const uint16_t rclass,
	const uint32_t ttl)
{
	if (s == NULL) {
		return -1;
	}

	memset(s, 0, sizeof(*s));

	// Nonzero initial scanner state.
	s->cs = 1127;

	// Reset the file descriptor.
	s->file.descriptor = -1;

	// Use the root zone as origin if not specified.
	if (origin == NULL || strlen(origin) == 0) {
		origin = ".";
	}
	size_t origin_len = strlen(origin);

	// Prepare a zone settings header.
	const char *format;
	if (origin[origin_len - 1] != '.') {
		format = "$ORIGIN %s.\n";
	} else {
		format = "$ORIGIN %s\n";
	}

	char settings[1024];
	int ret = snprintf(settings, sizeof(settings), format, origin);
	if (ret <= 0 || ret >= sizeof(settings)) {
		ERR(ZS_ENOMEM);
		return -1;
	}

	// Parse the settings to set up the scanner origin.
	if (zs_set_input_string(s, settings, ret) != 0 ||
	    zs_parse_all(s) != 0) {
		return -1;
	}

	// Set scanner defaults.
	s->path = strdup(".");
	if (s->path == NULL) {
		ERR(ZS_ENOMEM);
		return -1;
	}
	s->default_class = rclass;
	s->default_ttl = ttl;
	s->line_counter = 1;

	s->state = ZS_STATE_NONE;
	s->process.automatic = false;

	return 0;
}

static void input_deinit(
	zs_scanner_t *s,
	bool keep_filename)
{
	// Deinit the file input.
	if (s->file.descriptor != -1) {
		// Unmap the file content.
		if (s->input.start != NULL) {
			munmap((void *)s->input.start,
			       s->input.end - s->input.start);
		}

		// Close the opened file.
		close(s->file.descriptor);
		s->file.descriptor = -1;
	}

	// Keep file name for possible trailing error report.
	if (!keep_filename) {
		free(s->file.name);
		s->file.name = NULL;
	}

	// Unset the input limits.
	s->input.start   = NULL;
	s->input.current = NULL;
	s->input.end     = NULL;
	s->input.eof     = false;
}

__attribute__((visibility("default")))
void zs_deinit(
	zs_scanner_t *s)
{
	if (s == NULL) {
		return;
	}

	input_deinit(s, false);
	free(s->path);
}

static int set_input_string(
	zs_scanner_t *s,
	const char *input,
	size_t size,
	bool final_block)
{
	if (s == NULL) {
		return -1;
	}

	if (input == NULL) {
		ERR(ZS_EINVAL);
		return -1;
	}

	// Deinit possibly opened file.
	input_deinit(s, final_block);

	// Set the scanner input limits.
	s->input.start   = input;
	s->input.current = input;
	s->input.end     = input + size;
	s->input.eof     = final_block;

	return 0;
}

__attribute__((visibility("default")))
int zs_set_input_string(
	zs_scanner_t *s,
	const char *input,
	size_t size)
{
	return set_input_string(s, input, size, false);
}

__attribute__((visibility("default")))
int zs_set_input_file(
	zs_scanner_t *s,
	const char *file_name)
{
	if (s == NULL) {
		return -1;
	}

	if (file_name == NULL) {
		ERR(ZS_EINVAL);
		return -1;
	}

	// Deinit possibly opened file.
	input_deinit(s, false);

	// Try to open the file.
	s->file.descriptor = open(file_name, O_RDONLY);
	if (s->file.descriptor == -1) {
		ERR(ZS_FILE_OPEN);
		return -1;
	}

	// Check for regular file input.
	struct stat file_stat;
	if (fstat(s->file.descriptor, &file_stat) == -1 ||
	    !S_ISREG(file_stat.st_mode)) {
		ERR(ZS_FILE_INVALID);
		input_deinit(s, false);
		return -1;
	}

	// Check for empty file (cannot mmap).
	if (file_stat.st_size > 0) {
		// Map the file to the memory.
		char *start = mmap(0, file_stat.st_size, PROT_READ, MAP_SHARED,
		                   s->file.descriptor, 0);
		if (start == MAP_FAILED) {
			ERR(ZS_FILE_MMAP);
			input_deinit(s, false);
			return -1;
		}

		// Try to set the mapped memory advise to sequential.
		(void)madvise(start, file_stat.st_size, MADV_SEQUENTIAL);

		// Set the scanner input limits.
		s->input.start   = start;
		s->input.current = start;
		s->input.end     = start + file_stat.st_size;
	}

	// Get absolute path of the zone file.
	char *full_name = realpath(file_name, NULL);
	if (full_name != NULL) {
		free(s->path);
		s->path = strdup(dirname(full_name));
		free(full_name);
		if (s->path == NULL) {
			ERR(ZS_ENOMEM);
			input_deinit(s, false);
			return -1;
		}
	} else {
		ERR(ZS_FILE_PATH);
		input_deinit(s, false);
		return -1;
	}

	s->file.name = strdup(file_name);
	if (s->file.name == NULL) {
		ERR(ZS_ENOMEM);
		input_deinit(s, false);
		return -1;
	}

	return 0;
}

__attribute__((visibility("default")))
int zs_set_processing(
	zs_scanner_t *s,
	void (*process_record)(zs_scanner_t *),
	void (*process_error)(zs_scanner_t *),
	void *data)
{
	if (s == NULL) {
		return -1;
	}

	s->process.record = process_record;
	s->process.error = process_error;
	s->process.data = data;

	return 0;
}

typedef enum {
	WRAP_NONE,     // Initial state.
	WRAP_DETECTED, // Input block end is a first '\' in rdata.
	WRAP_PROCESS   // Parsing of auxiliary block = "\".
} wrap_t;

static void parse(
	zs_scanner_t *s,
	wrap_t *wrap)
{
	// Restore scanner input limits (Ragel internals).
	const char *p = s->input.current;
	const char *pe = s->input.end;
	const char *eof = s->input.eof ? pe : NULL;

	// Restore state variables (Ragel internals).
	int cs  = s->cs;
	int top = s->top;
	int stack[RAGEL_STACK_SIZE];
	memcpy(stack, s->stack, sizeof(stack));

	// Auxiliary variables which are used in scanner body.
	struct in_addr  addr4;
	struct in6_addr addr6;
	uint32_t timestamp;
	int16_t  window;
	int      ret;

	// Next 2 variables are for better performance.
	// Restoring r_data pointer to next free space.
	uint8_t *rdata_tail = s->r_data + s->r_data_tail;
	// Initialization of the last r_data byte.
	uint8_t *rdata_stop = s->r_data + MAX_RDATA_LENGTH - 1;

	// Write scanner body (in C).

	{
	int _klen;
	unsigned int _trans;
	short _widec;
	const short *_acts;
	unsigned int _nacts;
	const short *_keys;

	if ( p == pe )
		goto _test_eof;
	if ( cs == 0 )
		goto _out;
_resume:
	_widec = (*p);
	_klen = _zone_scanner_cond_lengths[cs];
	_keys = _zone_scanner_cond_keys + (_zone_scanner_cond_offsets[cs]*2);
	if ( _klen > 0 ) {
		const short *_lower = _keys;
		const short *_mid;
		const short *_upper = _keys + (_klen<<1) - 2;
		while (1) {
			if ( _upper < _lower )
				break;

			_mid = _lower + (((_upper-_lower) >> 1) & ~1);
			if ( _widec < _mid[0] )
				_upper = _mid - 2;
			else if ( _widec > _mid[1] )
				_lower = _mid + 2;
			else {
				switch ( _zone_scanner_cond_spaces[_zone_scanner_cond_offsets[cs] + ((_mid - _keys)>>1)] ) {
	case 0: {
		_widec = (short)(640 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		break;
	}
	case 1: {
		_widec = (short)(1152 + ((*p) - -128));
		if (
 !s->multiline  ) _widec += 256;
		break;
	}
	case 2: {
		_widec = (short)(128 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		break;
	}
	case 3: {
		_widec = (short)(2688 + ((*p) - -128));
		if (
 s->number64 != 0  ) _widec += 256;
		break;
	}
	case 4: {
		_widec = (short)(4224 + ((*p) - -128));
		if (
 s->number64 == 0  ) _widec += 256;
		break;
	}
	case 5: {
		_widec = (short)(1664 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
		break;
	}
	case 6: {
		_widec = (short)(3200 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 s->number64 != 0  ) _widec += 512;
		break;
	}
	case 7: {
		_widec = (short)(4736 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 s->number64 == 0  ) _widec += 512;
		break;
	}
	case 8: {
		_widec = (short)(5760 + ((*p) - -128));
		if (
 s->number64 != 0  ) _widec += 256;
		if (
 s->number64 == 0  ) _widec += 512;
		break;
	}
	case 9: {
		_widec = (short)(12928 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
		if (
 s->number64 == 0  ) _widec += 1024;
		break;
	}
	case 10: {
		_widec = (short)(6784 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 s->number64 != 0  ) _widec += 512;
		if (
 s->number64 == 0  ) _widec += 1024;
		break;
	}
	case 11: {
		_widec = (short)(8832 + ((*p) - -128));
		if (
 s->multiline  ) _widec += 256;
		if (
 !s->multiline  ) _widec += 512;
		if (
 s->number64 != 0  ) _widec += 1024;
		if (
 s->number64 == 0  ) _widec += 2048;
		break;
	}
				}
				break;
			}
		}
	}

	_keys = _zone_scanner_trans_keys + _zone_scanner_key_offsets[cs];
	_trans = _zone_scanner_index_offsets[cs];

	_klen = _zone_scanner_single_lengths[cs];
	if ( _klen > 0 ) {
		const short *_lower = _keys;
		const short *_mid;
		const short *_upper = _keys + _klen - 1;
		while (1) {
			if ( _upper < _lower )
				break;

			_mid = _lower + ((_upper-_lower) >> 1);
			if ( _widec < *_mid )
				_upper = _mid - 1;
			else if ( _widec > *_mid )
				_lower = _mid + 1;
			else {
				_trans += (unsigned int)(_mid - _keys);
				goto _match;
			}
		}
		_keys += _klen;
		_trans += _klen;
	}

	_klen = _zone_scanner_range_lengths[cs];
	if ( _klen > 0 ) {
		const short *_lower = _keys;
		const short *_mid;
		const short *_upper = _keys + (_klen<<1) - 2;
		while (1) {
			if ( _upper < _lower )
				break;

			_mid = _lower + (((_upper-_lower) >> 1) & ~1);
			if ( _widec < _mid[0] )
				_upper = _mid - 2;
			else if ( _widec > _mid[1] )
				_lower = _mid + 2;
			else {
				_trans += (unsigned int)((_mid - _keys)>>1);
				goto _match;
			}
		}
		_trans += _klen;
	}

_match:
	_trans = _zone_scanner_indicies[_trans];
	cs = _zone_scanner_trans_targs[_trans];

	if ( _zone_scanner_trans_actions[_trans] == 0 )
		goto _again;

	_acts = _zone_scanner_actions + _zone_scanner_trans_actions[_trans];
	_nacts = (unsigned int) *_acts++;
	while ( _nacts-- > 0 )
	{
		switch ( *_acts++ )
		{
	case 0:
	{
		p--; {cs = stack[--top]; goto _again;}
	}
	break;
	case 1:
	{
		s->line_counter++;
	}
	break;
	case 2:
	{
		if (s->multiline == true) {
			ERR(ZS_LEFT_PARENTHESIS);
			p--; {cs = 268;goto _again;}
		}
		s->multiline = true;
	}
	break;
	case 3:
	{
		if (s->multiline == false) {
			ERR(ZS_RIGHT_PARENTHESIS);
			p--; {cs = 268;goto _again;}
		}
		s->multiline = false;
	}
	break;
	case 4:
	{
		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	break;
	case 5:
	{
		s->buffer[s->buffer_length++] = 0;
	}
	break;
	case 6:
	{
		s->buffer[0] = 0;
		s->buffer_length = 0;
	}
	break;
	case 7:
	{
		WARN(ZS_BAD_REST);
		p--; {cs = 268;goto _again;}
	}
	break;
	case 8:
	{
		s->buffer_length = 0;
	}
	break;
	case 9:
	{
		if ((*p) == '\r') {
			ERR(ZS_DOS_NEWLINE);
		}

		if (s->buffer_length < sizeof(s->buffer) - 1) {
			s->buffer[s->buffer_length++] = (*p);
		}
	}
	break;
	case 10:
	{
		// Terminate the error context string.
		s->buffer[s->buffer_length++] = 0;

		// Error counter incrementation.
		s->error.counter++;

		// Initialize the fcall stack.
		top = 0;

		// Reset the multiline context.
		s->multiline = false;

		s->state = ZS_STATE_ERROR;

		// Execute the error callback.
		if (s->process.automatic) {
			if (s->process.error != NULL) {
				s->process.error(s);

				// Stop if required from the callback.
				if (s->state == ZS_STATE_STOP) {
					{p++; goto _out; }
				}
			}

			// Stop the scanner if fatal error.
			if (s->error.fatal) {
				{p++; goto _out; }
			}
			{cs = 1127;goto _again;}
		} else {
			// Return if external processing.
			p--; cs = 1127; {p++; goto _out; }
		}
	}
	break;
	case 11:
	{
		s->item_length = 0;
		s->item_length_position = s->dname_tmp_length++;
	}
	break;
	case 12:
	{
		// Check for maximum dname label length.
		if (s->item_length < MAX_LABEL_LENGTH) {
			(s->dname)[s->dname_tmp_length++] = (*p);
			s->item_length++;
		} else {
			WARN(ZS_LABEL_OVERFLOW);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 13:
	{
		// Check for maximum dname length overflow after each label.
		// (at least the next label length must follow).
		if (s->dname_tmp_length < MAX_DNAME_LENGTH) {
			(s->dname)[s->item_length_position] =
				(uint8_t)(s->item_length);
		} else {
			WARN(ZS_DNAME_OVERFLOW);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 14:
	{
		if (s->item_length < MAX_LABEL_LENGTH) {
			(s->dname)[s->dname_tmp_length] = 0;
			s->item_length++;
		} else {
			WARN(ZS_LABEL_OVERFLOW);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 15:
	{
		(s->dname)[s->dname_tmp_length] *= 10;
		(s->dname)[s->dname_tmp_length] += digit_to_num[(uint8_t)(*p)];
	}
	break;
	case 16:
	{
		s->dname_tmp_length++;
	}
	break;
	case 17:
	{
		WARN(ZS_BAD_NUMBER);
		p--; {cs = 268;goto _again;}
	}
	break;
	case 18:
	{
		// Enough room for the terminal label is guaranteed (_label_exit).
		(s->dname)[s->dname_tmp_length++] = 0;
	}
	break;
	case 19:
	{
		// Check for (relative + origin) dname length overflow.
		if (s->dname_tmp_length + s->zone_origin_length <= MAX_DNAME_LENGTH) {
			memcpy(s->dname + s->dname_tmp_length,
			       s->zone_origin,
			       s->zone_origin_length);

			s->dname_tmp_length += s->zone_origin_length;
		} else {
			WARN(ZS_DNAME_OVERFLOW);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 20:
	{
		// Copy already verified zone origin.
		memcpy(s->dname,
		       s->zone_origin,
		       s->zone_origin_length);

		s->dname_tmp_length = s->zone_origin_length;
	}
	break;
	case 21:
	{
		s->item_length_position = 0;
		s->dname_tmp_length = 0;
	}
	break;
	case 22:
	{
		WARN(ZS_BAD_DNAME_CHAR);
		p--; {cs = 268;goto _again;}
	}
	break;
	case 23:
	{ p--; {stack[top++] = cs; cs = 270;goto _again;} }
	break;
	case 24:
	{
		if (rdata_tail <= rdata_stop) {
			s->item_length_location = rdata_tail++;
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 25:
	{
		s->item_length = rdata_tail - s->item_length_location - 1;

		if (s->item_length <= MAX_ITEM_LENGTH) {
			*(s->item_length_location) = (uint8_t)(s->item_length);
		} else {
			WARN(ZS_ITEM_OVERFLOW);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 26:
	{
		s->dname = s->r_owner;
		s->r_owner_length = 0;
	}
	break;
	case 27:
	{
		s->r_owner_length = s->dname_tmp_length;
	}
	break;
	case 28:
	{
		if (s->r_owner_length == 0) {
			WARN(ZS_BAD_PREVIOUS_OWNER);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 29:
	{
		s->r_owner_length = 0;
		WARN(ZS_BAD_OWNER);
		p--; {cs = 268;goto _again;}
	}
	break;
	case 30:
	{
		s->dname = rdata_tail;
	}
	break;
	case 31:
	{
		rdata_tail += s->dname_tmp_length;
	}
	break;
	case 32:
	{
		// Overflow check: 10*(s->number64) + fc - '0' <= UINT64_MAX
		if ((s->number64 < (UINT64_MAX / 10)) ||   // Dominant fast check.
			((s->number64 == (UINT64_MAX / 10)) && // Marginal case.
			 ((uint8_t)(*p) <= (UINT64_MAX % 10) + '0')
			)
		   ) {
			s->number64 *= 10;
			s->number64 += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER64_OVERFLOW);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 33:
	{
		s->number64 = 0;
	}
	break;
	case 34:
	{
		WARN(ZS_BAD_NUMBER);
		p--; {cs = 268;goto _again;}
	}
	break;
	case 35:
	{
		s->decimal_counter = 0;
	}
	break;
	case 36:
	{
		s->number64_tmp = s->number64;
	}
	break;
	case 37:
	{
		s->decimal_counter++;
	}
	break;
	case 38:
	{
		if (s->decimal_counter == 0 && s->number64 < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals);
		} else if (s->decimal_counter <= s->decimals &&
				 s->number64_tmp < UINT32_MAX) {
			s->number64 *= pow(10, s->decimals - s->decimal_counter);
			s->number64 += s->number64_tmp * pow(10, s->decimals);
		} else {
			WARN(ZS_FLOAT_OVERFLOW);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 39:
	{
		s->decimals = 2;
	}
	break;
	case 40:
	{
		s->decimals = 3;
	}
	break;
	case 41:
	{
		if (s->number64 <= UINT8_MAX) {
			*rdata_tail = (uint8_t)(s->number64);
			rdata_tail += 1;
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 42:
	{
		if (s->number64 <= UINT16_MAX) {
			uint16_t num16 = htons((uint16_t)s->number64);
			memcpy(rdata_tail, &num16, 2);
			rdata_tail += 2;
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 43:
	{
		if (s->number64 <= UINT32_MAX) {
			uint32_t num32 = htonl((uint32_t)s->number64);
			memcpy(rdata_tail, &num32, 4);
			rdata_tail += 4;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 44:
	{
		if (s->number64 <= UINT16_MAX) {
			s->r_type = (uint16_t)(s->number64);
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 45:
	{
		if (s->number64 <= UINT16_MAX) {
			s->r_data_length = (uint16_t)(s->number64);
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 46:
	{
		WARN(ZS_BAD_TIME_UNIT);
		p--; {cs = 268;goto _again;}
	}
	break;
	case 47:
	{ if (s->number64 <= (UINT32_MAX / 60)) {
	                  s->number64 *= 60;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {cs = 268;goto _again;}
	              }
	            }
	break;
	case 48:
	{ if (s->number64 <= (UINT32_MAX / 3600)) {
	                  s->number64 *= 3600;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {cs = 268;goto _again;}
	              }
	            }
	break;
	case 49:
	{ if (s->number64 <= (UINT32_MAX / 86400)) {
	                  s->number64 *= 86400;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {cs = 268;goto _again;}
	              }
	            }
	break;
	case 50:
	{ if (s->number64 <= (UINT32_MAX / 604800)) {
	                  s->number64 *= 604800;
	              } else {
	                  WARN(ZS_NUMBER32_OVERFLOW);
	                  p--; {cs = 268;goto _again;}
	              }
	            }
	break;
	case 51:
	{
		s->number64_tmp = s->number64;
	}
	break;
	case 52:
	{
		if (s->number64 + s->number64_tmp < UINT32_MAX) {
			s->number64 += s->number64_tmp;
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 53:
	{
		s->buffer_length = 0;
	}
	break;
	case 54:
	{
		if (s->buffer_length < MAX_RDATA_LENGTH) {
			s->buffer[s->buffer_length++] = (*p);
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 55:
	{
		s->buffer[s->buffer_length] = 0;

		if (s->buffer_length == 14) { // Date; 14 = len("YYYYMMDDHHmmSS").
			ret = date_to_timestamp(s->buffer, &timestamp);

			if (ret == ZS_OK) {
				*((uint32_t *)rdata_tail) = htonl(timestamp);
				rdata_tail += 4;
			} else {
				WARN(ret);
				p--; {cs = 268;goto _again;}
			}
		} else if (s->buffer_length <= 10) { // Timestamp format.
			char *end;

			s->number64 = strtoull((char *)(s->buffer), &end,  10);

			if (end == (char *)(s->buffer) || *end != '\0') {
				WARN(ZS_BAD_TIMESTAMP);
				p--; {cs = 268;goto _again;}
			}

			if (s->number64 <= UINT32_MAX) {
				*((uint32_t *)rdata_tail) = htonl((uint32_t)s->number64);
				rdata_tail += 4;
			} else {
				WARN(ZS_NUMBER32_OVERFLOW);
				p--; {cs = 268;goto _again;}
			}
		} else {
			WARN(ZS_BAD_TIMESTAMP_LENGTH);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 56:
	{
		WARN(ZS_BAD_TIMESTAMP_CHAR);
		p--; {cs = 268;goto _again;}
	}
	break;
	case 57:
	{
		if (rdata_tail <= rdata_stop) {
			// Split long string.
			if (s->long_string &&
			    rdata_tail - s->item_length_location == 1 + MAX_ITEM_LENGTH) {
				// _item_length_exit equivalent.
				*(s->item_length_location) = MAX_ITEM_LENGTH;
				// _item_length_init equivalent.
				s->item_length_location = rdata_tail++;

				if (rdata_tail > rdata_stop) {
					WARN(ZS_TEXT_OVERFLOW);
					p--; {cs = 268;goto _again;}
				}
			}

			*(rdata_tail++) = (*p);
		} else {
			WARN(ZS_TEXT_OVERFLOW);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 58:
	{
		WARN(ZS_BAD_TEXT_CHAR);
		p--; {cs = 268;goto _again;}
	}
	break;
	case 59:
	{
		WARN(ZS_BAD_TEXT);
		p--; {cs = 268;goto _again;}
	}
	break;
	case 60:
	{
		if (rdata_tail <= rdata_stop) {
			// Split long string.
			if (s->long_string &&
			    rdata_tail - s->item_length_location == 1 + MAX_ITEM_LENGTH) {
				// _item_length_exit equivalent.
				*(s->item_length_location) = MAX_ITEM_LENGTH;
				// _item_length_init equivalent.
				s->item_length_location = rdata_tail++;

				if (rdata_tail > rdata_stop) {
					WARN(ZS_TEXT_OVERFLOW);
					p--; {cs = 268;goto _again;}
				}
			}

			*rdata_tail = 0;
			s->item_length++;
		} else {
			WARN(ZS_TEXT_OVERFLOW);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 61:
	{
		if ((*rdata_tail < (UINT8_MAX / 10)) ||   // Dominant fast check.
			((*rdata_tail == (UINT8_MAX / 10)) && // Marginal case.
			 ((*p) <= (UINT8_MAX % 10) + '0')
			)
		   ) {
			*rdata_tail *= 10;
			*rdata_tail += digit_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_NUMBER8_OVERFLOW);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 62:
	{
		rdata_tail++;
	}
	break;
	case 63:
	{
		WARN(ZS_BAD_NUMBER);
		p--; {cs = 268;goto _again;}
	}
	break;
	case 64:
	{ p--; {stack[top++] = cs; cs = 279;goto _again;} }
	break;
	case 65:
	{
		s->long_string = true;
	}
	break;
	case 66:
	{
		s->long_string = false;
	}
	break;
	case 67:
	{
		if (s->number64 <= UINT32_MAX) {
			s->default_ttl = (uint32_t)(s->number64);
		} else {
			ERR(ZS_NUMBER32_OVERFLOW);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 68:
	{
		ERR(ZS_BAD_TTL);
		p--; {cs = 268;goto _again;}
	}
	break;
	case 69:
	{ p--; {stack[top++] = cs; cs = 291;goto _again;} }
	break;
	case 70:
	{
		s->dname = s->zone_origin;
	}
	break;
	case 71:
	{
		s->zone_origin_length = s->dname_tmp_length;
	}
	break;
	case 72:
	{
		ERR(ZS_BAD_ORIGIN);
		p--; {cs = 268;goto _again;}
	}
	break;
	case 73:
	{ p--; {stack[top++] = cs; cs = 300;goto _again;} }
	break;
	case 74:
	{
		rdata_tail = s->r_data;
	}
	break;
	case 75:
	{
		size_t len = rdata_tail - s->r_data;
		if (len >= sizeof(s->include_filename)) {
			ERR(ZS_BAD_INCLUDE_FILENAME);
			p--; {cs = 268;goto _again;}
		}

		// Store zero terminated include filename.
		memcpy(s->include_filename, s->r_data, len);
		s->include_filename[len] = '\0';

		// For detection whether origin is not present.
		s->dname = NULL;
	}
	break;
	case 76:
	{
		ERR(ZS_BAD_INCLUDE_FILENAME);
		p--; {cs = 268;goto _again;}
	}
	break;
	case 77:
	{
		s->dname = s->r_data;
	}
	break;
	case 78:
	{
		s->r_data_length = s->dname_tmp_length;
	}
	break;
	case 79:
	{
		ERR(ZS_BAD_INCLUDE_ORIGIN);
		p--; {cs = 268;goto _again;}
	}
	break;
	case 80:
	{
		// Extend relative file path.
		if (s->include_filename[0] != '/') {
			ret = snprintf((char *)(s->buffer), sizeof(s->buffer),
			               "%s/%s", s->path, s->include_filename);
			if (ret <= 0 || ret > sizeof(s->buffer)) {
				ERR(ZS_BAD_INCLUDE_FILENAME);
				p--; {cs = 268;goto _again;}
			}
			memcpy(s->include_filename, s->buffer, ret);
		}

		// Origin conversion from wire to text form in \DDD notation.
		if (s->dname == NULL) { // Use current origin.
			wire_dname_to_str(s->zone_origin,
			                  s->zone_origin_length,
			                  (char *)s->buffer);
		} else { // Use specified origin.
			wire_dname_to_str(s->r_data,
			                  s->r_data_length,
			                  (char *)s->buffer);
		}

		// Let the caller to solve the include.
		if (s->process.automatic) {
			// Create new scanner for included zone file.
			zs_scanner_t *ss = malloc(sizeof(zs_scanner_t));
			if (ss == NULL) {
				ERR(ZS_UNPROCESSED_INCLUDE);
				p--; {cs = 268;goto _again;}
			}

			// Parse included zone file.
			if (zs_init(ss, (char *)s->buffer, s->default_class,
			            s->default_ttl) != 0 ||
			    zs_set_input_file(ss, (char *)(s->include_filename)) != 0 ||
			    zs_set_processing(ss, s->process.record, s->process.error,
			                      s->process.data) != 0 ||
			    zs_parse_all(ss) != 0) {
				// File internal errors are handled by error callback.
				if (ss->error.counter > 0) {
					s->error.counter += ss->error.counter;
					ERR(ZS_UNPROCESSED_INCLUDE);
				// General include file error.
				} else {
					ERR(ss->error.code);
				}
				zs_deinit(ss);
				free(ss);
				p--; {cs = 268;goto _again;}
			}
			zs_deinit(ss);
			free(ss);
		} else {
			s->state = ZS_STATE_INCLUDE;
			p--; cs = 1127; {p++; goto _out; }
		}
	}
	break;
	case 81:
	{ p--; {stack[top++] = cs; cs = 312;goto _again;} }
	break;
	case 82:
	{
		ERR(ZS_OK);
	}
	break;
	case 83:
	{
		NOERR;
	}
	break;
	case 84:
	{
		ERR(ZS_BAD_DIRECTIVE);
		p--; {cs = 268;goto _again;}
	}
	break;
	case 85:
	{
		s->r_class = s->default_class;
	}
	break;
	case 86:
	{
		s->r_ttl = s->default_ttl;
	}
	break;
	case 87:
	{
		s->r_class = KNOT_CLASS_IN;
	}
	break;
	case 88:
	{
		if (s->number64 <= UINT32_MAX) {
			s->r_ttl = (uint32_t)(s->number64);
		} else {
			WARN(ZS_NUMBER32_OVERFLOW);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 89:
	{
		s->buffer_length = 0;
	}
	break;
	case 90:
	{
		if (s->buffer_length < MAX_RDATA_LENGTH) {
			s->buffer[s->buffer_length++] = (*p);
		}
		else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 91:
	{
		WARN(ZS_BAD_ADDRESS_CHAR);
		p--; {cs = 268;goto _again;}
	}
	break;
	case 92:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET, (char *)s->buffer, &addr4) <= 0) {
			WARN(ZS_BAD_IPV4);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 93:
	{
		memcpy(rdata_tail, &(addr4.s_addr), INET4_ADDR_LENGTH);
		rdata_tail += INET4_ADDR_LENGTH;
	}
	break;
	case 94:
	{
		s->buffer[s->buffer_length] = 0;

		if (inet_pton(AF_INET6, (char *)s->buffer, &addr6) <= 0) {
			WARN(ZS_BAD_IPV6);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 95:
	{
		memcpy(rdata_tail, &(addr6.s6_addr), INET6_ADDR_LENGTH);
		rdata_tail += INET6_ADDR_LENGTH;
	}
	break;
	case 96:
	{
		memset(&(s->apl), 0, sizeof(s->apl));
	}
	break;
	case 97:
	{
		s->apl.excl_flag = 128; // dec 128  = bin 10000000.
	}
	break;
	case 98:
	{
		s->apl.addr_family = 1;
	}
	break;
	case 99:
	{
		s->apl.addr_family = 2;
	}
	break;
	case 100:
	{
		if ((s->apl.addr_family == 1 && s->number64 <= 32) ||
		    (s->apl.addr_family == 2 && s->number64 <= 128)) {
			s->apl.prefix_length = (uint8_t)(s->number64);
		} else {
			WARN(ZS_BAD_APL);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 101:
	{
		// Write address family.
		*((uint16_t *)rdata_tail) = htons(s->apl.addr_family);
		rdata_tail += 2;
		// Write prefix length in bites.
		*(rdata_tail) = s->apl.prefix_length;
		rdata_tail += 1;
		// Copy address to buffer.
		uint8_t len;
		switch (s->apl.addr_family) {
		case 1:
			len = INET4_ADDR_LENGTH;
			memcpy(s->buffer, &(addr4.s_addr), len);
			break;
		case 2:
			len = INET6_ADDR_LENGTH;
			memcpy(s->buffer, &(addr6.s6_addr), len);
			break;
		default:
			WARN(ZS_BAD_APL);
			p--; {cs = 268;goto _again;}
		}
		// Find prefix without trailing zeroes.
		while (len > 0) {
			if ((s->buffer[len - 1] & 255) != 0) {
				break;
			}
			len--;
		}
		// Write negation flag + prefix length in bytes.
		*(rdata_tail) = len + s->apl.excl_flag;
		rdata_tail += 1;
		// Write address prefix non-null data.
		memcpy(rdata_tail, s->buffer, len);
		rdata_tail += len;
	}
	break;
	case 102:
	{
		WARN(ZS_BAD_APL);
		p--; {cs = 268;goto _again;}
	}
	break;
	case 103:
	{
		if (rdata_tail <= rdata_stop) {
			*rdata_tail = first_hex_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 104:
	{
		*rdata_tail += second_hex_to_num[(uint8_t)(*p)];
		rdata_tail++;
	}
	break;
	case 105:
	{
		WARN(ZS_BAD_HEX_CHAR);
		p--; {cs = 268;goto _again;}
	}
	break;
	case 106:
	{
		if ((rdata_tail - s->r_data) != s->r_data_length) {
			WARN(ZS_BAD_RDATA_LENGTH);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 107:
	{
		WARN(ZS_BAD_HEX_RDATA);
		p--; {cs = 268;goto _again;}
	}
	break;
	case 108:
	{
		if (rdata_tail <= rdata_stop) {
			*rdata_tail = first_base64_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 109:
	{
		*(rdata_tail++) += second_left_base64_to_num[(uint8_t)(*p)];

		if (rdata_tail <= rdata_stop) {
			*rdata_tail = second_right_base64_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 110:
	{
		*(rdata_tail++) += third_left_base64_to_num[(uint8_t)(*p)];

		if (rdata_tail <= rdata_stop) {
			*rdata_tail = third_right_base64_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 111:
	{
		*(rdata_tail++) += fourth_base64_to_num[(uint8_t)(*p)];
	}
	break;
	case 112:
	{
		WARN(ZS_BAD_BASE64_CHAR);
		p--; {cs = 268;goto _again;}
	}
	break;
	case 113:
	{ p--; {stack[top++] = cs; cs = 329;goto _again;} }
	break;
	case 114:
	{
		if (rdata_tail <= rdata_stop) {
			*rdata_tail = first_base32hex_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 115:
	{
		*(rdata_tail++) += second_left_base32hex_to_num[(uint8_t)(*p)];

		if (rdata_tail <= rdata_stop) {
			*rdata_tail = second_right_base32hex_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 116:
	{
		*rdata_tail += third_base32hex_to_num[(uint8_t)(*p)];
	}
	break;
	case 117:
	{
		*(rdata_tail++) += fourth_left_base32hex_to_num[(uint8_t)(*p)];

		if (rdata_tail <= rdata_stop) {
			*rdata_tail = fourth_right_base32hex_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 118:
	{
		*(rdata_tail++) += fifth_left_base32hex_to_num[(uint8_t)(*p)];

		if (rdata_tail <= rdata_stop) {
			*rdata_tail = fifth_right_base32hex_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 119:
	{
		*rdata_tail += sixth_base32hex_to_num[(uint8_t)(*p)];
	}
	break;
	case 120:
	{
		*(rdata_tail++) += seventh_left_base32hex_to_num[(uint8_t)(*p)];

		if (rdata_tail <= rdata_stop) {
			*rdata_tail = seventh_right_base32hex_to_num[(uint8_t)(*p)];
		} else {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 121:
	{
		*(rdata_tail++) += eighth_base32hex_to_num[(uint8_t)(*p)];
	}
	break;
	case 122:
	{
		WARN(ZS_BAD_BASE32HEX_CHAR);
		p--; {cs = 268;goto _again;}
	}
	break;
	case 123:
	{
		*(rdata_tail++) = 0;
	}
	break;
	case 124:
	{
		*(rdata_tail++) = 1;
	}
	break;
	case 125:
	{
		*(rdata_tail++) = 2;
	}
	break;
	case 126:
	{
		*(rdata_tail++) = 3;
	}
	break;
	case 127:
	{
		*(rdata_tail++) = 5;
	}
	break;
	case 128:
	{
		*(rdata_tail++) = 6;
	}
	break;
	case 129:
	{
		*(rdata_tail++) = 7;
	}
	break;
	case 130:
	{
		*(rdata_tail++) = 8;
	}
	break;
	case 131:
	{
		*(rdata_tail++) = 10;
	}
	break;
	case 132:
	{
		*(rdata_tail++) = 12;
	}
	break;
	case 133:
	{
		*(rdata_tail++) = 13;
	}
	break;
	case 134:
	{
		*(rdata_tail++) = 14;
	}
	break;
	case 135:
	{
		*(rdata_tail++) = 15;
	}
	break;
	case 136:
	{
		*(rdata_tail++) = 16;
	}
	break;
	case 137:
	{
		*(rdata_tail++) = 252;
	}
	break;
	case 138:
	{
		*(rdata_tail++) = 253;
	}
	break;
	case 139:
	{
		*(rdata_tail++) = 254;
	}
	break;
	case 140:
	{
		*((uint16_t *)rdata_tail) = htons(1);
		rdata_tail += 2;
	}
	break;
	case 141:
	{
		*((uint16_t *)rdata_tail) = htons(2);
		rdata_tail += 2;
	}
	break;
	case 142:
	{
		*((uint16_t *)rdata_tail) = htons(3);
		rdata_tail += 2;
	}
	break;
	case 143:
	{
		*((uint16_t *)rdata_tail) = htons(4);
		rdata_tail += 2;
	}
	break;
	case 144:
	{
		*((uint16_t *)rdata_tail) = htons(5);
		rdata_tail += 2;
	}
	break;
	case 145:
	{
		*((uint16_t *)rdata_tail) = htons(6);
		rdata_tail += 2;
	}
	break;
	case 146:
	{
		*((uint16_t *)rdata_tail) = htons(7);
		rdata_tail += 2;
	}
	break;
	case 147:
	{
		*((uint16_t *)rdata_tail) = htons(8);
		rdata_tail += 2;
	}
	break;
	case 148:
	{
		*((uint16_t *)rdata_tail) = htons(253);
		rdata_tail += 2;
	}
	break;
	case 149:
	{
		*((uint16_t *)rdata_tail) = htons(254);
		rdata_tail += 2;
	}
	break;
	case 150:
	{
		WARN(ZS_BAD_GATEWAY);
		p--; {cs = 268;goto _again;}
	}
	break;
	case 151:
	{
		WARN(ZS_BAD_GATEWAY_KEY);
		p--; {cs = 268;goto _again;}
	}
	break;
	case 152:
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {cs = 268;goto _again;}
	}
	break;
	case 153:
	{ type_num(KNOT_RRTYPE_A, &rdata_tail); }
	break;
	case 154:
	{ type_num(KNOT_RRTYPE_NS, &rdata_tail); }
	break;
	case 155:
	{ type_num(KNOT_RRTYPE_CNAME, &rdata_tail); }
	break;
	case 156:
	{ type_num(KNOT_RRTYPE_SOA, &rdata_tail); }
	break;
	case 157:
	{ type_num(KNOT_RRTYPE_PTR, &rdata_tail); }
	break;
	case 158:
	{ type_num(KNOT_RRTYPE_HINFO, &rdata_tail); }
	break;
	case 159:
	{ type_num(KNOT_RRTYPE_MINFO, &rdata_tail); }
	break;
	case 160:
	{ type_num(KNOT_RRTYPE_MX, &rdata_tail); }
	break;
	case 161:
	{ type_num(KNOT_RRTYPE_TXT, &rdata_tail); }
	break;
	case 162:
	{ type_num(KNOT_RRTYPE_RP, &rdata_tail); }
	break;
	case 163:
	{ type_num(KNOT_RRTYPE_AFSDB, &rdata_tail); }
	break;
	case 164:
	{ type_num(KNOT_RRTYPE_RT, &rdata_tail); }
	break;
	case 165:
	{ type_num(KNOT_RRTYPE_KEY, &rdata_tail); }
	break;
	case 166:
	{ type_num(KNOT_RRTYPE_AAAA, &rdata_tail); }
	break;
	case 167:
	{ type_num(KNOT_RRTYPE_LOC, &rdata_tail); }
	break;
	case 168:
	{ type_num(KNOT_RRTYPE_SRV, &rdata_tail); }
	break;
	case 169:
	{ type_num(KNOT_RRTYPE_NAPTR, &rdata_tail); }
	break;
	case 170:
	{ type_num(KNOT_RRTYPE_KX, &rdata_tail); }
	break;
	case 171:
	{ type_num(KNOT_RRTYPE_CERT, &rdata_tail); }
	break;
	case 172:
	{ type_num(KNOT_RRTYPE_DNAME, &rdata_tail); }
	break;
	case 173:
	{ type_num(KNOT_RRTYPE_APL, &rdata_tail); }
	break;
	case 174:
	{ type_num(KNOT_RRTYPE_DS, &rdata_tail); }
	break;
	case 175:
	{ type_num(KNOT_RRTYPE_SSHFP, &rdata_tail); }
	break;
	case 176:
	{ type_num(KNOT_RRTYPE_IPSECKEY, &rdata_tail); }
	break;
	case 177:
	{ type_num(KNOT_RRTYPE_RRSIG, &rdata_tail); }
	break;
	case 178:
	{ type_num(KNOT_RRTYPE_NSEC, &rdata_tail); }
	break;
	case 179:
	{ type_num(KNOT_RRTYPE_DNSKEY, &rdata_tail); }
	break;
	case 180:
	{ type_num(KNOT_RRTYPE_DHCID, &rdata_tail); }
	break;
	case 181:
	{ type_num(KNOT_RRTYPE_NSEC3, &rdata_tail); }
	break;
	case 182:
	{ type_num(KNOT_RRTYPE_NSEC3PARAM, &rdata_tail); }
	break;
	case 183:
	{ type_num(KNOT_RRTYPE_TLSA, &rdata_tail); }
	break;
	case 184:
	{ type_num(KNOT_RRTYPE_CDS, &rdata_tail); }
	break;
	case 185:
	{ type_num(KNOT_RRTYPE_CDNSKEY, &rdata_tail); }
	break;
	case 186:
	{ type_num(KNOT_RRTYPE_SPF, &rdata_tail); }
	break;
	case 187:
	{ type_num(KNOT_RRTYPE_NID, &rdata_tail); }
	break;
	case 188:
	{ type_num(KNOT_RRTYPE_L32, &rdata_tail); }
	break;
	case 189:
	{ type_num(KNOT_RRTYPE_L64, &rdata_tail); }
	break;
	case 190:
	{ type_num(KNOT_RRTYPE_LP, &rdata_tail); }
	break;
	case 191:
	{ type_num(KNOT_RRTYPE_EUI48, &rdata_tail); }
	break;
	case 192:
	{ type_num(KNOT_RRTYPE_EUI64, &rdata_tail); }
	break;
	case 193:
	{ type_num(KNOT_RRTYPE_URI, &rdata_tail); }
	break;
	case 194:
	{ type_num(KNOT_RRTYPE_CAA, &rdata_tail); }
	break;
	case 195:
	{
		if (s->number64 <= UINT16_MAX) {
			window_add_bit(s->number64, s);
		} else {
			WARN(ZS_NUMBER16_OVERFLOW);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 196:
	{ window_add_bit(KNOT_RRTYPE_A, s); }
	break;
	case 197:
	{ window_add_bit(KNOT_RRTYPE_NS, s); }
	break;
	case 198:
	{ window_add_bit(KNOT_RRTYPE_CNAME, s); }
	break;
	case 199:
	{ window_add_bit(KNOT_RRTYPE_SOA, s); }
	break;
	case 200:
	{ window_add_bit(KNOT_RRTYPE_PTR, s); }
	break;
	case 201:
	{ window_add_bit(KNOT_RRTYPE_HINFO, s); }
	break;
	case 202:
	{ window_add_bit(KNOT_RRTYPE_MINFO, s); }
	break;
	case 203:
	{ window_add_bit(KNOT_RRTYPE_MX, s); }
	break;
	case 204:
	{ window_add_bit(KNOT_RRTYPE_TXT, s); }
	break;
	case 205:
	{ window_add_bit(KNOT_RRTYPE_RP, s); }
	break;
	case 206:
	{ window_add_bit(KNOT_RRTYPE_AFSDB, s); }
	break;
	case 207:
	{ window_add_bit(KNOT_RRTYPE_RT, s); }
	break;
	case 208:
	{ window_add_bit(KNOT_RRTYPE_KEY, s); }
	break;
	case 209:
	{ window_add_bit(KNOT_RRTYPE_AAAA, s); }
	break;
	case 210:
	{ window_add_bit(KNOT_RRTYPE_LOC, s); }
	break;
	case 211:
	{ window_add_bit(KNOT_RRTYPE_SRV, s); }
	break;
	case 212:
	{ window_add_bit(KNOT_RRTYPE_NAPTR, s); }
	break;
	case 213:
	{ window_add_bit(KNOT_RRTYPE_KX, s); }
	break;
	case 214:
	{ window_add_bit(KNOT_RRTYPE_CERT, s); }
	break;
	case 215:
	{ window_add_bit(KNOT_RRTYPE_DNAME, s); }
	break;
	case 216:
	{ window_add_bit(KNOT_RRTYPE_APL, s); }
	break;
	case 217:
	{ window_add_bit(KNOT_RRTYPE_DS, s); }
	break;
	case 218:
	{ window_add_bit(KNOT_RRTYPE_SSHFP, s); }
	break;
	case 219:
	{ window_add_bit(KNOT_RRTYPE_IPSECKEY, s); }
	break;
	case 220:
	{ window_add_bit(KNOT_RRTYPE_RRSIG, s); }
	break;
	case 221:
	{ window_add_bit(KNOT_RRTYPE_NSEC, s); }
	break;
	case 222:
	{ window_add_bit(KNOT_RRTYPE_DNSKEY, s); }
	break;
	case 223:
	{ window_add_bit(KNOT_RRTYPE_DHCID, s); }
	break;
	case 224:
	{ window_add_bit(KNOT_RRTYPE_NSEC3, s); }
	break;
	case 225:
	{ window_add_bit(KNOT_RRTYPE_NSEC3PARAM, s); }
	break;
	case 226:
	{ window_add_bit(KNOT_RRTYPE_TLSA, s); }
	break;
	case 227:
	{ window_add_bit(KNOT_RRTYPE_CDS, s); }
	break;
	case 228:
	{ window_add_bit(KNOT_RRTYPE_CDNSKEY, s); }
	break;
	case 229:
	{ window_add_bit(KNOT_RRTYPE_SPF, s); }
	break;
	case 230:
	{ window_add_bit(KNOT_RRTYPE_NID, s); }
	break;
	case 231:
	{ window_add_bit(KNOT_RRTYPE_L32, s); }
	break;
	case 232:
	{ window_add_bit(KNOT_RRTYPE_L64, s); }
	break;
	case 233:
	{ window_add_bit(KNOT_RRTYPE_LP, s); }
	break;
	case 234:
	{ window_add_bit(KNOT_RRTYPE_EUI48, s); }
	break;
	case 235:
	{ window_add_bit(KNOT_RRTYPE_EUI64, s); }
	break;
	case 236:
	{ window_add_bit(KNOT_RRTYPE_URI, s); }
	break;
	case 237:
	{ window_add_bit(KNOT_RRTYPE_CAA, s); }
	break;
	case 238:
	{
		memset(s->windows, 0, sizeof(s->windows));
		s->last_window = -1;
	}
	break;
	case 239:
	{
		for (window = 0; window <= s->last_window; window++) {
			if ((s->windows[window]).length > 0) {
				if (rdata_tail + 2 + (s->windows[window]).length <= rdata_stop)
				{
					// Window number.
					*rdata_tail = (uint8_t)window;
					rdata_tail += 1;
					// Bitmap length.
					*rdata_tail = (s->windows[window]).length;
					rdata_tail += 1;
					// Copying bitmap.
					memcpy(rdata_tail,
					       (s->windows[window]).bitmap,
					       (s->windows[window]).length);
					rdata_tail += (s->windows[window]).length;
				} else {
					WARN(ZS_RDATA_OVERFLOW);
					p--; {cs = 268;goto _again;}
				}
			}
		}
	}
	break;
	case 240:
	{
		WARN(ZS_BAD_BITMAP);
		p--; {cs = 268;goto _again;}
	}
	break;
	case 241:
	{ p--; {stack[top++] = cs; cs = 336;goto _again;} }
	break;
	case 242:
	{
		if (s->number64 <= 90) {
			s->loc.d1 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 243:
	{
		if (s->number64 <= 180) {
			s->loc.d2 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 244:
	{
		if (s->number64 <= 59) {
			s->loc.m1 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 245:
	{
		if (s->number64 <= 59) {
			s->loc.m2 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 246:
	{
		if (s->number64 <= 59999) {
			s->loc.s1 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 247:
	{
		if (s->number64 <= 59999) {
			s->loc.s2 = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 248:
	{
		if ((s->loc.alt_sign ==  1 && s->number64 <= 4284967295) ||
		    (s->loc.alt_sign == -1 && s->number64 <=   10000000))
		{
			s->loc.alt = (uint32_t)(s->number64);
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 249:
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.siz = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 250:
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.hp = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 251:
	{
		if (s->number64 <= 9000000000ULL) {
			s->loc.vp = s->number64;
		} else {
			WARN(ZS_BAD_NUMBER);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 252:
	{
		s->loc.lat_sign = -1;
	}
	break;
	case 253:
	{
		s->loc.long_sign = -1;
	}
	break;
	case 254:
	{
		s->loc.alt_sign = -1;
	}
	break;
	case 255:
	{
		memset(&(s->loc), 0, sizeof(s->loc));
		// Defaults.
		s->loc.siz = 100;
		s->loc.vp  = 1000;
		s->loc.hp  = 1000000;
		s->loc.lat_sign  = 1;
		s->loc.long_sign = 1;
		s->loc.alt_sign  = 1;
	}
	break;
	case 256:
	{
		// Write version.
		*(rdata_tail) = 0;
		rdata_tail += 1;
		// Write size.
		*(rdata_tail) = loc64to8(s->loc.siz);
		rdata_tail += 1;
		// Write horizontal precision.
		*(rdata_tail) = loc64to8(s->loc.hp);
		rdata_tail += 1;
		// Write vertical precision.
		*(rdata_tail) = loc64to8(s->loc.vp);
		rdata_tail += 1;
		// Write latitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LAT_ZERO + s->loc.lat_sign *
			(3600000 * s->loc.d1 + 60000 * s->loc.m1 + s->loc.s1));
		rdata_tail += 4;
		// Write longitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_LONG_ZERO + s->loc.long_sign *
			(3600000 * s->loc.d2 + 60000 * s->loc.m2 + s->loc.s2));
		rdata_tail += 4;
		// Write altitude.
		*((uint32_t *)rdata_tail) = htonl(LOC_ALT_ZERO + s->loc.alt_sign *
			(s->loc.alt));
		rdata_tail += 4;
	}
	break;
	case 257:
	{
		WARN(ZS_BAD_LOC_DATA);
		p--; {cs = 268;goto _again;}
	}
	break;
	case 258:
	{
		WARN(ZS_BAD_HEX_RDATA);
		p--; {cs = 268;goto _again;}
	}
	break;
	case 259:
	{
		s->item_length = 0;
	}
	break;
	case 260:
	{
		s->item_length++;
	}
	break;
	case 261:
	{
		if (s->item_length != 6) {
			WARN(ZS_BAD_EUI_LENGTH);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 262:
	{
		if (s->item_length != 8) {
			WARN(ZS_BAD_EUI_LENGTH);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 263:
	{
		WARN(ZS_BAD_CHAR_DASH);
		p--; {cs = 268;goto _again;}
	}
	break;
	case 264:
	{
		s->item_length = 0;
	}
	break;
	case 265:
	{
		s->item_length++;
	}
	break;
	case 266:
	{
		if (s->item_length != 4) {
			WARN(ZS_BAD_L64_LENGTH);
			p--; {cs = 268;goto _again;}
		}
	}
	break;
	case 267:
	{
		WARN(ZS_BAD_CHAR_COLON);
		p--; {cs = 268;goto _again;}
	}
	break;
	case 268:
	{
		WARN(ZS_BAD_ALGORITHM);
		p--; {cs = 268;goto _again;}
	}
	break;
	case 269:
	{
		WARN(ZS_BAD_CERT_TYPE);
		p--; {cs = 268;goto _again;}
	}
	break;
	case 270:
	{ p--; {stack[top++] = cs; cs = 487;goto _again;} }
	break;
	case 271:
	{ p--; {stack[top++] = cs; cs = 591;goto _again;} }
	break;
	case 272:
	{
		rdata_tail = s->r_data;
	}
	break;
	case 273:
	{
		WARN(ZS_BAD_RDATA);
		p--; {cs = 268;goto _again;}
	}
	break;
	case 274:
	{
		p--;
		switch (s->r_type) {
		case KNOT_RRTYPE_A:
			{stack[top++] = cs; cs = 632;goto _again;}
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
			{stack[top++] = cs; cs = 634;goto _again;}
		case KNOT_RRTYPE_SOA:
			{stack[top++] = cs; cs = 636;goto _again;}
		case KNOT_RRTYPE_HINFO:
			{stack[top++] = cs; cs = 668;goto _again;}
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_RP:
			{stack[top++] = cs; cs = 673;goto _again;}
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_LP:
			{stack[top++] = cs; cs = 678;goto _again;}
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
			{stack[top++] = cs; cs = 683;goto _again;}
		case KNOT_RRTYPE_AAAA:
			{stack[top++] = cs; cs = 687;goto _again;}
		case KNOT_RRTYPE_LOC:
			{stack[top++] = cs; cs = 689;goto _again;}
		case KNOT_RRTYPE_SRV:
			{stack[top++] = cs; cs = 744;goto _again;}
		case KNOT_RRTYPE_NAPTR:
			{stack[top++] = cs; cs = 755;goto _again;}
		case KNOT_RRTYPE_CERT:
			{stack[top++] = cs; cs = 772;goto _again;}
		case KNOT_RRTYPE_APL:
			{stack[top++] = cs; cs = 783;goto _again;}
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_CDS:
			{stack[top++] = cs; cs = 794;goto _again;}
		case KNOT_RRTYPE_SSHFP:
			{stack[top++] = cs; cs = 807;goto _again;}
		case KNOT_RRTYPE_IPSECKEY:
			{stack[top++] = cs; cs = 817;goto _again;}
		case KNOT_RRTYPE_RRSIG:
			{stack[top++] = cs; cs = 856;goto _again;}
		case KNOT_RRTYPE_NSEC:
			{stack[top++] = cs; cs = 1010;goto _again;}
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_CDNSKEY:
			{stack[top++] = cs; cs = 1013;goto _again;}
		case KNOT_RRTYPE_DHCID:
			{stack[top++] = cs; cs = 1024;goto _again;}
		case KNOT_RRTYPE_NSEC3:
			{stack[top++] = cs; cs = 1026;goto _again;}
		case KNOT_RRTYPE_NSEC3PARAM:
			{stack[top++] = cs; cs = 1055;goto _again;}
		case KNOT_RRTYPE_TLSA:
			{stack[top++] = cs; cs = 1068;goto _again;}
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L64:
			{stack[top++] = cs; cs = 1086;goto _again;}
		case KNOT_RRTYPE_L32:
			{stack[top++] = cs; cs = 1081;goto _again;}
		case KNOT_RRTYPE_EUI48:
			{stack[top++] = cs; cs = 1099;goto _again;}
		case KNOT_RRTYPE_EUI64:
			{stack[top++] = cs; cs = 1105;goto _again;}
		case KNOT_RRTYPE_URI:
			{stack[top++] = cs; cs = 1111;goto _again;}
		case KNOT_RRTYPE_CAA:
			{stack[top++] = cs; cs = 1119;goto _again;}
		default:
			WARN(ZS_CANNOT_TEXT_DATA);
			{cs = 268;goto _again;}
		}
	}
	break;
	case 275:
	{
		switch (s->r_type) {
		// Next types must not have empty rdata.
		case KNOT_RRTYPE_A:
		case KNOT_RRTYPE_NS:
		case KNOT_RRTYPE_CNAME:
		case KNOT_RRTYPE_PTR:
		case KNOT_RRTYPE_DNAME:
		case KNOT_RRTYPE_SOA:
		case KNOT_RRTYPE_HINFO:
		case KNOT_RRTYPE_MINFO:
		case KNOT_RRTYPE_MX:
		case KNOT_RRTYPE_AFSDB:
		case KNOT_RRTYPE_RT:
		case KNOT_RRTYPE_KX:
		case KNOT_RRTYPE_TXT:
		case KNOT_RRTYPE_SPF:
		case KNOT_RRTYPE_RP:
		case KNOT_RRTYPE_AAAA:
		case KNOT_RRTYPE_LOC:
		case KNOT_RRTYPE_SRV:
		case KNOT_RRTYPE_NAPTR:
		case KNOT_RRTYPE_CERT:
		case KNOT_RRTYPE_DS:
		case KNOT_RRTYPE_SSHFP:
		case KNOT_RRTYPE_IPSECKEY:
		case KNOT_RRTYPE_RRSIG:
		case KNOT_RRTYPE_NSEC:
		case KNOT_RRTYPE_KEY:
		case KNOT_RRTYPE_DNSKEY:
		case KNOT_RRTYPE_DHCID:
		case KNOT_RRTYPE_NSEC3:
		case KNOT_RRTYPE_NSEC3PARAM:
		case KNOT_RRTYPE_TLSA:
		case KNOT_RRTYPE_CDS:
		case KNOT_RRTYPE_CDNSKEY:
		case KNOT_RRTYPE_NID:
		case KNOT_RRTYPE_L32:
		case KNOT_RRTYPE_L64:
		case KNOT_RRTYPE_LP:
		case KNOT_RRTYPE_EUI48:
		case KNOT_RRTYPE_EUI64:
		case KNOT_RRTYPE_URI:
		case KNOT_RRTYPE_CAA:
			{stack[top++] = cs; cs = 468;goto _again;}
		// Next types can have empty rdata.
		case KNOT_RRTYPE_APL:
		default:
			{stack[top++] = cs; cs = 477;goto _again;}
		}
	}
	break;
	case 276:
	{
		if (pe - p == 1) {
			*wrap = WRAP_DETECTED;
		}
	}
	break;
	case 277:
	{
		if (*wrap == WRAP_NONE) {
			p--;
		}
	}
	break;
	case 278:
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {cs = 268;goto _again;}
	}
	break;
	case 279:
	{ s->r_type = KNOT_RRTYPE_A; }
	break;
	case 280:
	{ s->r_type = KNOT_RRTYPE_NS; }
	break;
	case 281:
	{ s->r_type = KNOT_RRTYPE_CNAME; }
	break;
	case 282:
	{ s->r_type = KNOT_RRTYPE_SOA; }
	break;
	case 283:
	{ s->r_type = KNOT_RRTYPE_PTR; }
	break;
	case 284:
	{ s->r_type = KNOT_RRTYPE_HINFO; }
	break;
	case 285:
	{ s->r_type = KNOT_RRTYPE_MINFO; }
	break;
	case 286:
	{ s->r_type = KNOT_RRTYPE_MX; }
	break;
	case 287:
	{ s->r_type = KNOT_RRTYPE_TXT; }
	break;
	case 288:
	{ s->r_type = KNOT_RRTYPE_RP; }
	break;
	case 289:
	{ s->r_type = KNOT_RRTYPE_AFSDB; }
	break;
	case 290:
	{ s->r_type = KNOT_RRTYPE_RT; }
	break;
	case 291:
	{ s->r_type = KNOT_RRTYPE_KEY; }
	break;
	case 292:
	{ s->r_type = KNOT_RRTYPE_AAAA; }
	break;
	case 293:
	{ s->r_type = KNOT_RRTYPE_LOC; }
	break;
	case 294:
	{ s->r_type = KNOT_RRTYPE_SRV; }
	break;
	case 295:
	{ s->r_type = KNOT_RRTYPE_NAPTR; }
	break;
	case 296:
	{ s->r_type = KNOT_RRTYPE_KX; }
	break;
	case 297:
	{ s->r_type = KNOT_RRTYPE_CERT; }
	break;
	case 298:
	{ s->r_type = KNOT_RRTYPE_DNAME; }
	break;
	case 299:
	{ s->r_type = KNOT_RRTYPE_APL; }
	break;
	case 300:
	{ s->r_type = KNOT_RRTYPE_DS; }
	break;
	case 301:
	{ s->r_type = KNOT_RRTYPE_SSHFP; }
	break;
	case 302:
	{ s->r_type = KNOT_RRTYPE_IPSECKEY; }
	break;
	case 303:
	{ s->r_type = KNOT_RRTYPE_RRSIG; }
	break;
	case 304:
	{ s->r_type = KNOT_RRTYPE_NSEC; }
	break;
	case 305:
	{ s->r_type = KNOT_RRTYPE_DNSKEY; }
	break;
	case 306:
	{ s->r_type = KNOT_RRTYPE_DHCID; }
	break;
	case 307:
	{ s->r_type = KNOT_RRTYPE_NSEC3; }
	break;
	case 308:
	{ s->r_type = KNOT_RRTYPE_NSEC3PARAM; }
	break;
	case 309:
	{ s->r_type = KNOT_RRTYPE_TLSA; }
	break;
	case 310:
	{ s->r_type = KNOT_RRTYPE_CDS; }
	break;
	case 311:
	{ s->r_type = KNOT_RRTYPE_CDNSKEY; }
	break;
	case 312:
	{ s->r_type = KNOT_RRTYPE_SPF; }
	break;
	case 313:
	{ s->r_type = KNOT_RRTYPE_NID; }
	break;
	case 314:
	{ s->r_type = KNOT_RRTYPE_L32; }
	break;
	case 315:
	{ s->r_type = KNOT_RRTYPE_L64; }
	break;
	case 316:
	{ s->r_type = KNOT_RRTYPE_LP; }
	break;
	case 317:
	{ s->r_type = KNOT_RRTYPE_EUI48; }
	break;
	case 318:
	{ s->r_type = KNOT_RRTYPE_EUI64; }
	break;
	case 319:
	{ s->r_type = KNOT_RRTYPE_URI; }
	break;
	case 320:
	{ s->r_type = KNOT_RRTYPE_CAA; }
	break;
	case 321:
	{
		if (rdata_tail - s->r_data > UINT16_MAX) {
			WARN(ZS_RDATA_OVERFLOW);
			p--; {cs = 268;goto _again;}
		}
		s->r_data_length = rdata_tail - s->r_data;

		s->state = ZS_STATE_DATA;

		// Execute the record callback.
		if (s->process.automatic) {
			if (s->process.record != NULL) {
				s->process.record(s);

				// Stop if required from the callback.
				if (s->state == ZS_STATE_STOP) {
					{p++; goto _out; }
				}
			}
		} else {
			// Return if external processing.
			p--; {p++; goto _out; }
		}
	}
	break;
		}
	}

_again:
	if ( cs == 0 )
		goto _out;
	if ( ++p != pe )
		goto _resume;
	_test_eof: {}
	if ( p == eof )
	{
	const short *__acts = _zone_scanner_actions + _zone_scanner_eof_actions[cs];
	unsigned int __nacts = (unsigned int) *__acts++;
	while ( __nacts-- > 0 ) {
		switch ( *__acts++ ) {
	case 7:
	{
		WARN(ZS_BAD_REST);
		p--; {cs = 268;	if ( p == pe )
		goto _test_eof;
goto _again;}
	}
	break;
	case 17:
	{
		WARN(ZS_BAD_NUMBER);
		p--; {cs = 268;	if ( p == pe )
		goto _test_eof;
goto _again;}
	}
	break;
	case 22:
	{
		WARN(ZS_BAD_DNAME_CHAR);
		p--; {cs = 268;	if ( p == pe )
		goto _test_eof;
goto _again;}
	}
	break;
	case 29:
	{
		s->r_owner_length = 0;
		WARN(ZS_BAD_OWNER);
		p--; {cs = 268;	if ( p == pe )
		goto _test_eof;
goto _again;}
	}
	break;
	case 34:
	{
		WARN(ZS_BAD_NUMBER);
		p--; {cs = 268;	if ( p == pe )
		goto _test_eof;
goto _again;}
	}
	break;
	case 46:
	{
		WARN(ZS_BAD_TIME_UNIT);
		p--; {cs = 268;	if ( p == pe )
		goto _test_eof;
goto _again;}
	}
	break;
	case 56:
	{
		WARN(ZS_BAD_TIMESTAMP_CHAR);
		p--; {cs = 268;	if ( p == pe )
		goto _test_eof;
goto _again;}
	}
	break;
	case 58:
	{
		WARN(ZS_BAD_TEXT_CHAR);
		p--; {cs = 268;	if ( p == pe )
		goto _test_eof;
goto _again;}
	}
	break;
	case 59:
	{
		WARN(ZS_BAD_TEXT);
		p--; {cs = 268;	if ( p == pe )
		goto _test_eof;
goto _again;}
	}
	break;
	case 63:
	{
		WARN(ZS_BAD_NUMBER);
		p--; {cs = 268;	if ( p == pe )
		goto _test_eof;
goto _again;}
	}
	break;
	case 66:
	{
		s->long_string = false;
	}
	break;
	case 68:
	{
		ERR(ZS_BAD_TTL);
		p--; {cs = 268;	if ( p == pe )
		goto _test_eof;
goto _again;}
	}
	break;
	case 72:
	{
		ERR(ZS_BAD_ORIGIN);
		p--; {cs = 268;	if ( p == pe )
		goto _test_eof;
goto _again;}
	}
	break;
	case 76:
	{
		ERR(ZS_BAD_INCLUDE_FILENAME);
		p--; {cs = 268;	if ( p == pe )
		goto _test_eof;
goto _again;}
	}
	break;
	case 79:
	{
		ERR(ZS_BAD_INCLUDE_ORIGIN);
		p--; {cs = 268;	if ( p == pe )
		goto _test_eof;
goto _again;}
	}
	break;
	case 83:
	{
		NOERR;
	}
	break;
	case 84:
	{
		ERR(ZS_BAD_DIRECTIVE);
		p--; {cs = 268;	if ( p == pe )
		goto _test_eof;
goto _again;}
	}
	break;
	case 91:
	{
		WARN(ZS_BAD_ADDRESS_CHAR);
		p--; {cs = 268;	if ( p == pe )
		goto _test_eof;
goto _again;}
	}
	break;
	case 102:
	{
		WARN(ZS_BAD_APL);
		p--; {cs = 268;	if ( p == pe )
		goto _test_eof;
goto _again;}
	}
	break;
	case 105:
	{
		WARN(ZS_BAD_HEX_CHAR);
		p--; {cs = 268;	if ( p == pe )
		goto _test_eof;
goto _again;}
	}
	break;
	case 107:
	{
		WARN(ZS_BAD_HEX_RDATA);
		p--; {cs = 268;	if ( p == pe )
		goto _test_eof;
goto _again;}
	}
	break;
	case 112:
	{
		WARN(ZS_BAD_BASE64_CHAR);
		p--; {cs = 268;	if ( p == pe )
		goto _test_eof;
goto _again;}
	}
	break;
	case 122:
	{
		WARN(ZS_BAD_BASE32HEX_CHAR);
		p--; {cs = 268;	if ( p == pe )
		goto _test_eof;
goto _again;}
	}
	break;
	case 150:
	{
		WARN(ZS_BAD_GATEWAY);
		p--; {cs = 268;	if ( p == pe )
		goto _test_eof;
goto _again;}
	}
	break;
	case 151:
	{
		WARN(ZS_BAD_GATEWAY_KEY);
		p--; {cs = 268;	if ( p == pe )
		goto _test_eof;
goto _again;}
	}
	break;
	case 152:
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {cs = 268;	if ( p == pe )
		goto _test_eof;
goto _again;}
	}
	break;
	case 240:
	{
		WARN(ZS_BAD_BITMAP);
		p--; {cs = 268;	if ( p == pe )
		goto _test_eof;
goto _again;}
	}
	break;
	case 257:
	{
		WARN(ZS_BAD_LOC_DATA);
		p--; {cs = 268;	if ( p == pe )
		goto _test_eof;
goto _again;}
	}
	break;
	case 258:
	{
		WARN(ZS_BAD_HEX_RDATA);
		p--; {cs = 268;	if ( p == pe )
		goto _test_eof;
goto _again;}
	}
	break;
	case 263:
	{
		WARN(ZS_BAD_CHAR_DASH);
		p--; {cs = 268;	if ( p == pe )
		goto _test_eof;
goto _again;}
	}
	break;
	case 267:
	{
		WARN(ZS_BAD_CHAR_COLON);
		p--; {cs = 268;	if ( p == pe )
		goto _test_eof;
goto _again;}
	}
	break;
	case 268:
	{
		WARN(ZS_BAD_ALGORITHM);
		p--; {cs = 268;	if ( p == pe )
		goto _test_eof;
goto _again;}
	}
	break;
	case 269:
	{
		WARN(ZS_BAD_CERT_TYPE);
		p--; {cs = 268;	if ( p == pe )
		goto _test_eof;
goto _again;}
	}
	break;
	case 273:
	{
		WARN(ZS_BAD_RDATA);
		p--; {cs = 268;	if ( p == pe )
		goto _test_eof;
goto _again;}
	}
	break;
	case 278:
	{
		WARN(ZS_UNSUPPORTED_TYPE);
		p--; {cs = 268;	if ( p == pe )
		goto _test_eof;
goto _again;}
	}
	break;
		}
	}
	}

	_out: {}
	}


	// Check if the scanner state machine is in an uncovered state.
	bool extra_error = false;
	if (cs == 0) {
		ERR(ZS_UNCOVERED_STATE);
		extra_error = true;
	// Check for an unclosed multiline record.
	} else if (s->input.eof && s->multiline) {
		ERR(ZS_UNCLOSED_MULTILINE);
		extra_error = true;
	}

	// Treat the extra error.
	if (extra_error) {
		s->error.counter++;
		s->state = ZS_STATE_ERROR;

		// Copy the error context just for the part of the current line.
		s->buffer_length = 0;
		while (p < pe && *p != '\n' && s->buffer_length < 50) {
			s->buffer[s->buffer_length++] = *p++;
		}
		s->buffer[s->buffer_length++] = 0;

		// Execute the error callback.
		if (s->process.automatic && s->process.error != NULL) {
			s->process.error(s);
		}

		return;
	}

	// Storing scanner states.
	s->cs  = cs;
	s->top = top;
	memcpy(s->stack, stack, sizeof(stack));

	// Store the current parser position.
	s->input.current = p;

	// Storing r_data pointer.
	s->r_data_tail = rdata_tail - s->r_data;

	if (*wrap == WRAP_DETECTED) {
		if (set_input_string(s, "\\", 1, true) != 0) {
			return;
		}

		*wrap = WRAP_PROCESS;
		parse(s, wrap);
	} else {
		*wrap = WRAP_NONE;
	}
}

__attribute__((visibility("default")))
int zs_parse_record(
	zs_scanner_t *s)
{
	if (s == NULL) {
		return -1;
	}

	// Check if parsing is possible.
	switch (s->state) {
	case ZS_STATE_NONE:
	case ZS_STATE_DATA:
	case ZS_STATE_INCLUDE:
		break;
	case ZS_STATE_ERROR:
		if (s->error.fatal) {
			return -1;
		}
		break;
	default:
		// Return if stop or end of file.
		return 0;
	}

	// Check for the end of the input.
	if (s->input.current != s->input.end) {
		// Try to parse another item.
		s->state = ZS_STATE_NONE;
		wrap_t wrap = WRAP_NONE;
		parse(s, &wrap);

		// Finish if nothing was parsed.
		if (s->state == ZS_STATE_NONE) {
			// Parse the final block.
			if (set_input_string(s, "\n", 1, true) != 0) {
				return -1;
			}
			parse(s, &wrap);
			if (s->state == ZS_STATE_NONE) {
				s->state = ZS_STATE_EOF;
			}
		}
	} else {
		s->state = ZS_STATE_EOF;
	}

	return 0;
}

__attribute__((visibility("default")))
int zs_parse_all(
	zs_scanner_t *s)
{
	if (s == NULL) {
		return -1;
	}

	s->process.automatic = true;

	// Parse input block.
	wrap_t wrap = WRAP_NONE;
	parse(s, &wrap);

	// Parse trailing newline-char block if it makes sense.
	if (s->state != ZS_STATE_STOP && !s->error.fatal) {
		if (set_input_string(s, "\n", 1, true) != 0) {
			return -1;
		}
		parse(s, &wrap);
	}

	// Check if any errors have occurred.
	if (s->error.counter > 0) {
		return -1;
	}

	return 0;
}
